import { getFields } from '../raw-api/common';
import { RequestValidationError, looksLikeNumber, UserNotFoundError } from '@avst-api/commons';
export class IssueBuilder {
    constructor(cacheManager, fieldOperations = []) {
        this.cacheManager = cacheManager;
        this.fieldOperations = fieldOperations;
    }
    clearCache() {
        this.cacheManager.clearCache();
        return this.getNewInstance();
    }
    /**
     * Sets the reporter.
     * @param reporter Reporter's accountId or user object or email;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withReporter(reporter, updateOperation) {
        return this.setSystemField('reporter', reporter, updateOperation);
    }
    /**
     * Sets the project.
     * @param project Project ID or key or project object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withProject(project, updateOperation) {
        return this.setSystemField('project', project, updateOperation);
    }
    /**
     * Sets the issue type.
     * @param issueType Issue type ID or name or issue type object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withIssueType(issueType, updateOperation) {
        return this.setSystemField('issuetype', issueType, updateOperation);
    }
    /**
     * Sets the parent issue for a sub-task.
     * @param parentIssue Parent Issue key, Issue ID or Issue object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withParent(parentIssue, updateOperation) {
        return this.setSystemField('parent', parentIssue, updateOperation);
    }
    /**
     * Sets the components.
     * @param components Array of component IDs or component object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withComponents(components, updateOperation) {
        return this.setSystemField('components', components, updateOperation);
    }
    /**
     * Sets the assignee.
     * @param assignee Assignee's accountId or user object or email;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withAssignee(assignee, updateOperation) {
        return this.setSystemField('assignee', assignee, updateOperation);
    }
    //TODO: add support to also make it work with version names
    /**
     * Sets the fix versions.
     * @param fixVersions Array of fix version IDs or version objects;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withFixVersions(fixVersions, updateOperation) {
        return this.setSystemField('fixVersions', fixVersions, updateOperation);
    }
    /**
     * Sets the priority.
     * @param priority Priority ID, name or priority object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withPriority(priority, updateOperation) {
        return this.setSystemField('priority', priority, updateOperation);
    }
    //TODO: add support to also make it work with version names
    /**
     * Sets the versions.
     * @param versions Array of version IDs or version objects;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withVersions(versions, updateOperation) {
        return this.setSystemField('versions', versions, updateOperation);
    }
    /**
     * Sets the security.
     * @param security Issue security level ID or security level object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withSecurity(security, updateOperation) {
        return this.setSystemField('security', security, updateOperation);
    }
    /**
     * Sets the labels.
     * @param labels Array of labels;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withLabels(labels, updateOperation) {
        return this.setSystemField('labels', labels, updateOperation);
    }
    /**
     * Sets the due date.
     * @param dueDate Due date for the issue either as a ISO 8601 string or date object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withDueDate(dueDate, updateOperation) {
        return this.setSystemField('duedate', dueDate, updateOperation);
    }
    /**
     * Sets the description.
     * @param description Issue description as a string or content object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withDescription(description, updateOperation) {
        return this.setSystemField('description', description, updateOperation);
    }
    /**
     * Sets the environment.
     * @param environment Issue environment as a string or content object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEnvironment(environment, updateOperation) {
        return this.setSystemField('environment', environment, updateOperation);
    }
    /**
     * Sets the resolution while updating an issue.
     * @param resolution Issue resolution ID, name or resolution object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withResolution(resolution, updateOperation) {
        return this.setSystemField('resolution', resolution, updateOperation);
    }
    withSummary(summary, updateOperation) {
        return this.setSystemField('summary', summary, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withTextCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withReadOnlyTextCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: literal color.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withIssueColorCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: uuid.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withUUIDCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value for issues with epic issue type.
     * ghx-label-1 - brown
     * ghx-label-2 - yellow
     * ghx-label-3 - light brown
     * ghx-label-4 - dark blue
     * ghx-label-5 - light blue
     * ghx-label-6 - light green
     * ghx-label-7 - coral/orange
     * ghx-label-8 - dark purple
     * ghx-label-9 - light pink
     * ghx-label-10 - lavender
     * ghx-label-11 - light aqua
     * ghx-label-12- light gray
     * ghx-label-13 - dark green
     * ghx-label-14 - dark coral/red(ish)
     * @param customField Custom field ID or name.
     * @param value Custom field value: epic color.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEpicColorCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value for issues with epic issue type.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either ID or status object.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEpicStatusCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: epic issue key.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEpicLinkCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value for issues with epic issue type.
     * @param customField Custom field ID or name.
     * @param value Custom field value: name.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEpicNameCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withNumberCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either option of project's key or ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withProjectPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of either option name or ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiSelectCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either ISO 8601 string or Date object.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withDatePickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either option name or ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withSelectCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of either option name or ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiCheckBoxesCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either ISO 8601 string or Date object.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withDateTimePickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of labels.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withLabelsCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either option name or ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withRadioButtonsCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either Content object or string.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiLineTextCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either string or URL object.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withURLCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: User's account ID or email.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withUserPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of group names.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiGroupPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: Group's name.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withGroupPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of User's object, accound ID or email.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiUserPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of either option key or ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiVersionPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either option key or ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withVersionPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, list of options, either option IDs or option names.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    // TODO: add support for passing in option names, and figure out why updating does not work
    /*public setMultiSelectCustomField(customField: string, value: number | string | Array<number | string>, updateOperation?: UpdateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }*/
    buildCreateRequest() {
        return this.build();
    }
    buildUpdateRequest() {
        return this.build();
    }
    async build() {
        const request = {};
        const promises = [];
        this.fieldOperations.forEach(fieldOperation => promises.push(this.processField(fieldOperation, request)));
        await Promise.all(promises);
        return request;
    }
    async processField(fieldOperation, request) {
        const fieldOp = await this.populateFieldId(fieldOperation);
        const fo = await this.processValues(fieldOp);
        if (!fo.updateOperation) {
            if (!request.fields) {
                request.fields = {};
            }
            request.fields[fo.id] = fo.value;
        }
        else {
            if (!request.update) {
                request.update = {};
            }
            if (!request.update[fo.id]) {
                request.update[fo.id] = [];
            }
            request.update[fo.id].push({ [fo.updateOperation]: fo.value });
        }
    }
    async populateFieldId(fieldOperation) {
        if (fieldOperation.id) {
            return fieldOperation;
        }
        else {
            const fields = await this.cacheManager.getAllFields();
            const customFields = getFields(fields, fieldOperation.name);
            if (customFields.length === 0) {
                throw new RequestValidationError([`Custom field not found: ${fieldOperation.name}`], fieldOperation.name);
            }
            else if (customFields.length === 1) {
                fieldOperation.id = customFields[0].id;
                return fieldOperation;
            }
            else {
                throw new RequestValidationError([`Found too many matching custom fields: ${fieldOperation.name}, please consider using field ID instead`], fieldOperation.name);
            }
        }
    }
    async processValues(fieldOperation) {
        switch (fieldOperation.name) {
            case 'project':
                return this.processProjectValue(fieldOperation);
            case 'issuetype':
                return this.processIssueType(fieldOperation);
            case 'parent':
                return this.processParentIssue(fieldOperation);
            case 'components':
                return this.processMultiIDField(fieldOperation);
            case 'assignee':
                return this.processUserPickerSystemField(fieldOperation);
            case 'fixVersions':
                return this.processMultiIDField(fieldOperation);
            case 'priority':
                return this.processPriority(fieldOperation);
            case 'versions':
                return this.processMultiIDField(fieldOperation);
            case 'security':
                return this.processSecurity(fieldOperation);
            case 'description':
                return this.processTextAreaField(fieldOperation);
            case 'environment':
                return this.processTextAreaField(fieldOperation);
            case 'dueDate':
                return this.processDateField(fieldOperation);
            case 'resolution':
                return this.processResolution(fieldOperation);
            case 'reporter':
                return this.processUserPickerSystemField(fieldOperation);
        }
        if (fieldOperation.id.startsWith('customfield_')) {
            const fields = await this.cacheManager.getAllFields();
            const customField = fields.find(field => field.id === fieldOperation.id);
            if (customField) {
                switch (customField.schema.custom) {
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiselect':
                        return this.processMultiOptionField(fieldOperation, customField);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:select':
                        return this.processSingleOptionField(fieldOperation, customField);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes':
                        return this.processMultiOptionField(fieldOperation, customField);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:datepicker':
                        return this.processDateField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:datetime':
                        return this.processDateField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons':
                        return this.processSingleOptionField(fieldOperation, customField);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:textarea':
                        return this.processTextAreaField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:userpicker':
                        return this.processUserPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multigrouppicker':
                        return this.processMultiGroupPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:grouppicker':
                        return this.processGroupPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:url':
                        return this.processURLField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:project':
                        return this.processProjectPickerField(fieldOperation, customField);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiuserpicker':
                        return this.processMultiUserPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiversion':
                        return this.processMultiVersionPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:version':
                        return this.processFieldWithID(fieldOperation);
                    case 'com.pyxis.greenhopper.jira:gh-epic-status':
                        return this.processFieldWithID(fieldOperation);
                }
            }
            else {
                throw new Error(`Custom field not found: ${fieldOperation.id}`);
            }
            return fieldOperation;
        }
        return fieldOperation;
    }
    async processProjectValue(fieldOperation) {
        var _a;
        if ((_a = fieldOperation.value) === null || _a === void 0 ? void 0 : _a.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
        try {
            const project = await this.cacheManager.getProject(fieldOperation.value);
            fieldOperation.value = { id: project.id.toString() };
            return fieldOperation;
        }
        catch (e) {
            fieldOperation.isErrorInProcessProjectValue = true;
            return fieldOperation;
        }
    }
    async processIssueType(fieldOperation) {
        var _a;
        const projectId = await this.waitForProjectToBeResolved();
        if ((_a = fieldOperation.value) === null || _a === void 0 ? void 0 : _a.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
        const issueTypes = await this.cacheManager.getAllIssueTypes();
        const issueType = issueTypes.find(issueType => {
            var _a, _b;
            return issueType.name.toLowerCase() === fieldOperation.value.toString().trim().toLowerCase()
                && !issueType.scope
                || ((_b = (_a = issueType.scope) === null || _a === void 0 ? void 0 : _a.project) === null || _b === void 0 ? void 0 : _b.id) === projectId;
        });
        if (issueType) {
            fieldOperation.value = { id: issueType.id.toString() };
        }
        else {
            throw new RequestValidationError([`Issue type not found: ${fieldOperation.value}`], 'issuetype');
        }
        return fieldOperation;
    }
    waitForProjectToBeResolved() {
        const getProjectId = () => {
            const project = this.fieldOperations.find(fo => fo.name === 'project');
            if (!project) {
                throw Error('Project must be specified.');
            }
            else if (project.isErrorInProcessProjectValue) {
                throw Error(`Project with the key '${project.value}' not found.`);
            }
            else if (typeof project.value.id === 'string') {
                return project.value.id;
            }
            else {
                return undefined;
            }
        };
        return new Promise((resolve, reject) => {
            let triesBeforeRejectCounter = 0;
            const checkIfProjectIsResolved = () => {
                if (triesBeforeRejectCounter < 100) {
                    triesBeforeRejectCounter++;
                }
                else {
                    reject('Project id not found.');
                    return;
                }
                try {
                    const projectId = getProjectId();
                    if (projectId) {
                        resolve(projectId);
                    }
                    else {
                        setTimeout(checkIfProjectIsResolved, 100);
                    }
                }
                catch (e) {
                    reject(e);
                }
            };
            checkIfProjectIsResolved();
        });
    }
    processParentIssue(fieldOperation) {
        var _a, _b;
        if (((_a = fieldOperation.value) === null || _a === void 0 ? void 0 : _a.key) || ((_b = fieldOperation.value) === null || _b === void 0 ? void 0 : _b.id)) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value };
        }
        else {
            fieldOperation.value = { key: fieldOperation.value };
        }
        return fieldOperation;
    }
    async processUserPickerSystemField(fieldOperation) {
        var _a, _b;
        const emailRegExp = /.+@.+/;
        if ((_a = fieldOperation.value) === null || _a === void 0 ? void 0 : _a.accountId) {
            return fieldOperation;
        }
        else if ((_b = fieldOperation.value) === null || _b === void 0 ? void 0 : _b.match(emailRegExp)) {
            fieldOperation.value = { accountId: await this.getAccountIdByEmail(fieldOperation.value, fieldOperation.name) };
        }
        else {
            fieldOperation.value = { accountId: fieldOperation.value };
        }
        return fieldOperation;
    }
    async processMultiIDField(fieldOperation) {
        const convertedValues = [];
        (fieldOperation.value || []).forEach((value, index) => {
            if (value === null || value === void 0 ? void 0 : value.id) {
                convertedValues[index] = value;
            }
            else {
                convertedValues[index] = { id: value.toString() };
            }
        });
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    async processPriority(fieldOperation) {
        var _a;
        if ((_a = fieldOperation.value) === null || _a === void 0 ? void 0 : _a.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
        const priorities = await this.cacheManager.getAllPriorities();
        const priority = priorities.find(priority => priority.name.toLowerCase() === fieldOperation.value.toString().trim().toLowerCase());
        if (priority) {
            fieldOperation.value = { id: priority.id.toString() };
        }
        else {
            throw new RequestValidationError([`Priority not found: ${fieldOperation.value}`], 'priority');
        }
        return fieldOperation;
    }
    async processResolution(fieldOperation) {
        var _a;
        if ((_a = fieldOperation.value) === null || _a === void 0 ? void 0 : _a.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
        const resolutions = await this.cacheManager.getAllResolutions();
        const resolution = resolutions.find(resolution => resolution.name.toLowerCase() === fieldOperation.value.toString().trim().toLowerCase());
        if (resolution) {
            fieldOperation.value = { id: resolution.id.toString() };
        }
        else {
            throw new RequestValidationError([`Resolution not found: ${fieldOperation.value}`], 'resolution');
        }
        return fieldOperation;
    }
    processSecurity(fieldOperation) {
        if (fieldOperation.value.id) {
            return fieldOperation;
        }
        else {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
    }
    async processMultiOptionField(fieldOperation, customField) {
        const convertedValues = [];
        const promises = [];
        (fieldOperation.value || []).forEach((value, index) => {
            if (value === null) {
                convertedValues[index] = { id: value };
            }
            else if (value === null || value === void 0 ? void 0 : value.id) {
                convertedValues[index] = value;
            }
            else if (looksLikeNumber(value)) {
                convertedValues[index] = { id: value.toString() };
            }
            else {
                promises.push(this.cacheManager.getCustomFieldOptions(customField.schema.customId).then(options => {
                    const option = options.find(option => option.value.toLowerCase() === value.trim().toLowerCase());
                    if (option) {
                        convertedValues[index] = { id: option.id.toString() };
                    }
                    else {
                        return Promise.reject(new RequestValidationError([`Custom field option not found - Custom Field: ${customField.name}(${customField.schema.customId}) - Option: ${value}`], fieldOperation.name));
                    }
                    return Promise.resolve();
                }));
            }
        });
        await Promise.all(promises);
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    async processSingleOptionField(fieldOperation, customField) {
        const value = fieldOperation.value;
        if (value === null) {
            fieldOperation.value = value;
            return fieldOperation;
        }
        else if (value === null || value === void 0 ? void 0 : value.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(value)) {
            fieldOperation.value = { id: value.toString() };
            return fieldOperation;
        }
        else {
            const options = await this.cacheManager.getCustomFieldOptions((customField.schema.customId));
            const option = options.find(option => option.value.toLowerCase() === value.trim().toLowerCase());
            if (option) {
                fieldOperation.value = { id: option.id.toString() };
            }
            else {
                throw new RequestValidationError([`Custom field option not found - Custom Field: ${customField.name}(${customField.schema.customId}) - Option: ${value}`], fieldOperation.name);
            }
            return fieldOperation;
        }
    }
    processDateField(fieldOperation) {
        const value = fieldOperation.value;
        if (value instanceof Date) {
            fieldOperation.value = value.toISOString();
        }
        return Promise.resolve(fieldOperation);
    }
    processTextAreaField(fieldOperation) {
        const value = fieldOperation.value;
        if (typeof value === 'string') {
            fieldOperation.value = { version: 1, type: 'doc', content: [{ type: 'paragraph', content: [{ type: 'text', text: value }] }] };
        }
        return Promise.resolve(fieldOperation);
    }
    async processUserPickerField(fieldOperation) {
        const value = fieldOperation.value;
        const emailRegExp = /.+@.+/;
        if (value === null || value === void 0 ? void 0 : value.accountId) {
            return fieldOperation;
        }
        else if (value === null || value === void 0 ? void 0 : value.match(emailRegExp)) {
            fieldOperation.value = { accountId: await this.getAccountIdByEmail(value, fieldOperation.name) };
        }
        else {
            fieldOperation.value = { accountId: value };
        }
        return fieldOperation;
    }
    processGroupPickerField(fieldOperation) {
        const value = fieldOperation.value;
        if (value === null || value === void 0 ? void 0 : value.name) {
            return Promise.resolve(fieldOperation);
        }
        fieldOperation.value = { name: value };
        return Promise.resolve(fieldOperation);
    }
    async processMultiGroupPickerField(fieldOperation) {
        const convertedValues = [];
        (fieldOperation.value || []).forEach((value, index) => {
            if (value === null || value === void 0 ? void 0 : value.name) {
                convertedValues[index] = value;
            }
            else {
                convertedValues[index] = { name: value };
            }
        });
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    processURLField(fieldOperation) {
        const value = fieldOperation.value;
        if (value instanceof URL) {
            fieldOperation.value = value.toString();
        }
        return Promise.resolve(fieldOperation);
    }
    async processProjectPickerField(fieldOperation, customField) {
        const value = fieldOperation.value;
        if (value === null || value === void 0 ? void 0 : value.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(value)) {
            fieldOperation.value = { id: value.toString() };
            return fieldOperation;
        }
        else {
            const project = await this.cacheManager.getProject(value);
            if (project) {
                fieldOperation.value = { id: project.id.toString() };
            }
            else {
                throw new RequestValidationError([`Project not found - Custom Field: ${customField.name}(${customField.schema.customId}) - Project: ${value}`], fieldOperation.name);
            }
            return fieldOperation;
        }
    }
    processFieldWithID(fieldOperation) {
        const value = fieldOperation.value;
        if (value === null || value === void 0 ? void 0 : value.id) {
            return Promise.resolve(fieldOperation);
        }
        fieldOperation.value = { id: value };
        return Promise.resolve(fieldOperation);
    }
    //TODO: maybe find by version name if project is specified
    async processMultiVersionPickerField(fieldOperation) {
        const convertedValues = [];
        (fieldOperation.value || []).forEach((value, index) => {
            if (value === null || value === void 0 ? void 0 : value.id) {
                convertedValues[index] = value;
            }
            else {
                convertedValues[index] = { id: value };
            }
        });
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    async processMultiUserPickerField(fieldOperation) {
        const convertedValues = [];
        const promises = [];
        const emailRegExp = /.+@.+/;
        (fieldOperation.value || []).forEach((value, index) => {
            if (value === null || value === void 0 ? void 0 : value.accountId) {
                convertedValues[index] = value;
            }
            else if (value === null || value === void 0 ? void 0 : value.match(emailRegExp)) {
                promises.push(this.cacheManager.getAllUsers().then(users => {
                    const user = users.find(user => user.emailAddress && user.emailAddress.localeCompare(value.trim(), 'en', { sensitivity: 'base' }) === 0);
                    if (user) {
                        convertedValues[index] = { accountId: user.accountId };
                    }
                    else {
                        return Promise.reject(new UserNotFoundError(`User for multiuser picker field ${fieldOperation.name} not found by given email: ${value}`, fieldOperation.name));
                    }
                    return Promise.resolve();
                }));
            }
            else {
                convertedValues[index] = { accountId: value };
            }
        });
        await Promise.all(promises);
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    async getAccountIdByEmail(email, fieldName) {
        const users = await this.cacheManager.getAllUsers();
        const user = users.find(user => user.emailAddress && user.emailAddress.localeCompare(email.trim(), 'en', { sensitivity: 'base' }) === 0);
        if (user) {
            return user.accountId;
        }
        else {
            throw new UserNotFoundError(`User for ${fieldName} field not found by given email: ${email}`, fieldName);
        }
    }
    setSystemField(id, value, updateOperation) {
        if (id !== undefined && value !== undefined) {
            this.fieldOperations.push({
                id,
                name: id,
                value,
                updateOperation
            });
            return this.getNewInstance();
        }
        return this;
    }
    setCustomField(customFieldIdOrName, value, updateOperation) {
        if (customFieldIdOrName !== undefined && value !== undefined) {
            this.fieldOperations.push({
                name: customFieldIdOrName,
                value,
                updateOperation
            });
            return this.getNewInstance();
        }
        return this;
    }
    getNewInstance() {
        return new IssueBuilder(this.cacheManager, this.fieldOperations);
    }
}
