import { getIssueFields } from './handled-api/issue/field';
import { getIssueCustomFieldContexts } from './handled-api/issue/field/custom/context';
import { getIssueCustomFieldContextOptions } from './handled-api/issue/field/custom/context/option';
import { getProject } from './handled-api/project';
import { getIssueTypesForUser } from './handled-api/issue/type';
import { getIssuePriorities } from './handled-api/issue/priority';
import { getIssueResolutions } from './handled-api/issue/resolution';
import { injectBuilders } from './handled-api/common';
import { ErrorStrategyBuilder } from './builders/errorStrategy';
import { getUsers } from './handled-api/user';
export class CacheManager {
    constructor(connection, options) {
        this.connection = connection;
        this.options = options;
        this.projects = new Map(); // TODO: check if correct
        this.customFieldOptions = new Map(); // TODO: check if correct
        if (!this.options) {
            this.options = {};
        }
        if (this.options.errorStrategy === undefined) {
            options = {
                errorStrategy: ErrorStrategyBuilder.create()
                    .retryOnRateLimiting()
                    .build()
            };
        }
    }
    clearCache() {
        this.fields = undefined;
        this.issueTypes = undefined;
        this.priorities = undefined;
        this.resolutions = undefined;
        this.users = undefined;
        this.projects.clear();
        this.customFieldOptions.clear();
    }
    getAllUsers() {
        if (!this.users) {
            this.users = this.fetchAllUsers();
        }
        return this.users;
    }
    async fetchAllUsers() {
        var _a;
        async function* fetchUsers(connectionId, errorStrategy) {
            let queryMore = true;
            let startAt = 0;
            let maxResults = 50;
            while (queryMore) {
                const response = await getUsers(injectBuilders({
                    connectionId,
                    errorStrategy,
                    startAt,
                    maxResults
                }));
                yield* response;
                queryMore = response.length === maxResults;
                startAt += response.length;
            }
        }
        const users = [];
        for await (const value of fetchUsers(this.connection, (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy)) {
            users.push(value);
        }
        return users;
    }
    getAllFields() {
        if (!this.fields) {
            this.fields = getIssueFields(injectBuilders({
                connectionId: this.connection,
                errorStrategy: this.options.errorStrategy
            }));
        }
        return this.fields;
    }
    getAllIssueTypes() {
        if (!this.issueTypes) {
            this.issueTypes = getIssueTypesForUser(injectBuilders({
                connectionId: this.connection,
                errorStrategy: this.options.errorStrategy
            }));
        }
        return this.issueTypes;
    }
    getProject(projectKey) {
        if (!this.projects.has(projectKey)) {
            const project = getProject(injectBuilders({
                connectionId: this.connection,
                errorStrategy: this.options.errorStrategy,
                projectIdOrKey: projectKey
            }));
            this.projects.set(projectKey, project);
        }
        return this.projects.get(projectKey);
    }
    getCustomFieldOptions(fieldId) {
        if (!this.customFieldOptions.has(fieldId)) {
            this.customFieldOptions.set(fieldId, this.fetchCustomFieldOptions(fieldId));
        }
        return this.customFieldOptions.get(fieldId);
    }
    getAllPriorities() {
        if (!this.priorities) {
            this.priorities = getIssuePriorities(injectBuilders({
                connectionId: this.connection,
                errorStrategy: this.options.errorStrategy
            }));
        }
        return this.priorities;
    }
    getAllResolutions() {
        if (!this.resolutions) {
            this.resolutions = getIssueResolutions(injectBuilders({
                connectionId: this.connection,
                errorStrategy: this.options.errorStrategy
            }));
        }
        return this.resolutions;
    }
    async fetchCustomFieldContextId(fieldId) {
        const contexts = await getIssueCustomFieldContexts(injectBuilders({
            connectionId: this.connection,
            errorStrategy: this.options.errorStrategy,
            fieldId: `customfield_${fieldId}`
        }));
        if (!contexts || !contexts.values) {
            throw Error(`No context found for the custom field with id: ${fieldId}.`);
        }
        else if (contexts.values.length > 1) {
            throw Error(`There is more than one context for the custom field with id: ${fieldId}.`);
        }
        return +contexts.values[0].id;
    }
    async fetchCustomFieldOptions(fieldId) {
        var _a;
        const contextId = await this.fetchCustomFieldContextId(fieldId);
        async function* fetchOptions(connectionId, errorStrategy) {
            var _a;
            let queryMore = true;
            let startAt = 0;
            while (queryMore) {
                const response = await getIssueCustomFieldContextOptions(injectBuilders({
                    connectionId,
                    errorStrategy,
                    fieldId: `customfield_${fieldId}`,
                    contextId,
                    startAt
                }));
                const values = (_a = response.values) !== null && _a !== void 0 ? _a : [];
                yield* values;
                queryMore = !(response.isLast || values.length === 0);
                startAt += values.length;
            }
        }
        const options = [];
        for await (const value of fetchOptions(this.connection, (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy)) {
            options.push(value);
        }
        return options;
    }
}
