import { httpPost } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpGet } from "../raw-api/common";
import { httpPut } from "../raw-api/common";
import { httpDelete } from "../raw-api/common";
/**
* Creates a filter. The filter is shared according to the [default share scope](#api-rest-api-3-filter-post). The filter is not selected as a favorite.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-post
* @param options Request options.
*/
export function createFilter(options) {
    const { connectionId: instanceId, headers, body, expand } = options;
    const queryParams = { expand };
    return httpPost(instanceId, constructUrl(`/rest/api/3/filter`, queryParams), body, headers);
}
/**
* Returns the filters owned by the user. If `includeFavourites` is `true`, the user's visible favorite filters are also returned.

**[Permissions](#permissions) required:** Permission to access Jira, however, a favorite filters is only visible to the user where the filter is:

 *  owned by the user.
 *  shared with a group that the user is a member of.
 *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  shared with a public project.
 *  shared with the public.

For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-my-get
* @param options Request options.
*/
export function getMyFilters(options) {
    const { connectionId: instanceId, headers, expand, includeFavourites } = options;
    const queryParams = { expand, includeFavourites };
    return httpGet(instanceId, constructUrl(`/rest/api/3/filter/my`, queryParams), headers);
}
/**
* Returns a [paginated](#pagination) list of filters. Use this operation to get:

 *  specific filters, by defining `id` only.
 *  filters that match all of the specified attributes. For example, all filters for a user with a particular word in their name. When multiple attributes are specified only filters matching all attributes are returned.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, only the following filters that match the query parameters are returned:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-search-get
* @param options Request options.
*/
export function searchFilters(options) {
    const { connectionId: instanceId, headers, filterName, accountId, owner, groupname, projectId, id, orderBy, startAt, maxResults, expand } = options;
    const queryParams = { filterName, accountId, owner, groupname, projectId, id, orderBy, startAt, maxResults, expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/filter/search`, queryParams, true), headers);
}
/**
* Returns a filter.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, the filter is only returned where it is:

 *  owned by the user.
 *  shared with a group that the user is a member of.
 *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  shared with a public project.
 *  shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-get
* @param options Request options.
*/
export function getFilter(options) {
    const { connectionId: instanceId, headers, id, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/filter/${id}`, queryParams), headers);
}
/**
* Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.

**[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-put
* @param options Request options.
*/
export function updateFilter(options) {
    const { connectionId: instanceId, headers, id, body, expand } = options;
    const queryParams = { expand };
    return httpPut(instanceId, constructUrl(`/rest/api/3/filter/${id}`, queryParams), body, headers);
}
/**
* Delete a filter.

**[Permissions](#permissions) required:** Permission to access Jira, however filters can only be deleted by the creator of the filter or a user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-delete
* @param options Request options.
*/
export function deleteFilter(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpDelete(instanceId, `/rest/api/3/filter/${id}`, headers, true);
}
