import { httpGet } from "../../../raw-api/common";
import { httpPut } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
/**
* Returns the keys of all the properties of a comment.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-get
* @param options Request options.
*/
export function getIssueCommentPropertyKeys(options) {
    const { connectionId: instanceId, headers, commentId } = options;
    return httpGet(instanceId, `/rest/api/3/comment/${commentId}/properties`, headers);
}
/**
* Returns the value of a comment property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-get
* @param options Request options.
*/
export function getIssueCommentProperty(options) {
    const { connectionId: instanceId, headers, commentId, propertyKey } = options;
    return httpGet(instanceId, `/rest/api/3/comment/${commentId}/properties/${propertyKey}`, headers);
}
/**
* Creates or updates the value of a property for a comment. Use this resource to store custom data against a comment.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

**[Permissions](#permissions) required:** either of:

 *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on any comment.
 *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on a comment created by the user.

Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-put
* @param options Request options.
*/
export function setIssueCommentProperty(options) {
    const { connectionId: instanceId, headers, commentId, propertyKey, body } = options;
    return httpPut(instanceId, `/rest/api/3/comment/${commentId}/properties/${propertyKey}`, body, headers);
}
/**
* Deletes a comment property.

**[Permissions](#permissions) required:** either of:

 *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from any comment.
 *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from a comment created by the user.

Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-delete
* @param options Request options.
*/
export function deleteIssueCommentProperty(options) {
    const { connectionId: instanceId, headers, commentId, propertyKey } = options;
    return httpDelete(instanceId, `/rest/api/3/comment/${commentId}/properties/${propertyKey}`, headers, true);
}
