import { httpPost } from "../../../raw-api/common";
import { httpGet } from "../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPut } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
/**
* Creates a field configuration. The field configuration is created with the same field properties as the default configuration, with all the fields being optional.

This operation can only create configurations for use in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-post
* @param options Request options.
*/
export function createIssueFieldConfiguration(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/fieldconfiguration`, body, headers);
}
/**
* Returns a [paginated](#pagination) list of field configurations. The list can be for all field configurations or a subset determined by any combination of these criteria:

 *  a list of field configuration item IDs.
 *  whether the field configuration is a default.
 *  whether the field configuration name or description contains a query string.

Only field configurations used in company-managed (classic) projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-get
* @param options Request options.
*/
export function getIssueFieldConfigurations(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, id, isDefault, query } = options;
    const queryParams = { startAt, maxResults, id, isDefault, query };
    return httpGet(instanceId, constructUrl(`/rest/api/3/fieldconfiguration`, queryParams, true), headers);
}
/**
* Updates a field configuration. The name and the description provided in the request override the existing values.

This operation can only update configurations used in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-put
* @param options Request options.
*/
export function updateIssueFieldConfiguration(options) {
    const { connectionId: instanceId, headers, id, body } = options;
    return httpPut(instanceId, `/rest/api/3/fieldconfiguration/${id}`, body, headers);
}
/**
* Deletes a field configuration.

This operation can only delete configurations used in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-delete
* @param options Request options.
*/
export function deleteIssueFieldConfiguration(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpDelete(instanceId, `/rest/api/3/fieldconfiguration/${id}`, headers);
}
/**
* Returns a [paginated](#pagination) list of all fields for a configuration.

Only the fields from configurations used in company-managed (classic) projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-id-fields-get
* @param options Request options.
*/
export function getIssueFieldConfigurationItems(options) {
    const { connectionId: instanceId, headers, id, startAt, maxResults } = options;
    const queryParams = { startAt, maxResults };
    return httpGet(instanceId, constructUrl(`/rest/api/3/fieldconfiguration/${id}/fields`, queryParams), headers);
}
/**
* Returns a [paginated](#pagination) list of field configuration issue type items.

Only items used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfigurationscheme-mapping-get
* @param options Request options.
*/
export function getIssueFieldConfigurationIssueTypeItems(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, fieldConfigurationSchemeId } = options;
    const queryParams = { startAt, maxResults, fieldConfigurationSchemeId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/fieldconfigurationscheme/mapping`, queryParams, true), headers);
}
/**
* Returns a [paginated](#pagination) list of field configuration schemes.

Only field configuration schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-get
* @param options Request options.
*/
export function getIssueFieldConfigurationSchemes(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, id } = options;
    const queryParams = { startAt, maxResults, id };
    return httpGet(instanceId, constructUrl(`/rest/api/3/fieldconfigurationscheme`, queryParams, true), headers);
}
