import { httpGet } from "../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
import { httpPut } from "../../../raw-api/common";
/**
* Returns the remote issue links for an issue. When a remote issue link global ID is provided the record with that global ID is returned, otherwise all remote issue links are returned. Where a global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-get
* @param options Request options.
*/
export function getRemoteIssueLinks(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, globalId } = options;
    const queryParams = { globalId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/remotelink`, queryParams), headers);
}
/**
* Creates or updates a remote issue link for an issue.

If a `globalId` is provided and a remote issue link with that global ID is found it is updated. Any fields without values in the request are set to null. Otherwise, the remote issue link is created.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-post
* @param options Request options.
*/
export function createOrUpdateRemoteIssueLink(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, body } = options;
    return httpPost(instanceId, `/rest/api/3/issue/${issueIdOrKey}/remotelink`, body, headers);
}
/**
* Deletes the remote issue link from the issue using the link's global ID. Where the global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is implemented, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-delete
* @param options Request options.
*/
export function deleteRemoteIssueLinkByGlobalId(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, globalId } = options;
    const queryParams = { globalId };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/remotelink`, queryParams), headers, true);
}
/**
* Returns a remote issue link for an issue.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-get
* @param options Request options.
*/
export function getRemoteIssueLink(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, linkId } = options;
    return httpGet(instanceId, `/rest/api/3/issue/${issueIdOrKey}/remotelink/${linkId}`, headers);
}
/**
* Updates a remote issue link for an issue.

Note: Fields without values in the request are set to null.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-put
* @param options Request options.
*/
export function updateRemoteIssueLink(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, linkId, body } = options;
    return httpPut(instanceId, `/rest/api/3/issue/${issueIdOrKey}/remotelink/${linkId}`, body, headers);
}
/**
* Deletes a remote issue link from an issue.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects*, *Edit issues*, and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-delete
* @param options Request options.
*/
export function deleteRemoteIssueLink(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, linkId } = options;
    return httpDelete(instanceId, `/rest/api/3/issue/${issueIdOrKey}/remotelink/${linkId}`, headers, true);
}
