import { httpGet } from "../../raw-api/common";
import { httpPut } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns the URLs and keys of an issue's properties.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Property details are only returned where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-get
* @param options Request options.
*/
export function getIssuePropertyKeys(options) {
    const { connectionId: instanceId, headers, issueIdOrKey } = options;
    return httpGet(instanceId, `/rest/api/3/issue/${issueIdOrKey}/properties`, headers);
}
/**
* Returns the key and value of an issue's property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-get
* @param options Request options.
*/
export function getIssueProperty(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, propertyKey } = options;
    return httpGet(instanceId, `/rest/api/3/issue/${issueIdOrKey}/properties/${propertyKey}`, headers);
}
/**
* Sets the value of an issue's property. Use this resource to store custom data against an issue.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-put
* @param options Request options.
*/
export function setIssueProperty(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, propertyKey, body } = options;
    return httpPut(instanceId, `/rest/api/3/issue/${issueIdOrKey}/properties/${propertyKey}`, body, headers);
}
/**
* Deletes an issue's property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-delete
* @param options Request options.
*/
export function deleteIssueProperty(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, propertyKey } = options;
    return httpDelete(instanceId, `/rest/api/3/issue/${issueIdOrKey}/properties/${propertyKey}`, headers, true);
}
