import { httpGet } from "../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../../raw-api/common";
import { httpPut } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
/**
* Returns a [paginated](#pagination) list of issue type schemes.

Only issue type schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-get
* @param options Request options.
*/
export function getIssueTypeSchemes(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, id } = options;
    const queryParams = { startAt, maxResults, id };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issuetypescheme`, queryParams, true), headers);
}
/**
* Creates an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-post
* @param options Request options.
*/
export function createIssueTypeScheme(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/issuetypescheme`, body, headers);
}
/**
* Returns a [paginated](#pagination) list of issue type scheme items.

Only issue type scheme items used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-mapping-get
* @param options Request options.
*/
export function getIssueTypeSchemeItems(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, issueTypeSchemeId } = options;
    const queryParams = { startAt, maxResults, issueTypeSchemeId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issuetypescheme/mapping`, queryParams, true), headers);
}
/**
* Returns a [paginated](#pagination) list of issue type schemes and, for each issue type scheme, a list of the projects that use it.

Only issue type schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-project-get
* @param options Request options.
*/
export function getIssueTypeSchemesForProjects(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, projectId } = options;
    const queryParams = { startAt, maxResults, projectId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issuetypescheme/project`, queryParams, true), headers);
}
/**
* Assigns an issue type scheme to a project.

If any issues in the project are assigned issue types not present in the new scheme, the operation will fail. To complete the assignment those issues must be updated to use issue types in the new scheme.

Issue type schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-put
* @param options Request options.
*/
export function assignIssueTypeSchemeToProject(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPut(instanceId, `/rest/api/3/issuetypescheme/project`, body, headers);
}
/**
* Adds issue types to an issue type scheme.

The added issue types are appended to the issue types list.

If any of the issue types exist in the issue type scheme, the operation fails and no issue types are added.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-put
* @param options Request options.
*/
export function addIssueTypesToIssueTypeScheme(options) {
    const { connectionId: instanceId, headers, issueTypeSchemeId, body } = options;
    return httpPut(instanceId, `/rest/api/3/issuetypescheme/${issueTypeSchemeId}/issuetype`, body, headers);
}
/**
* Updates an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-put
* @param options Request options.
*/
export function updateIssueTypeScheme(options) {
    const { connectionId: instanceId, headers, issueTypeSchemeId, body } = options;
    return httpPut(instanceId, `/rest/api/3/issuetypescheme/${issueTypeSchemeId}`, body, headers);
}
/**
* Deletes an issue type scheme.

Only issue type schemes used in classic projects can be deleted.

Any projects assigned to the scheme are reassigned to the default issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-delete
* @param options Request options.
*/
export function deleteIssueTypeScheme(options) {
    const { connectionId: instanceId, headers, issueTypeSchemeId } = options;
    return httpDelete(instanceId, `/rest/api/3/issuetypescheme/${issueTypeSchemeId}`, headers);
}
/**
* Changes the order of issue types in an issue type scheme.

The request body parameters must meet the following requirements:

 *  all of the issue types must belong to the issue type scheme.
 *  either `after` or `position` must be provided.
 *  the issue type in `after` must not be in the issue type list.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-move-put
* @param options Request options.
*/
export function changeIssueTypeSchemeIssueTypesOrder(options) {
    const { connectionId: instanceId, headers, issueTypeSchemeId, body } = options;
    return httpPut(instanceId, `/rest/api/3/issuetypescheme/${issueTypeSchemeId}/issuetype/move`, body, headers);
}
/**
* Removes an issue type from an issue type scheme.

This operation cannot remove:

 *  any issue type used by issues.
 *  any issue types from the default issue type scheme.
 *  the last standard issue type from an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-issuetypeid-delete
* @param options Request options.
*/
export function removeIssueTypesFromIssueTypeScheme(options) {
    const { connectionId: instanceId, headers, issueTypeSchemeId, issueTypeId } = options;
    return httpDelete(instanceId, `/rest/api/3/issuetypescheme/${issueTypeSchemeId}/issuetype/${issueTypeId}`, headers);
}
