import { httpGet } from "../../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../../../raw-api/common";
import { httpPut } from "../../../../raw-api/common";
import { httpDelete } from "../../../../raw-api/common";
/**
* Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.

Only company-managed projects associated with an issue type screen scheme are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-project-get
* @param options Request options.
*/
export function getIssueTypeScreenSchemeProjects(options) {
    const { connectionId: instanceId, headers, issueTypeScreenSchemeId, startAt, maxResults } = options;
    const queryParams = { startAt, maxResults };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issuetypescreenscheme/${issueTypeScreenSchemeId}/project`, queryParams), headers);
}
/**
* Returns a [paginated](#pagination) list of issue type screen schemes.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-get
* @param options Request options.
*/
export function getIssueTypeScreenSchemes(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, id } = options;
    const queryParams = { startAt, maxResults, id };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issuetypescreenscheme`, queryParams, true), headers);
}
/**
* Creates an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-post
* @param options Request options.
*/
export function createIssueTypeScreenScheme(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/issuetypescreenscheme`, body, headers);
}
/**
* Returns a [paginated](#pagination) list of issue type screen scheme items.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-mapping-get
* @param options Request options.
*/
export function getIssueTypeScreenSchemeItems(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, issueTypeScreenSchemeId } = options;
    const queryParams = { startAt, maxResults, issueTypeScreenSchemeId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issuetypescreenscheme/mapping`, queryParams, true), headers);
}
/**
* Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-project-get
* @param options Request options.
*/
export function getIssueTypeScreenSchemesForProjects(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, projectId } = options;
    const queryParams = { startAt, maxResults, projectId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issuetypescreenscheme/project`, queryParams, true), headers);
}
/**
* Assigns an issue type screen scheme to a project.

Issue type screen schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-put
* @param options Request options.
*/
export function assignIssueTypeScreenSchemeToProject(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPut(instanceId, `/rest/api/3/issuetypescreenscheme/project`, body, headers);
}
/**
* Updates an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-put
* @param options Request options.
*/
export function updateIssueTypeScreenScheme(options) {
    const { connectionId: instanceId, headers, issueTypeScreenSchemeId, body } = options;
    return httpPut(instanceId, `/rest/api/3/issuetypescreenscheme/${issueTypeScreenSchemeId}`, body, headers);
}
/**
* Deletes an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-delete
* @param options Request options.
*/
export function deleteIssueTypeScreenScheme(options) {
    const { connectionId: instanceId, headers, issueTypeScreenSchemeId } = options;
    return httpDelete(instanceId, `/rest/api/3/issuetypescreenscheme/${issueTypeScreenSchemeId}`, headers);
}
/**
* Appends issue type to screen scheme mappings to an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-put
* @param options Request options.
*/
export function appendMappingsToIssueTypeScreenScheme(options) {
    const { connectionId: instanceId, headers, issueTypeScreenSchemeId, body } = options;
    return httpPut(instanceId, `/rest/api/3/issuetypescreenscheme/${issueTypeScreenSchemeId}/mapping`, body, headers);
}
/**
* Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-default-put
* @param options Request options.
*/
export function updateDefaultIssueTypeScreenScheme(options) {
    const { connectionId: instanceId, headers, issueTypeScreenSchemeId, body } = options;
    return httpPut(instanceId, `/rest/api/3/issuetypescreenscheme/${issueTypeScreenSchemeId}/mapping/default`, body, headers);
}
/**
* Removes issue type to screen scheme mappings from an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-remove-post
* @param options Request options.
*/
export function removeMappingsFromIssueTypeScreenScheme(options) {
    const { connectionId: instanceId, headers, issueTypeScreenSchemeId, body } = options;
    return httpPost(instanceId, `/rest/api/3/issuetypescreenscheme/${issueTypeScreenSchemeId}/mapping/remove`, body, headers);
}
