import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../raw-api/common";
import { httpPut } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns worklogs for an issue, starting from the oldest worklog or from the worklog started on or after a date and time.

Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Workloads are only returned where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-get
* @param options Request options.
*/
export function getIssueWorklogs(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, startAt, maxResults, startedAfter, startedBefore, expand } = options;
    const queryParams = { startAt, maxResults, startedAfter, startedBefore, expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/worklog`, queryParams), headers);
}
/**
* Adds a worklog to an issue.

Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Work on issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-post
* @param options Request options.
*/
export function addIssueWorklog(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, body, notifyUsers, adjustEstimate, newEstimate, reduceBy, expand, overrideEditableFlag } = options;
    const queryParams = { notifyUsers, adjustEstimate, newEstimate, reduceBy, expand, overrideEditableFlag };
    return httpPost(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/worklog`, queryParams), body, headers);
}
/**
* Returns a worklog.

Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-get
* @param options Request options.
*/
export function getIssueWorklog(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, id, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/worklog/${id}`, queryParams), headers);
}
/**
* Updates a worklog.

Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-put
* @param options Request options.
*/
export function updateIssueWorklog(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, id, body, notifyUsers, adjustEstimate, newEstimate, expand, overrideEditableFlag } = options;
    const queryParams = { notifyUsers, adjustEstimate, newEstimate, expand, overrideEditableFlag };
    return httpPut(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/worklog/${id}`, queryParams), body, headers);
}
/**
* Deletes a worklog from an issue.

Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  *Delete all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any worklog or *Delete own worklogs* to delete worklogs created by the user,
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-delete
* @param options Request options.
*/
export function deleteIssueWorklog(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, id, notifyUsers, adjustEstimate, newEstimate, increaseBy, overrideEditableFlag } = options;
    const queryParams = { notifyUsers, adjustEstimate, newEstimate, increaseBy, overrideEditableFlag };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/worklog/${id}`, queryParams), headers, true);
}
/**
* Returns a list of IDs and delete timestamps for worklogs deleted after a date and time.

This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.

This resource does not return worklogs deleted during the minute preceding the request.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-deleted-get
* @param options Request options.
*/
export function getDeletedIssueWorklogIds(options) {
    const { connectionId: instanceId, headers, since } = options;
    const queryParams = { since };
    return httpGet(instanceId, constructUrl(`/rest/api/3/worklog/deleted`, queryParams), headers);
}
/**
* Returns worklog details for a list of worklog IDs.

The returned list of worklogs is limited to 1000 items.

**[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:

 *  the worklog is set as *Viewable by All Users*.
 *  the user is a member of a project role or group with permission to view the worklog.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-list-post
* @param options Request options.
*/
export function getIssueWorklogsFromIds(options) {
    const { connectionId: instanceId, headers, body, expand } = options;
    const queryParams = { expand };
    return httpPost(instanceId, constructUrl(`/rest/api/3/worklog/list`, queryParams), body, headers);
}
/**
* Returns a list of IDs and update timestamps for worklogs updated after a date and time.

This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.

This resource does not return worklogs updated during the minute preceding the request.

**[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:

 *  the worklog is set as *Viewable by All Users*.
 *  the user is a member of a project role or group with permission to view the worklog.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-updated-get
* @param options Request options.
*/
export function getUpdatedIssueWorklogIds(options) {
    const { connectionId: instanceId, headers, since, expand } = options;
    const queryParams = { since, expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/worklog/updated`, queryParams), headers);
}
