import { httpGet } from "../../../raw-api/common";
import { httpPut } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
/**
* Returns the keys of all properties for a worklog.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-get
* @param options Request options.
*/
export function getWorklogPropertyKeys(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, worklogId } = options;
    return httpGet(instanceId, `/rest/api/3/issue/${issueIdOrKey}/worklog/${worklogId}/properties`, headers);
}
/**
* Returns the value of a worklog property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-get
* @param options Request options.
*/
export function getWorklogProperty(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, worklogId, propertyKey } = options;
    return httpGet(instanceId, `/rest/api/3/issue/${issueIdOrKey}/worklog/${worklogId}/properties/${propertyKey}`, headers);
}
/**
* Sets the value of a worklog property. Use this operation to store custom data against the worklog.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-put
* @param options Request options.
*/
export function setWorklogProperty(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, worklogId, propertyKey, body } = options;
    return httpPut(instanceId, `/rest/api/3/issue/${issueIdOrKey}/worklog/${worklogId}/properties/${propertyKey}`, body, headers);
}
/**
* Deletes a worklog property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-delete
* @param options Request options.
*/
export function deleteWorklogProperty(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, worklogId, propertyKey } = options;
    return httpDelete(instanceId, `/rest/api/3/issue/${issueIdOrKey}/worklog/${worklogId}/properties/${propertyKey}`, headers, true);
}
