import { httpPost } from "../../raw-api/common";
import { httpGet } from "../../raw-api/common";
import { httpPut } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
* Creates a component. Use components to provide containers for issues within a project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-post
* @param options Request options.
*/
export function createProjectComponent(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/component`, body, headers);
}
/**
* Returns a component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-get
* @param options Request options.
*/
export function getProjectComponent(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/3/component/${id}`, headers);
}
/**
* Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-put
* @param options Request options.
*/
export function updateProjectComponent(options) {
    const { connectionId: instanceId, headers, id, body } = options;
    return httpPut(instanceId, `/rest/api/3/component/${id}`, body, headers);
}
/**
* Deletes a component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-delete
* @param options Request options.
*/
export function deleteProjectComponent(options) {
    const { connectionId: instanceId, headers, id, moveIssuesTo } = options;
    const queryParams = { moveIssuesTo };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/component/${id}`, queryParams), headers, true);
}
/**
* Returns the counts of issues assigned to the component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-relatedIssueCounts-get
* @param options Request options.
*/
export function getProjectComponentIssueCount(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/3/component/${id}/relatedIssueCounts`, headers);
}
/**
* Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-component-get
* @param options Request options.
*/
export function getProjectComponentsPaginated(options) {
    const { connectionId: instanceId, headers, projectIdOrKey, startAt, maxResults, orderBy, query } = options;
    const queryParams = { startAt, maxResults, orderBy, query };
    return httpGet(instanceId, constructUrl(`/rest/api/3/project/${projectIdOrKey}/component`, queryParams), headers);
}
/**
* Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-components-get
* @param options Request options.
*/
export function getProjectComponents(options) {
    const { connectionId: instanceId, headers, projectIdOrKey } = options;
    return httpGet(instanceId, `/rest/api/3/project/${projectIdOrKey}/components`, headers);
}
