import { httpGet } from "../../raw-api/common";
import { httpPut } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns all [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys for the project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-get
* @param options Request options.
*/
export function getProjectPropertyKeys(options) {
    const { connectionId: instanceId, headers, projectIdOrKey } = options;
    return httpGet(instanceId, `/rest/api/3/project/${projectIdOrKey}/properties`, headers);
}
/**
* Returns the value of a [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-get
* @param options Request options.
*/
export function getProjectProperty(options) {
    const { connectionId: instanceId, headers, projectIdOrKey, propertyKey } = options;
    return httpGet(instanceId, `/rest/api/3/project/${projectIdOrKey}/properties/${propertyKey}`, headers);
}
/**
* Sets the value of the [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). You can use project properties to store custom data against the project.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the property is created.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-put
* @param options Request options.
*/
export function setProjectProperty(options) {
    const { connectionId: instanceId, headers, projectIdOrKey, propertyKey, body } = options;
    return httpPut(instanceId, `/rest/api/3/project/${projectIdOrKey}/properties/${propertyKey}`, body, headers);
}
/**
* Deletes the [property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) from a project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-delete
* @param options Request options.
*/
export function deleteProjectProperty(options) {
    const { connectionId: instanceId, headers, projectIdOrKey, propertyKey } = options;
    return httpDelete(instanceId, `/rest/api/3/project/${projectIdOrKey}/properties/${propertyKey}`, headers, true);
}
