import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../raw-api/common";
import { httpPut } from "../raw-api/common";
import { httpDelete } from "../raw-api/common";
/**
* Returns a [paginated](#pagination) list of the screens a field is used in.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-field-fieldid-screens-get
* @param options Request options.
*/
export function getScreensForField(options) {
    const { connectionId: instanceId, headers, fieldId, startAt, maxResults, expand } = options;
    const queryParams = { startAt, maxResults, expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/field/${fieldId}/screens`, queryParams), headers);
}
/**
* Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-get
* @param options Request options.
*/
export function getScreens(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, id } = options;
    const queryParams = { startAt, maxResults, id };
    return httpGet(instanceId, constructUrl(`/rest/api/3/screens`, queryParams, true), headers);
}
/**
* Creates a screen with a default field tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-post
* @param options Request options.
*/
export function createScreen(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/screens`, body, headers);
}
/**
* Adds a field to the default tab of the default screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-addtodefault-fieldid-post
* @param options Request options.
*/
export function addFieldToDefaultScreen(options) {
    const { connectionId: instanceId, headers, fieldId } = options;
    return httpPost(instanceId, `/rest/api/3/screens/addToDefault/${fieldId}`, undefined, headers);
}
/**
* Returns the fields that can be added to a tab on a screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-availablefields-get
* @param options Request options.
*/
export function getAvailableScreenFields(options) {
    const { connectionId: instanceId, headers, screenId } = options;
    return httpGet(instanceId, `/rest/api/3/screens/${screenId}/availableFields`, headers);
}
/**
* Updates a screen. Only screens used in classic projects can be updated.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-put
* @param options Request options.
*/
export function updateScreen(options) {
    const { connectionId: instanceId, headers, screenId, body } = options;
    return httpPut(instanceId, `/rest/api/3/screens/${screenId}`, body, headers);
}
/**
* Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.

Only screens used in classic projects can be deleted.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-delete
* @param options Request options.
*/
export function deleteScreen(options) {
    const { connectionId: instanceId, headers, screenId } = options;
    return httpDelete(instanceId, `/rest/api/3/screens/${screenId}`, headers, true);
}
