import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPut } from "../raw-api/common";
import { httpDelete } from "../raw-api/common";
import { httpPost } from "../raw-api/common";
/**
* Returns the default [issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If `accountId` is not passed in the request, the calling user's details are returned.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLgl), to get the column details for any user.
 *  Permission to access Jira, to get the calling user's column details.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-get
* @param options Request options.
*/
export function getUserDefaultColumns(options) {
    const { connectionId: instanceId, headers, accountId } = options;
    const queryParams = { accountId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/user/columns`, queryParams), headers);
}
/**
* Sets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If an account ID is not passed, the calling user's default columns are set. If no column details are sent, then all default columns are removed.

The parameters for this resource are expressed as HTML form data. For example, in curl:

`curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/user/columns?accountId=5b10ac8d82e05b22cc7d4ef5'`

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
 *  Permission to access Jira, to set the calling user's columns.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-put
* @param options Request options.
*/
export function setUserDefaultColumns(options) {
    const { connectionId: instanceId, headers, body, accountId } = options;
    const queryParams = { accountId };
    return httpPut(instanceId, constructUrl(`/rest/api/3/user/columns`, queryParams), body, headers);
}
/**
* Resets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user to the system default. If `accountId` is not passed, the calling user's default columns are reset.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
 *  Permission to access Jira, to set the calling user's columns.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-delete
* @param options Request options.
*/
export function resetUserDefaultColumns(options) {
    const { connectionId: instanceId, headers, accountId } = options;
    const queryParams = { accountId };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/user/columns`, queryParams), headers, true);
}
/**
* Returns a user.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-get
* @param options Request options.
*/
export function getUser(options) {
    const { connectionId: instanceId, headers, accountId, username, key, expand } = options;
    const queryParams = { accountId, username, key, expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/user`, queryParams), headers);
}
/**
* Creates a user. This resource is retained for legacy compatibility. As soon as a more suitable alternative is available this resource will be deprecated.

If the user exists and has access to Jira, the operation returns a 201 status. If the user exists but does not have access to Jira, the operation returns a 400 status.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-post
* @param options Request options.
*/
export function createUser(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/user`, body, headers);
}
/**
* Deletes a user.

**[Permissions](#permissions) required:** Site administration (that is, membership of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-delete
* @param options Request options.
*/
export function deleteUser(options) {
    const { connectionId: instanceId, headers, accountId, username, key } = options;
    const queryParams = { accountId, username, key };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/user`, queryParams), headers, true);
}
/**
* Returns the account IDs for the users specified in the `key` or `username` parameters. Note that multiple `key` or `username` parameters can be specified.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-bulk-migration-get
* @param options Request options.
*/
export function getAccountIdsForUsers(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, username, key } = options;
    const queryParams = { startAt, maxResults, username, key };
    return httpGet(instanceId, constructUrl(`/rest/api/3/user/bulk/migration`, queryParams, true), headers);
}
/**
 * Returns a user's email address. This API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
 * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-email-get
 * @param options Request options.
 */
export function getUserEmail(options) {
    const { connectionId: instanceId, headers, accountId } = options;
    const queryParams = { accountId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/user/email`, queryParams), headers);
}
/**
* Returns the groups to which a user belongs.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-groups-get
* @param options Request options.
*/
export function getUserGroups(options) {
    const { connectionId: instanceId, headers, accountId, username, key } = options;
    const queryParams = { accountId, username, key };
    return httpGet(instanceId, constructUrl(`/rest/api/3/user/groups`, queryParams), headers);
}
/**
* Returns a list of all (active and inactive) users.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-users-search-get
* @param options Request options.
*/
export function getUsers(options) {
    const { connectionId: instanceId, headers, startAt, maxResults } = options;
    const queryParams = { startAt, maxResults };
    return httpGet(instanceId, constructUrl(`/rest/api/3/users/search`, queryParams), headers);
}
