import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../raw-api/common";
import { httpPut } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns a [paginated](#pagination) list of all workflow schemes, not including draft workflow schemes.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-workflowscheme-get
* @param options Request options.
*/
export function getWorkflowSchemes(options) {
    const { connectionId: instanceId, headers, startAt, maxResults } = options;
    const queryParams = { startAt, maxResults };
    return httpGet(instanceId, constructUrl(`/rest/api/3/workflowscheme`, queryParams), headers);
}
/**
* Creates a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-post
* @param options Request options.
*/
export function createWorkflowScheme(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/workflowscheme`, body, headers);
}
/**
* Returns a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-get
* @param options Request options.
*/
export function getWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, returnDraftIfExists } = options;
    const queryParams = { returnDraftIfExists };
    return httpGet(instanceId, constructUrl(`/rest/api/3/workflowscheme/${id}`, queryParams), headers);
}
/**
* Updates a workflow scheme, including the name, default workflow, issue type to project mappings, and more. If the workflow scheme is active (that is, being used by at least one project), then a draft workflow scheme is created or updated instead, provided that `updateDraftIfNeeded` is set to `true`.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-put
* @param options Request options.
*/
export function updateWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, body } = options;
    return httpPut(instanceId, `/rest/api/3/workflowscheme/${id}`, body, headers);
}
/**
* Deletes a workflow scheme. Note that a workflow scheme cannot be deleted if it is active (that is, being used by at least one project).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-delete
* @param options Request options.
*/
export function deleteWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpDelete(instanceId, `/rest/api/3/workflowscheme/${id}`, headers, true);
}
/**
* Returns the issue type-workflow mapping for an issue type in a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-get
* @param options Request options.
*/
export function getWorkflowForIssueTypeInWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, issueType, returnDraftIfExists } = options;
    const queryParams = { returnDraftIfExists };
    return httpGet(instanceId, constructUrl(`/rest/api/3/workflowscheme/${id}/issuetype/${issueType}`, queryParams), headers);
}
/**
* Sets the workflow for an issue type in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new issue type-workflow mapping. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-put
* @param options Request options.
*/
export function setWorkflowForIssueTypeInWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, issueType, body } = options;
    return httpPut(instanceId, `/rest/api/3/workflowscheme/${id}/issuetype/${issueType}`, body, headers);
}
/**
* Deletes the issue type-workflow mapping for an issue type in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the issue type-workflow mapping deleted. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-delete
* @param options Request options.
*/
export function deleteWorkflowForIssueTypeInWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, issueType, updateDraftIfNeeded } = options;
    const queryParams = { updateDraftIfNeeded };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/workflowscheme/${id}/issuetype/${issueType}`, queryParams), headers);
}
/**
* Returns the workflow-issue type mappings for a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-get
* @param options Request options.
*/
export function getIssueTypesForWorkflowInWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, workflowName, returnDraftIfExists } = options;
    const queryParams = { workflowName, returnDraftIfExists };
    return httpGet(instanceId, constructUrl(`/rest/api/3/workflowscheme/${id}/workflow`, queryParams), headers);
}
/**
* Sets the issue types for a workflow in a workflow scheme. The workflow can also be set as the default workflow for the workflow scheme. Unmapped issues types are mapped to the default workflow.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new workflow-issue types mappings. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-put
* @param options Request options.
*/
export function setIssueTypesForWorkflowInWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, body, workflowName } = options;
    const queryParams = { workflowName };
    return httpPut(instanceId, constructUrl(`/rest/api/3/workflowscheme/${id}/workflow`, queryParams), body, headers);
}
/**
* Deletes the workflow-issue type mapping for a workflow in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the workflow-issue type mapping deleted. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-delete
* @param options Request options.
*/
export function deleteIssueTypesForWorkflowInWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, workflowName, updateDraftIfNeeded } = options;
    const queryParams = { workflowName, updateDraftIfNeeded };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/workflowscheme/${id}/workflow`, queryParams), headers, true);
}
/**
* Returns the default workflow for a workflow scheme. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-get
* @param options Request options.
*/
export function getDefaultWorkflowForWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, returnDraftIfExists } = options;
    const queryParams = { returnDraftIfExists };
    return httpGet(instanceId, constructUrl(`/rest/api/3/workflowscheme/${id}/default`, queryParams), headers);
}
/**
* Sets the default workflow for a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request object and a draft workflow scheme is created or updated with the new default workflow. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-put
* @param options Request options.
*/
export function updateDefaultWorkflowForWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, body } = options;
    return httpPut(instanceId, `/rest/api/3/workflowscheme/${id}/default`, body, headers);
}
/**
* Resets the default workflow for a workflow scheme. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the default workflow reset. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-delete
* @param options Request options.
*/
export function deleteDefaultWorkflowForWorkflowScheme(options) {
    const { connectionId: instanceId, headers, id, updateDraftIfNeeded } = options;
    const queryParams = { updateDraftIfNeeded };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/workflowscheme/${id}/default`, queryParams), headers);
}
