/// <reference types="runtime" />
import { Issue } from "./types/issue";
import { IssueHelper } from "./helper/issue";
import { ManagedIssue } from "./common";
import { Dashboard } from "./types/dashboard";
import { Application } from "./types/application";
import { User } from "./types/user";
import { Instance } from "./types/instance";
import { Project } from "./types/project";
import { Filter } from "./types/filter";
import { Group } from "./types/group";
import { GroupAndUserPicker } from "./types/groupAndUserPicker";
import { Jql } from "./types/jql";
import { Label } from "./types/label";
import { Permission } from "./types/permission";
import { Myself } from "./types/myself";
import { Workflow } from "./types/workflow";
import { Screen } from "./types/screen";
import { Avatar } from "./types/avatar";
import { BuildersGroup } from "./common";
import { AssistedErrorStrategyFunction, AssistedErrorStrategyOption, ErrorStrategyHandlers } from "./handled-api/common";
interface ConnectionOptions extends AssistedErrorStrategyOption {
}
export declare namespace JiraCloudConnection {
    function connect(connection: string, options?: ConnectionOptions): JiraCloudInstance;
}
export declare class JiraCloudInstance {
    Builders: BuildersGroup;
    protected issueHelper: IssueHelper;
    All: AllGroup;
    private connection;
    Issue: IssueGroup;
    Dashboard: DashboardGroup;
    Application: ApplicationGroup;
    User: UserGroup;
    Instance: InstanceGroup;
    Project: ProjectGroup;
    Filter: FilterGroup;
    Group: GroupGroup;
    GroupAndUserPicker: GroupAndUserPickerGroup;
    Jql: JqlGroup;
    Label: LabelGroup;
    Permission: PermissionGroup;
    Myself: MyselfGroup;
    Workflow: WorkflowGroup;
    Screen: ScreenGroup;
    Avatar: AvatarGroup;
    constructor(connection: string, options?: ConnectionOptions);
    /**
     * Performs fetch call using managed connection.
     */
    fetch<T = any>(url: string, options?: RequestInit): Promise<Response<T>>;
    /**
     * Set global error strategy.
     */
    setGlobalErrorStrategy(errorStrategy?: ErrorStrategyHandlers | AssistedErrorStrategyFunction | null): void;
}
declare class BaseGroup {
    protected connection: string;
    protected options: ConnectionOptions;
    constructor(connection: string, options: ConnectionOptions);
    protected getBuildOptions(options: any): any;
}
declare class IssueGroup extends BaseGroup {
    private issueHelper;
    Type: IssueTypeGroup;
    Field: IssueFieldGroup;
    Worklog: IssueWorklogGroup;
    Attachment: IssueAttachmentGroup;
    Comment: IssueCommentGroup;
    Metadata: IssueMetadataGroup;
    Property: IssuePropertyGroup;
    Link: IssueLinkGroup;
    Transition: IssueTransitionGroup;
    Vote: IssueVoteGroup;
    Watcher: IssueWatcherGroup;
    Search: IssueSearchGroup;
    Priority: IssuePriorityGroup;
    Resolution: IssueResolutionGroup;
    Security: IssueSecurityGroup;
    Notification: IssueNotificationGroup;
    Navigator: IssueNavigatorGroup;
    constructor(connection: string, options: ConnectionOptions, issueHelper: IssueHelper);
    /**
  * Creates an issue or, where the option to create subtasks is enabled in Jira, a subtask. A transition may be applied, to move the issue or subtask to a workflow step other than the default start step, and issue properties set.
  
  The content of the issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issue's create screen. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Creating a subtask differs from creating an issue as follows:
  
   *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
   *  `parent` must contain the ID or key of the parent issue.
  
  In a next-gen project any issue may be made a child providing that the parent and child are members of the same project. In a classic project the parent field is only valid for subtasks.
  
  **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which the issue or subtask is created.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-post
  * @param options Request options.
  */
    createIssue<T = Issue.CreateIssue.Response.OK>(options: Issue.CreateIssue.Options): Promise<import("./definitions/CreatedIssueAsResponse").CreatedIssueAsResponse>;
    /**
  * Creates issues and, where the option to create subtasks is enabled in Jira, subtasks. Transitions may be applied, to move the issues or subtasks to a workflow step other than the default start step, and issue properties set.
  
  The content of each issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issues' create screens. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Creating a subtask differs from creating an issue as follows:
  
   *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
   *  `parent` the must contain the ID or key of the parent issue.
  
  **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which each issue or subtask is created.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-bulk-post
  * @param options Request options.
  */
    createIssues<T = Issue.CreateIssues.Response.OK>(options: Issue.CreateIssues.Options): Promise<import("./definitions/CreatedIssuesAsResponse").CreatedIssuesAsResponse>;
    /**
  * Returns the details for an issue.
  
  The issue is identified by its ID or key, however, if the identifier doesn't match an issue, a case-insensitive search and check for moved issues is performed. If a matching issue is found its details are returned, a 302 or other redirect is **not** returned. The issue key returned in the response is the key of the issue found.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-get
  * @param options Request options.
  */
    getIssue<T = ManagedIssue.Read.Response>(options: Issue.GetIssue.Options): Promise<ManagedIssue.Read.Response | T>;
    /**
  * Edits an issue. A transition may be applied and issue properties updated as part of the edit.
  
  The edits to the issue's fields are defined using `update` and `fields`. The fields that can be edited are determined using [ Get edit issue metadata](#api-rest-api-3-issue-issueIdOrKey-editmeta-get).
  
  The parent field may be set by key or ID. For standard issue types, the parent may be removed by setting `update.parent.set.none` to *true*. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Connect app users with admin permissions (from user permissions and app scopes) can override the screen security configuration using `overrideScreenSecurity` and `overrideEditableFlag`.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-put
  * @param options Request options.
  */
    editIssue<T = undefined>(options: Issue.EditIssue.Options): Promise<Issue.EditIssue.Response.OK>;
    /**
  * Deletes an issue.
  
  An issue cannot be deleted if it has one or more subtasks. To delete an issue with subtasks, set `deleteSubtasks`. This causes the issue's subtasks to be deleted with the issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Delete issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-delete
  * @param options Request options.
  */
    deleteIssue<T = Issue.DeleteIssue.Response.OK>(options: Issue.DeleteIssue.Options): Promise<undefined>;
    /**
  * Assigns an issue to a user. Use this operation when the calling user does not have the *Edit Issues* permission but has the *Assign issue* permission for the project that the issue is in.
  
  If `name` or `accountId` is set to:
  
   *  `"-1"`, the issue is assigned to the default assignee for the project.
   *  `null`, the issue is set to unassigned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* and *Assign Issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-assignee-put
  * @param options Request options.
  */
    assignIssue<T = Issue.AssignIssue.Response.OK>(options: Issue.AssignIssue.Options): Promise<any>;
    /**
  * Returns a [paginated](#pagination) list of all changelogs for an issue sorted by date, starting from the oldest.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-changelog-get
  * @param options Request options.
  */
    getChangeLogs<T = Issue.GetChangeLogs.Response.OK>(options: Issue.GetChangeLogs.Options): Promise<import("./definitions/PageBeanChangelogAsResponse").PageBeanChangelogAsResponse>;
    /**
  * Returns changelogs for an issue specified by a list of changelog IDs.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-changelog-list-post
  * @param options Request options.
  */
    getChangeLogsById<T = Issue.GetChangeLogsById.Response.OK>(options: Issue.GetChangeLogsById.Options): Promise<import("./definitions/PageOfChangelogsAsResponse").PageOfChangelogsAsResponse>;
    /**
  * Creates an email notification for an issue and adds it to the mail queue.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-notify-post
  * @param options Request options.
  */
    sendNotification<T = Issue.SendNotification.Response.OK>(options: Issue.SendNotification.Options): Promise<any>;
}
declare class IssueTypeGroup extends BaseGroup {
    Screen: IssueTypeScreenGroup;
    Property: IssueTypePropertyGroup;
    Scheme: IssueTypeSchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns all issue types.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issue types are only returned as follows:
  
   *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), all issue types are returned.
   *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for one or more projects, the issue types associated with the projects the user has permission to browse are returned.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-get
  * @param options Request options.
  */
    getTypesForUser<T = Issue.Type.GetTypesForUser.Response.OK>(options?: Issue.Type.GetTypesForUser.Options): Promise<Issue.Type.GetTypesForUser.Response.OK>;
    /**
  * Creates an issue type and adds it to the default issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-post
  * @param options Request options.
  */
    createType<T = Issue.Type.CreateType.Response.OK>(options: Issue.Type.CreateType.Options): Promise<import("./definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
    /**
  * Returns issue types for a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in the relevant project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-project-get
  * @param options Request options.
  */
    getTypesForProject<T = Issue.Type.GetTypesForProject.Response.OK>(options: Issue.Type.GetTypesForProject.Options): Promise<Issue.Type.GetTypesForProject.Response.OK>;
    /**
  * Returns an issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in a project the issue type is associated with or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-get
  * @param options Request options.
  */
    getType<T = Issue.Type.GetType.Response.OK>(options: Issue.Type.GetType.Options): Promise<import("./definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
    /**
  * Updates the issue type.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-put
  * @param options Request options.
  */
    updateType<T = Issue.Type.UpdateType.Response.OK>(options: Issue.Type.UpdateType.Options): Promise<import("./definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
    /**
  * Deletes the issue type. If the issue type is in use, all uses are updated with the alternative issue type (`alternativeIssueTypeId`). A list of alternative issue types are obtained from the [Get alternative issue types](#api-rest-api-3-issuetype-id-alternatives-get) resource.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-delete
  * @param options Request options.
  */
    deleteType<T = Issue.Type.DeleteType.Response.OK>(options: Issue.Type.DeleteType.Options): Promise<undefined>;
    /**
  * Returns a list of issue types that can be used to replace the issue type. The alternative issue types are those assigned to the same workflow scheme, field configuration scheme, and screen scheme.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-alternatives-get
  * @param options Request options.
  */
    getAlternativeTypes<T = Issue.Type.GetAlternativeTypes.Response.OK>(options: Issue.Type.GetAlternativeTypes.Options): Promise<Issue.Type.GetAlternativeTypes.Response.OK>;
    /**
  * Loads an avatar for the issue type.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST \ --user email@example.com:<api_token> \ --header 'X-Atlassian-Token: no-check' \ --header 'Content-Type: image/< image_type>' \ --data-binary "<@/path/to/file/with/your/avatar>" \ --url 'https://your-domain.atlassian.net/rest/api/3/issuetype/{issueTypeId}'This`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar, use [ Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-avatar2-post
  * @param options Request options.
  */
    loadTypeAvatar<T = Issue.Type.LoadTypeAvatar.Response.OK>(options: Issue.Type.LoadTypeAvatar.Options): Promise<import("./definitions/AvatarAsResponse").AvatarAsResponse>;
}
declare class IssueTypeScreenGroup extends BaseGroup {
    Scheme: IssueTypeScreenSchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class IssueTypeScreenSchemeGroup extends BaseGroup {
    /**
  * Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.
  
  Only company-managed projects associated with an issue type screen scheme are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-project-get
  * @param options Request options.
  */
    getProjects<T = Issue.Type.Screen.Scheme.GetProjects.Response.OK>(options: Issue.Type.Screen.Scheme.GetProjects.Options): Promise<import("./definitions/PageBeanProjectDetailsAsResponse").PageBeanProjectDetailsAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type screen schemes.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-get
  * @param options Request options.
  */
    getSchemes<T = Issue.Type.Screen.Scheme.GetSchemes.Response.OK>(options?: Issue.Type.Screen.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanIssueTypeScreenSchemeAsResponse").PageBeanIssueTypeScreenSchemeAsResponse>;
    /**
  * Creates an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-post
  * @param options Request options.
  */
    createScheme<T = Issue.Type.Screen.Scheme.CreateScheme.Response.OK>(options: Issue.Type.Screen.Scheme.CreateScheme.Options): Promise<import("./definitions/IssueTypeScreenSchemeIdAsResponse").IssueTypeScreenSchemeIdAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type screen scheme items.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-mapping-get
  * @param options Request options.
  */
    getSchemeItems<T = Issue.Type.Screen.Scheme.GetSchemeItems.Response.OK>(options?: Issue.Type.Screen.Scheme.GetSchemeItems.Options): Promise<import("./definitions/PageBeanIssueTypeScreenSchemeItemAsResponse").PageBeanIssueTypeScreenSchemeItemAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-project-get
  * @param options Request options.
  */
    getSchemesForProjects<T = Issue.Type.Screen.Scheme.GetSchemesForProjects.Response.OK>(options: Issue.Type.Screen.Scheme.GetSchemesForProjects.Options): Promise<import("./definitions/PageBeanIssueTypeScreenSchemesProjectsAsResponse").PageBeanIssueTypeScreenSchemesProjectsAsResponse>;
    /**
  * Assigns an issue type screen scheme to a project.
  
  Issue type screen schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-put
  * @param options Request options.
  */
    assignSchemeToProject<T = Issue.Type.Screen.Scheme.AssignSchemeToProject.Response.OK>(options: Issue.Type.Screen.Scheme.AssignSchemeToProject.Options): Promise<any>;
    /**
  * Updates an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-put
  * @param options Request options.
  */
    updateScheme<T = Issue.Type.Screen.Scheme.UpdateScheme.Response.OK>(options: Issue.Type.Screen.Scheme.UpdateScheme.Options): Promise<any>;
    /**
  * Deletes an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-delete
  * @param options Request options.
  */
    deleteScheme<T = Issue.Type.Screen.Scheme.DeleteScheme.Response.OK>(options: Issue.Type.Screen.Scheme.DeleteScheme.Options): Promise<any>;
    /**
  * Appends issue type to screen scheme mappings to an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-put
  * @param options Request options.
  */
    appendMappings<T = Issue.Type.Screen.Scheme.AppendMappings.Response.OK>(options: Issue.Type.Screen.Scheme.AppendMappings.Options): Promise<any>;
    /**
  * Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-default-put
  * @param options Request options.
  */
    updateDefaultScheme<T = Issue.Type.Screen.Scheme.UpdateDefaultScheme.Response.OK>(options: Issue.Type.Screen.Scheme.UpdateDefaultScheme.Options): Promise<any>;
    /**
  * Removes issue type to screen scheme mappings from an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-remove-post
  * @param options Request options.
  */
    removeMappings<T = Issue.Type.Screen.Scheme.RemoveMappings.Response.OK>(options: Issue.Type.Screen.Scheme.RemoveMappings.Options): Promise<any>;
}
declare class IssueTypePropertyGroup extends BaseGroup {
    /**
  * Returns all the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys of the issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the property keys of any issue type.
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the property keys of any issue types associated with the projects the user has permission to browse.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-get
  * @param options Request options.
  */
    getPropertyKeys<T = Issue.Type.Property.GetPropertyKeys.Response.OK>(options: Issue.Type.Property.GetPropertyKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the key and value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the details of any issue type.
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the details of any issue types associated with the projects the user has permission to browse.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-get
  * @param options Request options.
  */
    getProperty<T = Issue.Type.Property.GetProperty.Response.OK>(options: Issue.Type.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Creates or updates the value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). Use this resource to store and update data against an issue type.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-put
  * @param options Request options.
  */
    setProperty<T = Issue.Type.Property.SetProperty.Response.OK>(options: Issue.Type.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-delete
  * @param options Request options.
  */
    deleteProperty<T = Issue.Type.Property.DeleteProperty.Response.OK>(options: Issue.Type.Property.DeleteProperty.Options): Promise<undefined>;
}
declare class IssueTypeSchemeGroup extends BaseGroup {
    /**
  * Returns a [paginated](#pagination) list of issue type schemes.
  
  Only issue type schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-get
  * @param options Request options.
  */
    getSchemes<T = Issue.Type.Scheme.GetSchemes.Response.OK>(options?: Issue.Type.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanIssueTypeSchemeAsResponse").PageBeanIssueTypeSchemeAsResponse>;
    /**
  * Creates an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-post
  * @param options Request options.
  */
    createScheme<T = Issue.Type.Scheme.CreateScheme.Response.OK>(options: Issue.Type.Scheme.CreateScheme.Options): Promise<import("./definitions/IssueTypeSchemeIDAsResponse").IssueTypeSchemeIDAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type scheme items.
  
  Only issue type scheme items used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-mapping-get
  * @param options Request options.
  */
    getSchemeItems<T = Issue.Type.Scheme.GetSchemeItems.Response.OK>(options?: Issue.Type.Scheme.GetSchemeItems.Options): Promise<import("./definitions/PageBeanIssueTypeSchemeMappingAsResponse").PageBeanIssueTypeSchemeMappingAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type schemes and, for each issue type scheme, a list of the projects that use it.
  
  Only issue type schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-project-get
  * @param options Request options.
  */
    getSchemesForProjects<T = Issue.Type.Scheme.GetSchemesForProjects.Response.OK>(options: Issue.Type.Scheme.GetSchemesForProjects.Options): Promise<import("./definitions/PageBeanIssueTypeSchemeProjectsAsResponse").PageBeanIssueTypeSchemeProjectsAsResponse>;
    /**
  * Assigns an issue type scheme to a project.
  
  If any issues in the project are assigned issue types not present in the new scheme, the operation will fail. To complete the assignment those issues must be updated to use issue types in the new scheme.
  
  Issue type schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-put
  * @param options Request options.
  */
    assignToProject<T = Issue.Type.Scheme.AssignToProject.Response.OK>(options: Issue.Type.Scheme.AssignToProject.Options): Promise<any>;
    /**
  * Adds issue types to an issue type scheme.
  
  The added issue types are appended to the issue types list.
  
  If any of the issue types exist in the issue type scheme, the operation fails and no issue types are added.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-put
  * @param options Request options.
  */
    addIssueTypesToScheme<T = Issue.Type.Scheme.AddIssueTypesToScheme.Response.OK>(options: Issue.Type.Scheme.AddIssueTypesToScheme.Options): Promise<any>;
    /**
  * Updates an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-put
  * @param options Request options.
  */
    updateScheme<T = Issue.Type.Scheme.UpdateScheme.Response.OK>(options: Issue.Type.Scheme.UpdateScheme.Options): Promise<any>;
    /**
  * Deletes an issue type scheme.
  
  Only issue type schemes used in classic projects can be deleted.
  
  Any projects assigned to the scheme are reassigned to the default issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-delete
  * @param options Request options.
  */
    deleteScheme<T = Issue.Type.Scheme.DeleteScheme.Response.OK>(options: Issue.Type.Scheme.DeleteScheme.Options): Promise<any>;
    /**
  * Changes the order of issue types in an issue type scheme.
  
  The request body parameters must meet the following requirements:
  
   *  all of the issue types must belong to the issue type scheme.
   *  either `after` or `position` must be provided.
   *  the issue type in `after` must not be in the issue type list.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-move-put
  * @param options Request options.
  */
    changeIssueTypesOrder<T = Issue.Type.Scheme.ChangeIssueTypesOrder.Response.OK>(options: Issue.Type.Scheme.ChangeIssueTypesOrder.Options): Promise<any>;
    /**
  * Removes an issue type from an issue type scheme.
  
  This operation cannot remove:
  
   *  any issue type used by issues.
   *  any issue types from the default issue type scheme.
   *  the last standard issue type from an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-issuetypeid-delete
  * @param options Request options.
  */
    removeIssueTypesFromScheme<T = Issue.Type.Scheme.RemoveIssueTypesFromScheme.Response.OK>(options: Issue.Type.Scheme.RemoveIssueTypesFromScheme.Options): Promise<any>;
}
declare class IssueFieldGroup extends BaseGroup {
    Configuration: IssueFieldConfigurationGroup;
    Custom: IssueFieldCustomGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns system and custom issue fields according to the following rules:
  
   *  Fields that cannot be added to the issue navigator are always returned.
   *  Fields that cannot be placed on an issue screen are always returned.
   *  Fields that depend on global Jira settings are only returned if the setting is enabled. That is, timetracking fields, subtasks, votes, and watches.
   *  For all other fields, this operation only returns the fields that the user has permission to view (that is, the field is used in at least one project that the user has *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.)
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-field-get
  * @param options Request options.
  */
    getFields<T = Issue.Field.GetFields.Response.OK>(options?: Issue.Field.GetFields.Options): Promise<Issue.Field.GetFields.Response.OK>;
    /**
  * Returns a [paginated](#pagination) list of fields for Classic Jira projects. The list can include:
  
   *  all fields.
   *  specific fields, by defining `id`.
   *  fields that contain a string in the field name or description, by defining `query`.
   *  specific fields that contain a string in the field name or description, by defining `id` and `query`.
  
  Only custom fields can be queried, `type` must be set to `custom`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-field-search-get
  * @param options Request options.
  */
    getFieldsPaginated<T = Issue.Field.GetFieldsPaginated.Response.OK>(options?: Issue.Field.GetFieldsPaginated.Options): Promise<import("./definitions/PageBeanFieldAsResponse").PageBeanFieldAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of the contexts a field is used in. Deprecated, use [ Get custom field contexts](#api-rest-api-3-field-fieldId-context-get).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-contexts-get
  * @param options Request options.
  * @deprecated
  */
    getContexts<T = Issue.Field.GetContexts.Response.OK>(options: Issue.Field.GetContexts.Options): Promise<import("./definitions/PageBeanContextAsResponse").PageBeanContextAsResponse>;
    /**
  * Deletes a custom field. The custom field is deleted whether it is in the trash or not. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  This operation is [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-delete
  * @param options Request options.
  */
    deleteField<T = Issue.Field.DeleteField.Response.OK>(options: Issue.Field.DeleteField.Options): Promise<undefined>;
    /**
  * Restores a custom field from trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-restore-post
  * @param options Request options.
  */
    restoreField<T = Issue.Field.RestoreField.Response.OK>(options: Issue.Field.RestoreField.Options): Promise<any>;
    /**
  * Moves a custom field to trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-trash-post
  * @param options Request options.
  */
    moveToTrash<T = Issue.Field.MoveToTrash.Response.OK>(options: Issue.Field.MoveToTrash.Options): Promise<any>;
}
declare class IssueFieldConfigurationGroup extends BaseGroup {
    Scheme: IssueFieldConfigurationSchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Creates a field configuration. The field configuration is created with the same field properties as the default configuration, with all the fields being optional.
  
  This operation can only create configurations for use in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-post
  * @param options Request options.
  */
    createConfiguration<T = Issue.Field.Configuration.CreateConfiguration.Response.OK>(options: Issue.Field.Configuration.CreateConfiguration.Options): Promise<import("./definitions/FieldConfigurationAsResponse").FieldConfigurationAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of field configurations. The list can be for all field configurations or a subset determined by any combination of these criteria:
  
   *  a list of field configuration item IDs.
   *  whether the field configuration is a default.
   *  whether the field configuration name or description contains a query string.
  
  Only field configurations used in company-managed (classic) projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-get
  * @param options Request options.
  */
    getConfigurations<T = Issue.Field.Configuration.GetConfigurations.Response.OK>(options?: Issue.Field.Configuration.GetConfigurations.Options): Promise<import("./definitions/PageBeanFieldConfigurationDetailsAsResponse").PageBeanFieldConfigurationDetailsAsResponse>;
    /**
  * Updates a field configuration. The name and the description provided in the request override the existing values.
  
  This operation can only update configurations used in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-put
  * @param options Request options.
  */
    updateConfiguration<T = Issue.Field.Configuration.UpdateConfiguration.Response.OK>(options: Issue.Field.Configuration.UpdateConfiguration.Options): Promise<any>;
    /**
  * Deletes a field configuration.
  
  This operation can only delete configurations used in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-delete
  * @param options Request options.
  */
    deleteConfiguration<T = Issue.Field.Configuration.DeleteConfiguration.Response.OK>(options: Issue.Field.Configuration.DeleteConfiguration.Options): Promise<any>;
    /**
  * Returns a [paginated](#pagination) list of all fields for a configuration.
  
  Only the fields from configurations used in company-managed (classic) projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-id-fields-get
  * @param options Request options.
  */
    getConfigurationItems<T = Issue.Field.Configuration.GetConfigurationItems.Response.OK>(options: Issue.Field.Configuration.GetConfigurationItems.Options): Promise<import("./definitions/PageBeanFieldConfigurationItemAsResponse").PageBeanFieldConfigurationItemAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of field configuration issue type items.
  
  Only items used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfigurationscheme-mapping-get
  * @param options Request options.
  */
    getConfigurationIssueTypeItems<T = Issue.Field.Configuration.GetConfigurationIssueTypeItems.Response.OK>(options?: Issue.Field.Configuration.GetConfigurationIssueTypeItems.Options): Promise<import("./definitions/PageBeanFieldConfigurationIssueTypeItemAsResponse").PageBeanFieldConfigurationIssueTypeItemAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of field configuration schemes.
  
  Only field configuration schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-get
  * @param options Request options.
  */
    getSchemes<T = Issue.Field.Configuration.GetSchemes.Response.OK>(options?: Issue.Field.Configuration.GetSchemes.Options): Promise<import("./definitions/PageBeanFieldConfigurationSchemeAsResponse").PageBeanFieldConfigurationSchemeAsResponse>;
}
declare class IssueFieldConfigurationSchemeGroup extends BaseGroup {
    /**
  * Returns a [paginated](#pagination) list of field configuration schemes and, for each scheme, a list of the projects that use it.
  
  The list is sorted by field configuration scheme ID. The first item contains the list of project IDs assigned to the default field configuration scheme.
  
  Only field configuration schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfigurationscheme-project-get
  * @param options Request options.
  */
    getSchemesForProjects<T = Issue.Field.Configuration.Scheme.GetSchemesForProjects.Response.OK>(options: Issue.Field.Configuration.Scheme.GetSchemesForProjects.Options): Promise<import("./definitions/PageBeanFieldConfigurationSchemeProjectsAsResponse").PageBeanFieldConfigurationSchemeProjectsAsResponse>;
    /**
  * Assigns a field configuration scheme to a project. If the field configuration scheme ID is `null`, the operation assigns the default field configuration scheme.
  
  Field configuration schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-project-put
  * @param options Request options.
  */
    assignSchemeToProject<T = Issue.Field.Configuration.Scheme.AssignSchemeToProject.Response.OK>(options: Issue.Field.Configuration.Scheme.AssignSchemeToProject.Options): Promise<any>;
}
declare class IssueFieldCustomGroup extends BaseGroup {
    Option: IssueFieldCustomOptionGroup;
    Context: IssueFieldCustomContextGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Creates a custom field.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-field-post
  * @param options Request options.
  */
    createField<T = Issue.Field.Custom.CreateField.Response.OK>(options: Issue.Field.Custom.CreateField.Options): Promise<import("./definitions/FieldDetailsAsResponse").FieldDetailsAsResponse>;
    /**
  * Updates a custom field.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-put
  * @param options Request options.
  */
    updateField<T = Issue.Field.Custom.UpdateField.Response.OK>(options: Issue.Field.Custom.UpdateField.Options): Promise<any>;
}
declare class IssueFieldCustomOptionGroup extends BaseGroup {
    /**
  * Returns a custom field option. For example, an option in a select list.
  
  Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The custom field option is returned as follows:
  
   *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the custom field is used in, and the field is visible in at least one layout the user has permission to view.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-customFieldOption-id-get
  * @param options Request options.
  * @deprecated
  */
    getOption<T = Issue.Field.Custom.Option.GetOption.Response.OK>(options: Issue.Field.Custom.Option.GetOption.Options): Promise<import("./definitions/CustomFieldOptionAsResponse").CustomFieldOptionAsResponse>;
}
declare class IssueFieldCustomContextGroup extends BaseGroup {
    Option: IssueFieldCustomContextOptionGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a [paginated](#pagination) list of [ contexts](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html) for a custom field. Contexts can be returned as follows:
  
   *  With no other parameters set, all contexts.
   *  By defining `id` only, all contexts from the list of IDs.
   *  By defining `isAnyIssueType`, limit the list of contexts returned to either those that apply to all issue types (true) or those that apply to only a subset of issue types (false)
   *  By defining `isGlobalContext`, limit the list of contexts return to either those that apply to all projects (global contexts) (true) or those that apply to only a subset of projects (false).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-get
  * @param options Request options.
  */
    getContexts<T = Issue.Field.Custom.Context.GetContexts.Response.OK>(options: Issue.Field.Custom.Context.GetContexts.Options): Promise<import("./definitions/PageBeanCustomFieldContextAsResponse").PageBeanCustomFieldContextAsResponse>;
    /**
  * Creates a custom field context.
  
  If `projectIds` is empty, a global context is created. A global context is one that applies to all project. If `issueTypeIds` is empty, the context applies to all issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-post
  * @param options Request options.
  */
    createContext<T = Issue.Field.Custom.Context.CreateContext.Response.OK>(options: Issue.Field.Custom.Context.CreateContext.Options): Promise<import("./definitions/CreateCustomFieldContextAsResponse").CreateCustomFieldContextAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of defaults for a custom field. The results can be filtered by `contextId`, otherwise all values are returned. If no defaults are set for a context, nothing is returned.
  The returned object depends on type of the custom field:
  
   *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
   *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
   *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
   *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
   *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
   *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
   *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
   *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group picker.
   *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group picker.
   *  `CustomFieldContextDefaultValueURL` (type `url`) for URL.
   *  `CustomFieldContextDefaultValueProject` (type `project`) for project picker.
   *  `CustomFieldContextDefaultValueFloat` (type `float`) for float (a floating-point number).
   *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
   *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text field.
   *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area field.
   *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) field.
   *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version picker.
   *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version picker.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-get
  * @param options Request options.
  */
    getDefaultContexts<T = Issue.Field.Custom.Context.GetDefaultContexts.Response.OK>(options: Issue.Field.Custom.Context.GetDefaultContexts.Options): Promise<import("./definitions/PageBeanCustomFieldContextDefaultValueAsResponse").PageBeanCustomFieldContextDefaultValueAsResponse>;
    /**
  * Sets default for contexts of a custom field. Default are defined using these objects:
  
   *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
   *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
   *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
   *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
   *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
   *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
   *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
   *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group picker.
   *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group picker.
   *  `CustomFieldContextDefaultValueURL` (type `url`) for URL.
   *  `CustomFieldContextDefaultValueProject` (type `project`) for project picker.
   *  `CustomFieldContextDefaultValueFloat` (type `float`) for float (a floating-point number).
   *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
   *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text field.
   *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area field.
   *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) field.
   *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version picker.
   *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version picker.
  
  Only one type of default object can be included in a request. To remove a default for a context, set the default parameter to `null`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-put
  * @param options Request options.
  */
    setDefaultContexts<T = Issue.Field.Custom.Context.SetDefaultContexts.Response.OK>(options: Issue.Field.Custom.Context.SetDefaultContexts.Options): Promise<any>;
    /**
  * Returns a [paginated](#pagination) list of context to issue type mappings for a custom field. Mappings are returned for all contexts or a list of contexts. Mappings are ordered first by context ID and then by issue type ID.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-issuetypemapping-get
  * @param options Request options.
  */
    getIssueTypes<T = Issue.Field.Custom.Context.GetIssueTypes.Response.OK>(options: Issue.Field.Custom.Context.GetIssueTypes.Options): Promise<import("./definitions/PageBeanIssueTypeToContextMappingAsResponse").PageBeanIssueTypeToContextMappingAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of context to project mappings for a custom field. The result can be filtered by `contextId`. Otherwise, all mappings are returned. Invalid IDs are ignored.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-projectmapping-get
  * @param options Request options.
  */
    getProjectMappings<T = Issue.Field.Custom.Context.GetProjectMappings.Response.OK>(options: Issue.Field.Custom.Context.GetProjectMappings.Options): Promise<import("./definitions/PageBeanCustomFieldContextProjectMappingAsResponse").PageBeanCustomFieldContextProjectMappingAsResponse>;
    /**
  * Updates a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-put
  * @param options Request options.
  */
    updateContext<T = Issue.Field.Custom.Context.UpdateContext.Response.OK>(options: Issue.Field.Custom.Context.UpdateContext.Options): Promise<any>;
    /**
  * Adds issue types to a custom field context, appending the issue types to the issue types list.
  
  A custom field context without any issue types applies to all issue types. Adding issue types to such a custom field context would result in it applying to only the listed issue types.
  
  If any of the issue types exists in the custom field context, the operation fails and no issue types are added.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-put
  * @param options Request options.
  */
    addIssueTypes<T = Issue.Field.Custom.Context.AddIssueTypes.Response.OK>(options: Issue.Field.Custom.Context.AddIssueTypes.Options): Promise<any>;
    /**
  * Removes issue types from a custom field context.
  
  A custom field context without any issue types applies to all issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-remove-post
  * @param options Request options.
  */
    removeIssueTypes<T = Issue.Field.Custom.Context.RemoveIssueTypes.Response.OK>(options: Issue.Field.Custom.Context.RemoveIssueTypes.Options): Promise<any>;
    /**
  * Assigns a custom field context to projects.
  
  If any project in the request is assigned to any context of the custom field, the operation fails.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-put
  * @param options Request options.
  */
    assignToProjects<T = Issue.Field.Custom.Context.AssignToProjects.Response.OK>(options: Issue.Field.Custom.Context.AssignToProjects.Options): Promise<any>;
    /**
  * Removes a custom field context from projects.
  
  A custom field context without any projects applies to all projects. Removing all projects from a custom field context would result in it applying to all projects.
  
  If any project in the request is not assigned to the context, or the operation would result in two global contexts for the field, the operation fails.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-remove-post
  * @param options Request options.
  */
    removeFromProjects<T = Issue.Field.Custom.Context.RemoveFromProjects.Response.OK>(options: Issue.Field.Custom.Context.RemoveFromProjects.Options): Promise<any>;
}
declare class IssueFieldCustomContextOptionGroup extends BaseGroup {
    /**
  * Returns a [paginated](#pagination) list of all custom field option for a context. Options are returned first then cascading options, in the order they display in Jira.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-get
  * @param options Request options.
  */
    getOptions<T = Issue.Field.Custom.Context.Option.GetOptions.Response.OK>(options: Issue.Field.Custom.Context.Option.GetOptions.Options): Promise<import("./definitions/PageBeanCustomFieldContextOptionAsResponse").PageBeanCustomFieldContextOptionAsResponse>;
    /**
  * Creates options and, where the custom select field is of the type Select List (cascading), cascading options for a custom select field. The options are added to a context of the field.
  
  The maximum number of options that can be created per request is 1000 and each field can have a maximum of 10000 options.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-post
  * @param options Request options.
  */
    createOptions<T = Issue.Field.Custom.Context.Option.CreateOptions.Response.OK>(options: Issue.Field.Custom.Context.Option.CreateOptions.Options): Promise<import("./definitions/CustomFieldCreatedContextOptionsListAsResponse").CustomFieldCreatedContextOptionsListAsResponse>;
    /**
  * Updates the options of a custom field.
  
  If any of the options are not found, no options are updated. Options where the values in the request match the current values aren't updated and aren't reported in the response.
  
  Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-put
  * @param options Request options.
  */
    updateOptions<T = Issue.Field.Custom.Context.Option.UpdateOptions.Response.OK>(options: Issue.Field.Custom.Context.Option.UpdateOptions.Options): Promise<import("./definitions/CustomFieldUpdatedContextOptionsListAsResponse").CustomFieldUpdatedContextOptionsListAsResponse>;
    /**
  * Changes the order of custom field options or cascading options in a context.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-move-put
  * @param options Request options.
  */
    reorderOptions<T = Issue.Field.Custom.Context.Option.ReorderOptions.Response.OK>(options: Issue.Field.Custom.Context.Option.ReorderOptions.Options): Promise<any>;
    /**
  * Deletes a custom field option.
  
  Options with cascading options cannot be deleted without deleting the cascading options first.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-optionid-delete
  * @param options Request options.
  */
    deleteOption<T = Issue.Field.Custom.Context.Option.DeleteOption.Response.OK>(options: Issue.Field.Custom.Context.Option.DeleteOption.Options): Promise<undefined>;
}
declare class IssueWorklogGroup extends BaseGroup {
    Property: IssueWorklogPropertyGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns worklogs for an issue, starting from the oldest worklog or from the worklog started on or after a date and time.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Workloads are only returned where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-get
  * @param options Request options.
  */
    getWorklogs<T = Issue.Worklog.GetWorklogs.Response.OK>(options: Issue.Worklog.GetWorklogs.Options): Promise<import("./definitions/PageOfWorklogsAsResponse").PageOfWorklogsAsResponse>;
    /**
  * Adds a worklog to an issue.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Work on issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-post
  * @param options Request options.
  */
    addWorklog<T = Issue.Worklog.AddWorklog.Response.OK>(options: Issue.Worklog.AddWorklog.Options): Promise<import("./definitions/WorklogAsResponse").WorklogAsResponse>;
    /**
  * Returns a worklog.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-get
  * @param options Request options.
  */
    getWorklog<T = Issue.Worklog.GetWorklog.Response.OK>(options: Issue.Worklog.GetWorklog.Options): Promise<import("./definitions/WorklogAsResponse").WorklogAsResponse>;
    /**
  * Updates a worklog.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-put
  * @param options Request options.
  */
    updateWorklog<T = Issue.Worklog.UpdateWorklog.Response.OK>(options: Issue.Worklog.UpdateWorklog.Options): Promise<import("./definitions/WorklogAsResponse").WorklogAsResponse>;
    /**
  * Deletes a worklog from an issue.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Delete all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any worklog or *Delete own worklogs* to delete worklogs created by the user,
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-delete
  * @param options Request options.
  */
    deleteWorklog<T = Issue.Worklog.DeleteWorklog.Response.OK>(options: Issue.Worklog.DeleteWorklog.Options): Promise<undefined>;
    /**
  * Returns a list of IDs and delete timestamps for worklogs deleted after a date and time.
  
  This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
  
  This resource does not return worklogs deleted during the minute preceding the request.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-deleted-get
  * @param options Request options.
  */
    getDeletedIds<T = Issue.Worklog.GetDeletedIds.Response.OK>(options?: Issue.Worklog.GetDeletedIds.Options): Promise<import("./definitions/ChangedWorklogsAsResponse").ChangedWorklogsAsResponse>;
    /**
  * Returns worklog details for a list of worklog IDs.
  
  The returned list of worklogs is limited to 1000 items.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
  
   *  the worklog is set as *Viewable by All Users*.
   *  the user is a member of a project role or group with permission to view the worklog.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-list-post
  * @param options Request options.
  */
    getFromIds<T = Issue.Worklog.GetFromIds.Response.OK>(options: Issue.Worklog.GetFromIds.Options): Promise<Issue.Worklog.GetFromIds.Response.OK>;
    /**
  * Returns a list of IDs and update timestamps for worklogs updated after a date and time.
  
  This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
  
  This resource does not return worklogs updated during the minute preceding the request.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
  
   *  the worklog is set as *Viewable by All Users*.
   *  the user is a member of a project role or group with permission to view the worklog.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-updated-get
  * @param options Request options.
  */
    getUpdatedIds<T = Issue.Worklog.GetUpdatedIds.Response.OK>(options?: Issue.Worklog.GetUpdatedIds.Options): Promise<import("./definitions/ChangedWorklogsAsResponse").ChangedWorklogsAsResponse>;
}
declare class IssueWorklogPropertyGroup extends BaseGroup {
    /**
  * Returns the keys of all properties for a worklog.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-get
  * @param options Request options.
  */
    getKeys<T = Issue.Worklog.Property.GetKeys.Response.OK>(options: Issue.Worklog.Property.GetKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the value of a worklog property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-get
  * @param options Request options.
  */
    getProperty<T = Issue.Worklog.Property.GetProperty.Response.OK>(options: Issue.Worklog.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of a worklog property. Use this operation to store custom data against the worklog.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-put
  * @param options Request options.
  */
    setProperty<T = Issue.Worklog.Property.SetProperty.Response.OK>(options: Issue.Worklog.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes a worklog property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-delete
  * @param options Request options.
  */
    deleteProperty<T = Issue.Worklog.Property.DeleteProperty.Response.OK>(options: Issue.Worklog.Property.DeleteProperty.Options): Promise<undefined>;
}
declare class IssueAttachmentGroup extends BaseGroup {
    Metadata: IssueAttachmentMetadataGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Deletes an attachment from an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the project holding the issue containing the attachment:
  
   *  *Delete own attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by the calling user.
   *  *Delete all attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by any user.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-delete
  * @param options Request options.
  */
    deleteAttachment<T = Issue.Attachment.DeleteAttachment.Response.OK>(options: Issue.Attachment.DeleteAttachment.Options): Promise<undefined>;
    /**
  * Adds one or more attachments to an issue. Attachments are posted as multipart/form-data ([RFC 1867](https://www.ietf.org/rfc/rfc1867.txt)).
  
  Note that:
  
   *  The request must have a `X-Atlassian-Token: no-check` header, if not it is blocked. See [Special headers](#special-request-headers) for more information.
   *  The name of the multipart/form-data parameter that contains the attachments must be `file`.
  
  The following examples upload a file called *myfile.txt* to the issue *TEST-123*:
  
  #### curl ####
  
      curl --location --request POST 'https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments'
       -u 'email@example.com:<api_token>'
       -H 'X-Atlassian-Token: no-check'
       --form 'file=@"myfile.txt"'
  
  #### Node.js ####
  
      // This code sample uses the 'node-fetch' and 'form-data' libraries:
       // https://www.npmjs.com/package/node-fetch
       // https://www.npmjs.com/package/form-data
       const fetch = require('node-fetch');
       const FormData = require('form-data');
       const fs = require('fs');
      
       const filePath = 'myfile.txt';
       const form = new FormData();
       const stats = fs.statSync(filePath);
       const fileSizeInBytes = stats.size;
       const fileStream = fs.createReadStream(filePath);
      
       form.append('file', fileStream, {knownLength: fileSizeInBytes});
      
       fetch('https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments', {
           method: 'POST',
           body: form,
           headers: {
               'Authorization': `Basic ${Buffer.from(
                   'email@example.com:'
               ).toString('base64')}`,
               'Accept': 'application/json',
               'X-Atlassian-Token': 'no-check'
           }
       })
           .then(response => {
               console.log(
                   `Response: ${response.status} ${response.statusText}`
               );
               return response.text();
           })
           .then(text => console.log(text))
           .catch(err => console.error(err));
  
  #### Java ####
  
      // This code sample uses the  'Unirest' library:
       // http://unirest.io/java.html
       HttpResponse response = Unirest.post("https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments")
               .basicAuth("email@example.com", "")
               .header("Accept", "application/json")
               .header("X-Atlassian-Token", "no-check")
               .field("file", new File("myfile.txt"))
               .asJson();
      
               System.out.println(response.getBody());
  
  #### Python ####
  
      # This code sample uses the 'requests' library:
       # http://docs.python-requests.org
       import requests
       from requests.auth import HTTPBasicAuth
       import json
      
       url = "https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments"
      
       auth = HTTPBasicAuth("email@example.com", "")
      
       headers = {
          "Accept": "application/json",
          "X-Atlassian-Token": "no-check"
       }
      
       response = requests.request(
          "POST",
          url,
          headers = headers,
          auth = auth,
          files = {
               "file": ("myfile.txt", open("myfile.txt","rb"), "application-type")
          }
       )
      
       print(json.dumps(json.loads(response.text), sort_keys=True, indent=4, separators=(",", ": ")))
  
  #### PHP ####
  
      // This code sample uses the 'Unirest' library:
       // http://unirest.io/php.html
       Unirest\Request::auth('email@example.com', '');
      
       $headers = array(
         'Accept' => 'application/json',
         'X-Atlassian-Token' => 'no-check'
       );
      
       $parameters = array(
         'file' => File::add('myfile.txt')
       );
      
       $response = Unirest\Request::post(
         'https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments',
         $headers,
         $parameters
       );
      
       var_dump($response)
  
  #### Forge ####
  
      // This sample uses Atlassian Forge and the `form-data` library.
       // https://developer.atlassian.com/platform/forge/
       // https://www.npmjs.com/package/form-data
       import api from "@forge/api";
       import FormData from "form-data";
      
       const form = new FormData();
       form.append('file', fileStream, {knownLength: fileSizeInBytes});
      
       const response = await api.asApp().requestJira('/rest/api/2/issue/{issueIdOrKey}/attachments', {
           method: 'POST',
           body: form,
           headers: {
               'Accept': 'application/json',
               'X-Atlassian-Token': 'no-check'
           }
       });
      
       console.log(`Response: ${response.status} ${response.statusText}`);
       console.log(await response.json());
  
  Tip: Use a client library. Many client libraries have classes for handling multipart POST operations. For example, in Java, the Apache HTTP Components library provides a [MultiPartEntity](http://hc.apache.org/httpcomponents-client-ga/httpmime/apidocs/org/apache/http/entity/mime/MultipartEntity.html) class for multipart POST operations.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* and *Create attachments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-attachments-post
  * @param options Request options.
  */
    addAttachments<T = Issue.Attachment.AddAttachments.Response.OK>(options: Issue.Attachment.AddAttachments.Options): Promise<Issue.Attachment.AddAttachments.Response.OK>;
}
declare class IssueAttachmentMetadataGroup extends BaseGroup {
    /**
  * Returns the metadata for an attachment. Note that the attachment itself is not returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-get
  * @param options Request options.
  */
    getMetadata<T = Issue.Attachment.Metadata.GetMetadata.Response.OK>(options: Issue.Attachment.Metadata.GetMetadata.Options): Promise<import("./definitions/AttachmentMetadataAsResponse").AttachmentMetadataAsResponse>;
    /**
  * Returns the metadata for the contents of an attachment, if it is an archive, and metadata for the attachment itself. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned and metadata for the ZIP archive. Currently, only the ZIP archive format is supported.
  
  Use this operation to retrieve data that is presented to the user, as this operation returns the metadata for the attachment itself, such as the attachment's ID and name. Otherwise, use [ Get contents metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-raw-get), which only returns the metadata for the attachment's contents.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-expand-human-get
  * @param options Request options.
  */
    getMetadataForExpandedAttachment<T = Issue.Attachment.Metadata.GetMetadataForExpandedAttachment.Response.OK>(options: Issue.Attachment.Metadata.GetMetadataForExpandedAttachment.Options): Promise<import("./definitions/AttachmentArchiveMetadataReadableAsResponse").AttachmentArchiveMetadataReadableAsResponse>;
    /**
  * Returns the metadata for the contents of an attachment, if it is an archive. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned. Currently, only the ZIP archive format is supported.
  
  Use this operation if you are processing the data without presenting it to the user, as this operation only returns the metadata for the contents of the attachment. Otherwise, to retrieve data to present to the user, use [ Get all metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-human-get) which also returns the metadata for the attachment itself, such as the attachment's ID and name.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-expand-raw-get
  * @param options Request options.
  */
    getContentsMetadataForExpandedAttachment<T = Issue.Attachment.Metadata.GetContentsMetadataForExpandedAttachment.Response.OK>(options: Issue.Attachment.Metadata.GetContentsMetadataForExpandedAttachment.Options): Promise<import("./definitions/AttachmentArchiveImplAsResponse").AttachmentArchiveImplAsResponse>;
}
declare class IssueCommentGroup extends BaseGroup {
    Property: IssueCommentPropertyGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a [paginated](#pagination) list of comments specified by a list of comment IDs.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Comments are returned where the user:
  
   *  has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-list-post
  * @param options Request options.
  */
    getCommentsByIds<T = Issue.Comment.GetCommentsByIds.Response.OK>(options: Issue.Comment.GetCommentsByIds.Options): Promise<import("./definitions/PageBeanCommentAsResponse").PageBeanCommentAsResponse>;
    /**
  * Returns all comments for an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Comments are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-get
  * @param options Request options.
  */
    getComments<T = Issue.Comment.GetComments.Response.OK>(options: Issue.Comment.GetComments.Options): Promise<import("./definitions/PageOfCommentsAsResponse").PageOfCommentsAsResponse>;
    /**
  * Adds a comment to an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Add comments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-post
  * @param options Request options.
  */
    addComment<T = Issue.Comment.AddComment.Response.OK>(options: Issue.Comment.AddComment.Options): Promise<import("./definitions/CommentAsResponse").CommentAsResponse>;
    /**
  * Returns a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-get
  * @param options Request options.
  */
    getComment<T = Issue.Comment.GetComment.Response.OK>(options: Issue.Comment.GetComment.Options): Promise<import("./definitions/CommentAsResponse").CommentAsResponse>;
    /**
  * Updates a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any comment or *Edit own comments* to update comment created by the user.
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-put
  * @param options Request options.
  */
    updateComment<T = Issue.Comment.UpdateComment.Response.OK>(options: Issue.Comment.UpdateComment.Options): Promise<import("./definitions/CommentAsResponse").CommentAsResponse>;
    /**
  * Deletes a comment.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Delete all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any comment or *Delete own comments* to delete comment created by the user,
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-delete
  * @param options Request options.
  */
    deleteComment<T = Issue.Comment.DeleteComment.Response.OK>(options: Issue.Comment.DeleteComment.Options): Promise<undefined>;
}
declare class IssueCommentPropertyGroup extends BaseGroup {
    /**
  * Returns the keys of all the properties of a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-get
  * @param options Request options.
  */
    getKeys<T = Issue.Comment.Property.GetKeys.Response.OK>(options: Issue.Comment.Property.GetKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the value of a comment property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-get
  * @param options Request options.
  */
    getProperty<T = Issue.Comment.Property.GetProperty.Response.OK>(options: Issue.Comment.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Creates or updates the value of a property for a comment. Use this resource to store custom data against a comment.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on any comment.
   *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on a comment created by the user.
  
  Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-put
  * @param options Request options.
  */
    setProperty<T = Issue.Comment.Property.SetProperty.Response.OK>(options: Issue.Comment.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes a comment property.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from any comment.
   *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from a comment created by the user.
  
  Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-delete
  * @param options Request options.
  */
    deleteProperty<T = Issue.Comment.Property.DeleteProperty.Response.OK>(options: Issue.Comment.Property.DeleteProperty.Options): Promise<undefined>;
}
declare class IssueMetadataGroup extends BaseGroup {
    /**
  * Returns details of projects, issue types within projects, and, when requested, the create screen fields for each issue type for the user. Use the information to populate the requests in [ Create issue](#api-rest-api-3-issue-post) and [Create issues](#api-rest-api-3-issue-bulk-post).
  
  The request can be restricted to specific projects or issue types using the query parameters. The response will contain information for the valid projects, issue types, or project and issue type combinations requested. Note that invalid project, issue type, or project and issue type combinations do not generate errors.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Create issues* [project permission](https://confluence.atlassian.com/x/yodKLg) in the requested projects.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-createmeta-get
  * @param options Request options.
  */
    getCreateMetadata<T = Issue.Metadata.GetCreateMetadata.Response.OK>(options?: Issue.Metadata.GetCreateMetadata.Options): Promise<import("./definitions/IssueCreateMetadataAsResponse").IssueCreateMetadataAsResponse>;
    /**
  * Returns the edit screen fields for an issue that are visible to and editable by the user. Use the information to populate the requests in [Edit issue](#api-rest-api-3-issue-issueIdOrKey-put).
  
  Connect app users with admin permission (from user permissions and app scopes) and Forge app users with the `manage:jira-configuration` scope can return additional details using:
  
   *  `overrideScreenSecurity` Returns hidden fields.
   *  `overrideEditableFlag` Returns uneditable fields. For example, where an issue has a workflow status of closed none of its fields are editable.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  Note: For any fields to be editable the user must have the *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-editmeta-get
  * @param options Request options.
  */
    getEditMetadata<T = Issue.Metadata.GetEditMetadata.Response.OK>(options: Issue.Metadata.GetEditMetadata.Options): Promise<import("./definitions/IssueUpdateMetadataAsResponse").IssueUpdateMetadataAsResponse>;
}
declare class IssuePropertyGroup extends BaseGroup {
    /**
  * Returns the URLs and keys of an issue's properties.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Property details are only returned where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-get
  * @param options Request options.
  */
    getKeys<T = Issue.Property.GetKeys.Response.OK>(options: Issue.Property.GetKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the key and value of an issue's property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-get
  * @param options Request options.
  */
    getProperty<T = Issue.Property.GetProperty.Response.OK>(options: Issue.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of an issue's property. Use this resource to store custom data against an issue.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-put
  * @param options Request options.
  */
    setProperty<T = Issue.Property.SetProperty.Response.OK>(options: Issue.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes an issue's property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-delete
  * @param options Request options.
  */
    deleteProperty<T = Issue.Property.DeleteProperty.Response.OK>(options: Issue.Property.DeleteProperty.Options): Promise<undefined>;
}
declare class IssueLinkGroup extends BaseGroup {
    Remote: IssueLinkRemoteGroup;
    Type: IssueLinkTypeGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Creates a link between two issues. Use this operation to indicate a relationship between two issues and optionally add a comment to the from (outward) issue. To use this resource the site must have [Issue Linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This resource returns nothing on the creation of an issue link. To obtain the ID of the issue link, use `https://your-domain.atlassian.net/rest/api/3/issue/[linked issue key]?fields=issuelinks`.
  
  If the link request duplicates a link, the response indicates that the issue link was created. If the request included a comment, the comment is added.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues to be linked,
   *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) on the project containing the from (outward) issue,
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLink-post
  * @param options Request options.
  */
    createLink<T = Issue.Link.CreateLink.Response.OK>(options: Issue.Link.CreateLink.Options): Promise<any>;
    /**
  * Returns an issue link.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the linked issues.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLink-linkId-get
  * @param options Request options.
  */
    getLink<T = Issue.Link.GetLink.Response.OK>(options: Issue.Link.GetLink.Options): Promise<import("./definitions/IssueLinkAsResponse").IssueLinkAsResponse>;
    /**
  * Deletes an issue link.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  Browse project [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues in the link.
   *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one of the projects containing issues in the link.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLink-linkId-delete
  * @param options Request options.
  */
    deleteLink<T = Issue.Link.DeleteLink.Response.OK>(options: Issue.Link.DeleteLink.Options): Promise<undefined>;
}
declare class IssueLinkRemoteGroup extends BaseGroup {
    /**
  * Returns the remote issue links for an issue. When a remote issue link global ID is provided the record with that global ID is returned, otherwise all remote issue links are returned. Where a global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-get
  * @param options Request options.
  */
    getLinks<T = Issue.Link.Remote.GetLinks.Response.OK>(options: Issue.Link.Remote.GetLinks.Options): Promise<import("./definitions/RemoteIssueLinkAsResponse").RemoteIssueLinkAsResponse>;
    /**
  * Creates or updates a remote issue link for an issue.
  
  If a `globalId` is provided and a remote issue link with that global ID is found it is updated. Any fields without values in the request are set to null. Otherwise, the remote issue link is created.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-post
  * @param options Request options.
  */
    createOrUpdateLink<T = Issue.Link.Remote.CreateOrUpdateLink.Response.OK>(options: Issue.Link.Remote.CreateOrUpdateLink.Options): Promise<import("./definitions/RemoteIssueLinkIdentifiesAsResponse").RemoteIssueLinkIdentifiesAsResponse>;
    /**
  * Deletes the remote issue link from the issue using the link's global ID. Where the global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is implemented, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-delete
  * @param options Request options.
  */
    deleteLinkByGlobalId<T = Issue.Link.Remote.DeleteLinkByGlobalId.Response.OK>(options: Issue.Link.Remote.DeleteLinkByGlobalId.Options): Promise<undefined>;
    /**
  * Returns a remote issue link for an issue.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-get
  * @param options Request options.
  */
    getLink<T = Issue.Link.Remote.GetLink.Response.OK>(options: Issue.Link.Remote.GetLink.Options): Promise<import("./definitions/RemoteIssueLinkAsResponse").RemoteIssueLinkAsResponse>;
    /**
  * Updates a remote issue link for an issue.
  
  Note: Fields without values in the request are set to null.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-put
  * @param options Request options.
  */
    updateLink<T = Issue.Link.Remote.UpdateLink.Response.OK>(options: Issue.Link.Remote.UpdateLink.Options): Promise<any>;
    /**
  * Deletes a remote issue link from an issue.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects*, *Edit issues*, and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-delete
  * @param options Request options.
  */
    deleteLink<T = Issue.Link.Remote.DeleteLink.Response.OK>(options: Issue.Link.Remote.DeleteLink.Options): Promise<undefined>;
}
declare class IssueLinkTypeGroup extends BaseGroup {
    /**
  * Returns a list of all issue link types.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-get
  * @param options Request options.
  */
    getTypes<T = Issue.Link.Type.GetTypes.Response.OK>(options?: Issue.Link.Type.GetTypes.Options): Promise<import("./definitions/IssueLinkTypesAsResponse").IssueLinkTypesAsResponse>;
    /**
  * Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-post
  * @param options Request options.
  */
    createType<T = Issue.Link.Type.CreateType.Response.OK>(options: Issue.Link.Type.CreateType.Options): Promise<import("./definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
    /**
  * Returns an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-get
  * @param options Request options.
  */
    getType<T = Issue.Link.Type.GetType.Response.OK>(options: Issue.Link.Type.GetType.Options): Promise<import("./definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
    /**
  * Updates an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-put
  * @param options Request options.
  */
    updateType<T = Issue.Link.Type.UpdateType.Response.OK>(options: Issue.Link.Type.UpdateType.Options): Promise<import("./definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
    /**
  * Deletes an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-delete
  * @param options Request options.
  */
    deleteType<T = Issue.Link.Type.DeleteType.Response.OK>(options: Issue.Link.Type.DeleteType.Options): Promise<undefined>;
}
declare class IssueTransitionGroup extends BaseGroup {
    /**
  * Returns either all transitions or a transition that can be performed by the user on an issue, based on the issue's status.
  
  Note, if a request is made for a transition that does not exist or cannot be performed on the issue, given its status, the response will return any empty transitions list.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required: A list or transition is returned only when the user has:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  However, if the user does not have the *Transition issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) the response will not list any transitions.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-transitions-get
  * @param options Request options.
  */
    getTransitions<T = Issue.Transition.GetTransitions.Response.OK>(options: Issue.Transition.GetTransitions.Options): Promise<import("./definitions/TransitionsAsResponse").TransitionsAsResponse>;
    /**
  * Performs an issue transition and, if the transition has a screen, updates the fields from the transition screen.
  
  sortByCategory To update the fields on the transition screen, specify the fields in the `fields` or `update` parameters in the request body. Get details about the fields using [ Get transitions](#api-rest-api-3-issue-issueIdOrKey-transitions-get) with the `transitions.fields` expand.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Transition issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-transitions-post
  * @param options Request options.
  */
    performTransition<T = Issue.Transition.PerformTransition.Response.OK>(options: Issue.Transition.PerformTransition.Options): Promise<Issue.Transition.PerformTransition.Response.OK>;
}
declare class IssueVoteGroup extends BaseGroup {
    /**
  * Returns details about the votes on an issue.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  Note that users with the necessary permissions for this operation but without the *View voters and watchers* project permissions are not returned details in the `voters` field.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-get
  * @param options Request options.
  */
    getVotes<T = Issue.Vote.GetVotes.Response.OK>(options: Issue.Vote.GetVotes.Options): Promise<import("./definitions/VotesAsResponse").VotesAsResponse>;
    /**
  * Adds the user's vote to an issue. This is the equivalent of the user clicking *Vote* on an issue in Jira.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-post
  * @param options Request options.
  */
    addVote<T = Issue.Vote.AddVote.Response.OK>(options: Issue.Vote.AddVote.Options): Promise<any>;
    /**
  * Deletes a user's vote from an issue. This is the equivalent of the user clicking *Unvote* on an issue in Jira.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-delete
  * @param options Request options.
  */
    deleteVote<T = Issue.Vote.DeleteVote.Response.OK>(options: Issue.Vote.DeleteVote.Options): Promise<undefined>;
}
declare class IssueWatcherGroup extends BaseGroup {
    /**
  * Returns the watchers for an issue.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To see details of users on the watchlist other than themselves, *View voters and watchers* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-get
  * @param options Request options.
  */
    getWatchers<T = Issue.Watcher.GetWatchers.Response.OK>(options: Issue.Watcher.GetWatchers.Options): Promise<import("./definitions/WatchersAsResponse").WatchersAsResponse>;
    /**
  * Adds a user as a watcher of an issue by passing the account ID of the user. For example, `"5b10ac8d82e05b22cc7d4ef5"`. If no user is specified the calling user is added.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To add users other than themselves to the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-post
  * @param options Request options.
  */
    addWatcher<T = Issue.Watcher.AddWatcher.Response.OK>(options: Issue.Watcher.AddWatcher.Options): Promise<any>;
    /**
  * Deletes a user as a watcher of an issue.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To remove users other than themselves from the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-delete
  * @param options Request options.
  */
    deleteWatcher<T = Issue.Watcher.DeleteWatcher.Response.OK>(options: Issue.Watcher.DeleteWatcher.Options): Promise<undefined>;
}
declare class IssueSearchGroup extends BaseGroup {
    /**
  * Checks whether one or more issues would be returned by one or more JQL queries.
  
  **[Permissions](#permissions) required:** None, however, issues are only matched against JQL queries where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-search-post
  * @param options Request options.
  */
    checkAgainstJql<T = Issue.Search.CheckAgainstJql.Response.OK>(options: Issue.Search.CheckAgainstJql.Options): Promise<import("./definitions/IssueMatchesAsResponse").IssueMatchesAsResponse>;
    /**
  * Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ).
  
  There is a [GET](#api-rest-api-3-search-get) version of this resource that can be used for smaller JQL query expressions.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issues are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-search-get
  * @param options Request options.
  */
    searchByJql<T = Issue.Search.SearchByJql.Response.OK>(options: Issue.Search.SearchByJql.Options): Promise<import("./definitions/SearchResultsAsResponse").SearchResultsAsResponse>;
}
declare class IssuePriorityGroup extends BaseGroup {
    /**
  * Returns the list of all issue priorities.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-priority-get
  * @param options Request options.
  */
    getPriorities<T = Issue.Priority.GetPriorities.Response.OK>(options?: Issue.Priority.GetPriorities.Options): Promise<Issue.Priority.GetPriorities.Response.OK>;
    /**
  * Returns an issue priority.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-priority-id-get
  * @param options Request options.
  */
    getPriority<T = Issue.Priority.GetPriority.Response.OK>(options: Issue.Priority.GetPriority.Options): Promise<import("./definitions/PriorityAsResponse").PriorityAsResponse>;
}
declare class IssueResolutionGroup extends BaseGroup {
    /**
  * Returns a list of all issue resolution values.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-resolution-get
  * @param options Request options.
  */
    getResolutions<T = Issue.Resolution.GetResolutions.Response.OK>(options?: Issue.Resolution.GetResolutions.Options): Promise<Issue.Resolution.GetResolutions.Response.OK>;
    /**
  * Returns an issue resolution value.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-resolution-id-get
  * @param options Request options.
  */
    getResolution<T = Issue.Resolution.GetResolution.Response.OK>(options: Issue.Resolution.GetResolution.Options): Promise<import("./definitions/ResolutionAsResponse").ResolutionAsResponse>;
}
declare class IssueSecurityGroup extends BaseGroup {
    Scheme: IssueSecuritySchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns issue security level members.
  
  Only issue security level members in context of classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuesecurityschemes-issueSecuritySchemeId-members-get
  * @param options Request options.
  */
    getMembers<T = Issue.Security.GetMembers.Response.OK>(options: Issue.Security.GetMembers.Options): Promise<import("./definitions/PageBeanIssueSecurityLevelMemberAsResponse").PageBeanIssueSecurityLevelMemberAsResponse>;
    /**
  * Returns details of an issue security level.
  
  Use [Get issue security scheme](#api-rest-api-3-issuesecurityschemes-id-get) to obtain the IDs of issue security levels associated with the issue security scheme.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-level/#api-rest-api-3-securitylevel-id-get
  * @param options Request options.
  */
    getLevel<T = Issue.Security.GetLevel.Response.OK>(options: Issue.Security.GetLevel.Options): Promise<import("./definitions/SecurityLevelAsResponse").SecurityLevelAsResponse>;
}
declare class IssueSecuritySchemeGroup extends BaseGroup {
    /**
  * Returns all [issue security schemes](https://confluence.atlassian.com/x/J4lKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-get
  * @param options Request options.
  */
    getSchemes<T = Issue.Security.Scheme.GetSchemes.Response.OK>(options?: Issue.Security.Scheme.GetSchemes.Options): Promise<import("./definitions/SecuritySchemesAsResponse").SecuritySchemesAsResponse>;
    /**
  * Returns an issue security scheme along with its security levels.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project that uses the requested issue security scheme.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-id-get
  * @param options Request options.
  */
    getScheme<T = Issue.Security.Scheme.GetScheme.Response.OK>(options: Issue.Security.Scheme.GetScheme.Options): Promise<import("./definitions/SecuritySchemeAsResponse").SecuritySchemeAsResponse>;
}
declare class IssueNotificationGroup extends BaseGroup {
    Scheme: IssueNotificationSchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class IssueNotificationSchemeGroup extends BaseGroup {
    /**
  * Returns a [paginated](#pagination) list of [notification schemes](https://confluence.atlassian.com/x/8YdKLg) ordered by display name.
  
  ### About notification schemes ###
  
  A notification scheme is a list of events and recipients who will receive notifications for those events. The list is contained within the `notificationSchemeEvents` object and contains pairs of `events` and `notifications`:
  
   *  `event` Identifies the type of event. The events can be [Jira system events](https://confluence.atlassian.com/x/8YdKLg#Creatinganotificationscheme-eventsEvents) or [custom events](https://confluence.atlassian.com/x/AIlKLg).
   *  `notifications` Identifies the [recipients](https://confluence.atlassian.com/x/8YdKLg#Creatinganotificationscheme-recipientsRecipients) of notifications for each event. Recipients can be any of the following types:
      
       *  `CurrentAssignee`
       *  `Reporter`
       *  `CurrentUser`
       *  `ProjectLead`
       *  `ComponentLead`
       *  `User` (the `parameter` is the user key)
       *  `Group` (the `parameter` is the group name)
       *  `ProjectRole` (the `parameter` is the project role ID)
       *  `EmailAddress`
       *  `AllWatchers`
       *  `UserCustomField` (the `parameter` is the ID of the custom field)
       *  `GroupCustomField`(the `parameter` is the ID of the custom field)
  
  *Note that you should allow for events without recipients to appear in responses.*
  
  **[Permissions](#permissions) required:** Permission to access Jira, however the user must have permission to administer at least one project associated with a notification scheme for it to be returned.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-notification-schemes/#api-rest-api-3-notificationscheme-get
  * @param options Request options.
  */
    getSchemes<T = Issue.Notification.Scheme.GetSchemes.Response.OK>(options?: Issue.Notification.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanNotificationSchemeAsResponse").PageBeanNotificationSchemeAsResponse>;
    /**
  * Returns a [notification scheme](https://confluence.atlassian.com/x/8YdKLg), including the list of events and the recipients who will receive notifications for those events.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however the user must have permission to administer at least one project associated with the notification scheme.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-notification-schemes/#api-rest-api-3-notificationscheme-id-get
  * @param options Request options.
  */
    getScheme<T = Issue.Notification.Scheme.GetScheme.Response.OK>(options: Issue.Notification.Scheme.GetScheme.Options): Promise<import("./definitions/NotificationSchemeAsResponse").NotificationSchemeAsResponse>;
}
declare class IssueNavigatorGroup extends BaseGroup {
    /**
  * Returns the default issue navigator columns.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-get
  * @param options Request options.
  */
    getDefaultColumns<T = Issue.Navigator.GetDefaultColumns.Response.OK>(options?: Issue.Navigator.GetDefaultColumns.Options): Promise<Issue.Navigator.GetDefaultColumns.Response.OK>;
    /**
  * Sets the default issue navigator columns.
  
  The `columns` parameter accepts a navigable field value and is expressed as HTML form data. To specify multiple columns, pass multiple `columns` parameters. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/settings/columns`
  
  If no column details are sent, then all default columns are removed.
  
  A navigable field is one that can be used as a column on the issue navigator. Find details of navigable issue columns using [Get fields](#api-rest-api-3-field-get).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-put
  * @param options Request options.
  */
    setDefaultColumns<T = Issue.Navigator.SetDefaultColumns.Response.OK>(options: Issue.Navigator.SetDefaultColumns.Options): Promise<any>;
}
declare class DashboardGroup extends BaseGroup {
    Property: DashboardPropertyGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a list of dashboards owned by or shared with the user. The list may be filtered to include only favorite or owned dashboards.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-get
  * @param options Request options.
  */
    getDashboards<T = Dashboard.GetDashboards.Response.OK>(options?: Dashboard.GetDashboards.Options): Promise<import("./definitions/PageOfDashboardsAsResponse").PageOfDashboardsAsResponse>;
    /**
  * Creates a dashboard.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-post
  * @param options Request options.
  */
    createDashboard<T = Dashboard.CreateDashboard.Response.OK>(options: Dashboard.CreateDashboard.Options): Promise<import("./definitions/DashboardAsResponse").DashboardAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of dashboards. This operation is similar to [Get dashboards](#api-rest-api-3-dashboard-get) except that the results can be refined to include dashboards that have specific attributes. For example, dashboards with a particular name. When multiple attributes are specified only filters matching all attributes are returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The following dashboards that match the query parameters are returned:
  
   *  Dashboards owned by the user. Not returned for anonymous users.
   *  Dashboards shared with a group that the user is a member of. Not returned for anonymous users.
   *  Dashboards shared with a private project that the user can browse. Not returned for anonymous users.
   *  Dashboards shared with a public project.
   *  Dashboards shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-search-get
  * @param options Request options.
  */
    searchDashboards<T = Dashboard.SearchDashboards.Response.OK>(options?: Dashboard.SearchDashboards.Options): Promise<import("./definitions/PageBeanDashboardAsResponse").PageBeanDashboardAsResponse>;
    /**
  * Returns a dashboard.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  
  However, to get a dashboard, the dashboard must be shared with the user or the user must own it. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-get
  * @param options Request options.
  */
    getDashboard<T = Dashboard.GetDashboard.Response.OK>(options: Dashboard.GetDashboard.Options): Promise<import("./definitions/DashboardAsResponse").DashboardAsResponse>;
    /**
  * Updates a dashboard, replacing all the dashboard details with those provided.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be updated must be owned by the user.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-put
  * @param options Request options.
  */
    updateDashboard<T = Dashboard.UpdateDashboard.Response.OK>(options: Dashboard.UpdateDashboard.Options): Promise<import("./definitions/DashboardAsResponse").DashboardAsResponse>;
    /**
  * Deletes a dashboard.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be deleted must be owned by the user.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-delete
  * @param options Request options.
  */
    deleteDashboard<T = Dashboard.DeleteDashboard.Response.OK>(options: Dashboard.DeleteDashboard.Options): Promise<undefined>;
    /**
  * Copies a dashboard. Any values provided in the `dashboard` parameter replace those in the copied dashboard.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be copied must be owned by or shared with the user.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-copy-post
  * @param options Request options.
  */
    copyDashboard<T = Dashboard.CopyDashboard.Response.OK>(options: Dashboard.CopyDashboard.Options): Promise<import("./definitions/DashboardAsResponse").DashboardAsResponse>;
}
declare class DashboardPropertyGroup extends BaseGroup {
    /**
  * Returns the keys of all properties for a dashboard item.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira’s anonymous access is permitted.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-get
  * @param options Request options.
  */
    getPropertyKeys<T = Dashboard.Property.GetPropertyKeys.Response.OK>(options: Dashboard.Property.GetPropertyKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the key and value of a dashboard item property.
  
  A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
  
  When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
  
  There is no resource to set or get dashboard items.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira’s anonymous access is permitted.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-get
  * @param options Request options.
  */
    getProperty<T = Dashboard.Property.GetProperty.Response.OK>(options: Dashboard.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of a dashboard item property. Use this resource in apps to store custom data against a dashboard item.
  
  A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
  
  When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
  
  There is no resource to set or get dashboard items.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-put
  * @param options Request options.
  */
    setProperty<T = Dashboard.Property.SetProperty.Response.OK>(options: Dashboard.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes a dashboard item property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-delete
  * @param options Request options.
  */
    deleteProperty<T = Dashboard.Property.DeleteProperty.Response.OK>(options: Dashboard.Property.DeleteProperty.Options): Promise<undefined>;
}
declare class ApplicationGroup extends BaseGroup {
    Role: ApplicationRoleGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class ApplicationRoleGroup extends BaseGroup {
    /**
  * Returns all application roles. In Jira, application roles are managed using the [Application access configuration](https://confluence.atlassian.com/x/3YxjL) page.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-get
  * @param options Request options.
  */
    getRoles<T = Application.Role.GetRoles.Response.OK>(options?: Application.Role.GetRoles.Options): Promise<Application.Role.GetRoles.Response.OK>;
    /**
  * Returns an application role.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-key-get
  * @param options Request options.
  */
    getRole<T = Application.Role.GetRole.Response.OK>(options: Application.Role.GetRole.Options): Promise<import("./definitions/ApplicationRoleAsResponse").ApplicationRoleAsResponse>;
}
declare class UserGroup extends BaseGroup {
    Search: UserSearchGroup;
    Property: UserPropertyGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns the default [issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If `accountId` is not passed in the request, the calling user's details are returned.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLgl), to get the column details for any user.
   *  Permission to access Jira, to get the calling user's column details.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-get
  * @param options Request options.
  */
    getDefaultColumns<T = User.GetDefaultColumns.Response.OK>(options?: User.GetDefaultColumns.Options): Promise<User.GetDefaultColumns.Response.OK>;
    /**
  * Sets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If an account ID is not passed, the calling user's default columns are set. If no column details are sent, then all default columns are removed.
  
  The parameters for this resource are expressed as HTML form data. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/user/columns?accountId=5b10ac8d82e05b22cc7d4ef5'`
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
   *  Permission to access Jira, to set the calling user's columns.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-put
  * @param options Request options.
  */
    setDefaultColumns<T = User.SetDefaultColumns.Response.OK>(options: User.SetDefaultColumns.Options): Promise<any>;
    /**
  * Resets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user to the system default. If `accountId` is not passed, the calling user's default columns are reset.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
   *  Permission to access Jira, to set the calling user's columns.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-delete
  * @param options Request options.
  */
    resetDefaultColumns<T = User.ResetDefaultColumns.Response.OK>(options?: User.ResetDefaultColumns.Options): Promise<undefined>;
    /**
  * Returns a user.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-get
  * @param options Request options.
  */
    getUser<T = User.GetUser.Response.OK>(options?: User.GetUser.Options): Promise<import("./definitions/UserAsResponse").UserAsResponse>;
    /**
  * Creates a user. This resource is retained for legacy compatibility. As soon as a more suitable alternative is available this resource will be deprecated.
  
  If the user exists and has access to Jira, the operation returns a 201 status. If the user exists but does not have access to Jira, the operation returns a 400 status.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-post
  * @param options Request options.
  */
    createUser<T = User.CreateUser.Response.OK>(options: User.CreateUser.Options): Promise<import("./definitions/UserAsResponse").UserAsResponse>;
    /**
  * Deletes a user.
  
  **[Permissions](#permissions) required:** Site administration (that is, membership of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-delete
  * @param options Request options.
  */
    deleteUser<T = User.DeleteUser.Response.OK>(options: User.DeleteUser.Options): Promise<undefined>;
    /**
  * Returns the account IDs for the users specified in the `key` or `username` parameters. Note that multiple `key` or `username` parameters can be specified.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-bulk-migration-get
  * @param options Request options.
  */
    getAccountIdsForUsers<T = User.GetAccountIdsForUsers.Response.OK>(options?: User.GetAccountIdsForUsers.Options): Promise<User.GetAccountIdsForUsers.Response.OK>;
    /**
     * Returns a user's email address. This API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-email-get
     * @param options Request options.
     */
    getEmail<T = User.GetEmail.Response.OK>(options: User.GetEmail.Options): Promise<import("./definitions/UnrestrictedUserEmailAsResponse").UnrestrictedUserEmailAsResponse>;
    /**
  * Returns the groups to which a user belongs.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-groups-get
  * @param options Request options.
  */
    getGroups<T = User.GetGroups.Response.OK>(options: User.GetGroups.Options): Promise<User.GetGroups.Response.OK>;
    /**
  * Returns a list of all (active and inactive) users.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-users-search-get
  * @param options Request options.
  */
    getUsers<T = User.GetUsers.Response.OK>(options?: User.GetUsers.Options): Promise<User.GetUsers.Response.OK>;
}
declare class UserSearchGroup extends BaseGroup {
    /**
  * Returns a list of users who can be assigned issues in one or more projects. The list may be restricted to users whose attributes match a string.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned issues in the projects. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned issues in the projects, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-assignable-multiProjectSearch-get
  * @param options Request options.
  */
    findUsersAssignableToProjects<T = User.Search.FindUsersAssignableToProjects.Response.OK>(options: User.Search.FindUsersAssignableToProjects.Options): Promise<User.Search.FindUsersAssignableToProjects.Response.OK>;
    /**
  * Returns a list of users that can be assigned to an issue. Use this operation to find the list of users who can be assigned to:
  
   *  a new issue, by providing the `projectKeyOrId`.
   *  an updated issue, by providing the `issueKey`.
   *  to an issue during a transition (workflow action), by providing the `issueKey` and the transition id in `actionDescriptorId`. You can obtain the IDs of an issue's valid transitions using the `transitions` option in the `expand` parameter of [ Get issue](#api-rest-api-3-issue-issueIdOrKey-get).
  
  In all these cases, you can pass an account ID to determine if a user can be assigned to an issue. The user is returned in the response if they can be assigned to the issue or issue transition.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned the issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned the issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-assignable-search-get
  * @param options Request options.
  */
    findUsersAssignableToIssues<T = User.Search.FindUsersAssignableToIssues.Response.OK>(options?: User.Search.FindUsersAssignableToIssues.Options): Promise<User.Search.FindUsersAssignableToIssues.Response.OK>;
    /**
  * Returns a list of users who fulfill these criteria:
  
   *  their user attributes match a search string.
   *  they have a set of permissions for a project or issue.
  
  If no search string is provided, a list of all users with the permissions is returned.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission for the project or issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission for the project or issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get users for any project.
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project, to get users for that project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-permission-search-get
  * @param options Request options.
  */
    findUsersWithPermissions<T = User.Search.FindUsersWithPermissions.Response.OK>(options: User.Search.FindUsersWithPermissions.Options): Promise<User.Search.FindUsersWithPermissions.Response.OK>;
    /**
  * Returns a list of users whose attributes match the query term. The returned object includes the `html` field where the matched query term is highlighted with the HTML strong tag. A list of account IDs can be provided to exclude users from the results.
  
  This operation takes the users in the range defined by `maxResults`, up to the thousandth user, and then returns only the users from that range that match the query term. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the query term, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return search results for an exact name match only.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-picker-get
  * @param options Request options.
  */
    findUsersForPicker<T = User.Search.FindUsersForPicker.Response.OK>(options: User.Search.FindUsersForPicker.Options): Promise<import("./definitions/FoundUsersAsResponse").FoundUsersAsResponse>;
    /**
  * Returns a list of users that match the search string and property.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and property. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and property, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls or calls by users without the required permission return empty search results.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-search-get
  * @param options Request options.
  */
    findUsers<T = User.Search.FindUsers.Response.OK>(options?: User.Search.FindUsers.Options): Promise<User.Search.FindUsers.Response.OK>;
    /**
  * Finds users with a structured query and returns a [paginated](#pagination) list of user details.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  
  The query statements are:
  
   *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
   *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
   *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
   *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
   *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
   *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
   *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
   *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value.
  
  The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
  
  `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-search-query-get
  * @param options Request options.
  */
    findUsersByQuery<T = User.Search.FindUsersByQuery.Response.OK>(options: User.Search.FindUsersByQuery.Options): Promise<import("./definitions/PageBeanUserAsResponse").PageBeanUserAsResponse>;
    /**
  * Finds users with a structured query and returns a [paginated](#pagination) list of user keys.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  
  The query statements are:
  
   *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
   *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
   *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
   *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
   *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
   *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
   *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
   *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value.
  
  The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
  
  `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-search-query-key-get
  * @param options Request options.
  */
    findUserKeysByQuery<T = User.Search.FindUserKeysByQuery.Response.OK>(options: User.Search.FindUserKeysByQuery.Options): Promise<import("./definitions/PageBeanUserKeyAsResponse").PageBeanUserKeyAsResponse>;
    /**
  * Returns a list of users who fulfill these criteria:
  
   *  their user attributes match a search string.
   *  they have permission to browse issues.
  
  Use this resource to find users who can browse:
  
   *  an issue, by providing the `issueKey`.
   *  any issue in a project, by providing the `projectKey`.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission to browse issues. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission to browse issues, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return empty search results.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-viewissue-search-get
  * @param options Request options.
  */
    findUsersWithBrowsePermission<T = User.Search.FindUsersWithBrowsePermission.Response.OK>(options?: User.Search.FindUsersWithBrowsePermission.Options): Promise<User.Search.FindUsersWithBrowsePermission.Response.OK>;
}
declare class UserPropertyGroup extends BaseGroup {
    /**
  * Returns the keys of all properties for a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to access the property keys on any user.
   *  Access to Jira, to access the calling user's property keys.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-get
  * @param options Request options.
  */
    getPropertyKeys<T = User.Property.GetPropertyKeys.Response.OK>(options: User.Property.GetPropertyKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the value of a user's property.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get a property from any user.
   *  Access to Jira, to get a property from the calling user's record.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-get
  * @param options Request options.
  */
    getProperty<T = User.Property.GetProperty.Response.OK>(options: User.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of a user's property. Use this resource to store custom data against a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set a property on any user.
   *  Access to Jira, to set a property on the calling user's record.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-put
  * @param options Request options.
  */
    setProperty<T = User.Property.SetProperty.Response.OK>(options: User.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes a property from a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to delete a property from any user.
   *  Access to Jira, to delete a property from the calling user's record.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-delete
  * @param options Request options.
  */
    deleteProperty<T = User.Property.DeleteProperty.Response.OK>(options: User.Property.DeleteProperty.Options): Promise<undefined>;
}
declare class InstanceGroup extends BaseGroup {
    /**
  * Changes the value of an application property. For example, you can change the value of the `jira.clone.prefix` from its default value of *CLONE -* to *Clone -* if you prefer sentence case capitalization. Editable properties are described below along with their default values.
  
  #### Advanced settings ####
  
  The advanced settings below are also accessible in [Jira](https://confluence.atlassian.com/x/vYXKM).
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.clone.prefix` | The string of text prefixed to the title of a cloned issue. | `CLONE -` |
  | `jira.date.picker.java.format` | The date format for the Java (server-side) generated dates. This must be the same as the `jira.date.picker.javascript.format` format setting. | `d/MMM/yy` |
  | `jira.date.picker.javascript.format` | The date format for the JavaScript (client-side) generated dates. This must be the same as the `jira.date.picker.java.format` format setting. | `%e/%b/%y` |
  | `jira.date.time.picker.java.format` | The date format for the Java (server-side) generated date times. This must be the same as the `jira.date.time.picker.javascript.format` format setting. | `dd/MMM/yy h:mm a` |
  | `jira.date.time.picker.javascript.format` | The date format for the JavaScript (client-side) generated date times. This must be the same as the `jira.date.time.picker.java.format` format setting. | `%e/%b/%y %I:%M %p` |
  | `jira.issue.actions.order` | The default order of actions (such as *Comments* or *Change history*) displayed on the issue view. | `asc` |
  | `jira.table.cols.subtasks` | The columns to show while viewing subtask issues in a table. For example, a list of subtasks on an issue. | `issuetype, status, assignee, progress` |
  | `jira.view.issue.links.sort.order` | The sort order of the list of issue links on the issue view. | `type, status, priority` |
  | `jira.comment.collapsing.minimum.hidden` | The minimum number of comments required for comment collapsing to occur. A value of `0` disables comment collapsing. | `4` |
  | `jira.newsletter.tip.delay.days` | The number of days before a prompt to sign up to the Jira Insiders newsletter is shown. A value of `-1` disables this feature. | `7` |
  
  
  #### Look and feel ####
  
  The settings listed below adjust the [look and feel](https://confluence.atlassian.com/x/VwCLLg).
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.lf.date.time` | The [ time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `h:mm a` |
  | `jira.lf.date.day` | The [ day format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `EEEE h:mm a` |
  | `jira.lf.date.complete` | The [ date and time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy h:mm a` |
  | `jira.lf.date.dmy` | The [ date format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy` |
  | `jira.date.time.picker.use.iso8061` | When enabled, sets Monday as the first day of the week in the date picker, as specified by the ISO8601 standard. | `false` |
  | `jira.lf.logo.url` | The URL of the logo image file. | `/images/icon-jira-logo.png` |
  | `jira.lf.logo.show.application.title` | Controls the visibility of the application title on the sidebar. | `false` |
  | `jira.lf.favicon.url` | The URL of the favicon. | `/favicon.ico` |
  | `jira.lf.favicon.hires.url` | The URL of the high-resolution favicon. | `/images/64jira.png` |
  | `jira.lf.navigation.bgcolour` | The background color of the sidebar. | `#0747A6` |
  | `jira.lf.navigation.highlightcolour` | The color of the text and logo of the sidebar. | `#DEEBFF` |
  | `jira.lf.hero.button.base.bg.colour` | The background color of the hero button. | `#3b7fc4` |
  | `jira.title` | The text for the application title. The application title can also be set in *General settings*. | `Jira` |
  | `jira.option.globalsharing` | Whether filters and dashboards can be shared with anyone signed into Jira. | `true` |
  | `xflow.product.suggestions.enabled` | Whether to expose product suggestions for other Atlassian products within Jira. | `true` |
  
  
  #### Other settings ####
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.issuenav.criteria.autoupdate` | Whether instant updates to search criteria is active. | `true` |
  
  
  *Note: Be careful when changing [application properties and advanced settings](https://confluence.atlassian.com/x/vYXKM).*
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-application-properties-id-put
  * @param options Request options.
  */
    setApplicationProperty<T = Instance.SetApplicationProperty.Response.OK>(options: Instance.SetApplicationProperty.Options): Promise<import("./definitions/ApplicationPropertyAsResponse").ApplicationPropertyAsResponse>;
    /**
  * Returns all application properties or an application property.
  
  If you specify a value for the `key` parameter, then an application property is returned as an object (not in an array). Otherwise, an array of all editable application properties is returned. See [Set application property](#api-rest-api-3-application-properties-id-put) for descriptions of editable properties.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-application-properties-get
  * @param options Request options.
  */
    getApplicationProperty<T = Instance.GetApplicationProperty.Response.OK>(options?: Instance.GetApplicationProperty.Options): Promise<Instance.GetApplicationProperty.Response.OK>;
    /**
  * Returns the application properties that are accessible on the *Advanced Settings* page. To navigate to the *Advanced Settings* page in Jira, choose the Jira icon > **Jira settings** > **System**, **General Configuration** and then click **Advanced Settings** (in the upper right).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-application-properties-advanced-settings-get
  * @param options Request options.
  */
    getAdvancedSettings<T = Instance.GetAdvancedSettings.Response.OK>(options?: Instance.GetAdvancedSettings.Options): Promise<Instance.GetAdvancedSettings.Response.OK>;
    /**
  * Returns the attachment settings, that is, whether attachments are enabled and the maximum attachment size allowed.
  
  Note that there are also [project permissions](https://confluence.atlassian.com/x/yodKLg) that restrict whether users can create and delete attachments.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-meta-get
  * @param options Request options.
  */
    getAttachmentSettings<T = Instance.GetAttachmentSettings.Response.OK>(options?: Instance.GetAttachmentSettings.Options): Promise<import("./definitions/AttachmentSettingsAsResponse").AttachmentSettingsAsResponse>;
    /**
  * Returns the [global settings](https://confluence.atlassian.com/x/qYXKM) in Jira. These settings determine whether optional features (for example, subtasks, time tracking, and others) are enabled. If time tracking is enabled, this operation also returns the time tracking configuration.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-configuration-get
  * @param options Request options.
  */
    getGlobalSettings<T = Instance.GetGlobalSettings.Response.OK>(options?: Instance.GetGlobalSettings.Options): Promise<import("./definitions/ConfigurationAsResponse").ConfigurationAsResponse>;
    /**
  * Returns information about the Jira instance.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-serverInfo-get
  * @param options Request options.
  */
    getInfo<T = Instance.GetInfo.Response.OK>(options?: Instance.GetInfo.Options): Promise<import("./definitions/ServerInformationAsResponse").ServerInformationAsResponse>;
    /**
  * Returns licensing information about the Jira instance.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-instance-information/#api-rest-api-3-instance-license-get
  * @param options Request options.
  */
    getLicense<T = Instance.GetLicense.Response.OK>(options?: Instance.GetLicense.Options): Promise<import("./definitions/LicenseAsResponse").LicenseAsResponse>;
}
declare class ProjectGroup extends BaseGroup {
    Component: ProjectComponentGroup;
    Role: ProjectRoleGroup;
    Version: ProjectVersionGroup;
    IssueType: ProjectIssueTypeGroup;
    Validation: ProjectValidationGroup;
    Type: ProjectTypeGroup;
    Category: ProjectCategoryGroup;
    Notification: ProjectNotificationGroup;
    Permission: ProjectPermissionGroup;
    Security: ProjectSecurityGroup;
    Property: ProjectPropertyGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Creates a project based on a project type template, as shown in the following table:
  
  | Project Type Key | Project Template Key |
  |--|--|
  | `business` | `com.atlassian.jira-core-project-templates:jira-core-simplified-content-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-document-approval`, `com.atlassian.jira-core-project-templates:jira-core-simplified-lead-tracking`, `com.atlassian.jira-core-project-templates:jira-core-simplified-process-control`, `com.atlassian.jira-core-project-templates:jira-core-simplified-procurement`, `com.atlassian.jira-core-project-templates:jira-core-simplified-project-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-recruitment`, `com.atlassian.jira-core-project-templates:jira-core-simplified-task-tracking` |
  | `service_desk` | `com.atlassian.servicedesk:simplified-it-service-management`, `com.atlassian.servicedesk:simplified-general-service-desk`, `com.atlassian.servicedesk:simplified-internal-service-desk`, `com.atlassian.servicedesk:simplified-external-service-desk`, `com.atlassian.servicedesk:simplified-hr-service-desk`, `com.atlassian.servicedesk:simplified-facilities-service-desk`, `com.atlassian.servicedesk:simplified-legal-service-desk` |
  | `software` | `com.pyxis.greenhopper.jira:gh-simplified-agility-kanban`, `com.pyxis.greenhopper.jira:gh-simplified-agility-scrum`, `com.pyxis.greenhopper.jira:gh-simplified-basic`, `com.pyxis.greenhopper.jira:gh-simplified-kanban-classic`, `com.pyxis.greenhopper.jira:gh-simplified-scrum-classic` |
  The project types are available according to the installed Jira features as follows:
  
   *  Jira Core, the default, enables `business` projects.
   *  Jira Service Management enables `service_desk` projects.
   *  Jira Software enables `software` projects.
  
  To determine which features are installed, go to **Jira settings** > **Apps** > **Manage apps** and review the System Apps list. To add Jira Software or Jira Service Management into a JIRA instance, use **Jira settings** > **Apps** > **Finding new apps**. For more information, see [ Managing add-ons](https://confluence.atlassian.com/x/S31NLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-post
  * @param options Request options.
  */
    createProject<T = Project.CreateProject.Response.OK>(options: Project.CreateProject.Options): Promise<import("./definitions/ProjectIdentifiersAsResponse").ProjectIdentifiersAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of projects visible to the user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Projects are returned only where the user has one of:
  
   *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-search-get
  * @param options Request options.
  */
    getProjects<T = Project.GetProjects.Response.OK>(options?: Project.GetProjects.Options): Promise<import("./definitions/PageBeanProjectAsResponse").PageBeanProjectAsResponse>;
    /**
  * Returns the [project details](https://confluence.atlassian.com/x/ahLpNw) for a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-get
  * @param options Request options.
  */
    getProject<T = Project.GetProject.Response.OK>(options: Project.GetProject.Options): Promise<import("./definitions/ProjectAsResponse").ProjectAsResponse>;
    /**
  * Updates the [project details](https://confluence.atlassian.com/x/ahLpNw) of a project.
  
  All parameters are optional in the body of the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-put
  * @param options Request options.
  */
    updateProject<T = Project.UpdateProject.Response.OK>(options: Project.UpdateProject.Options): Promise<import("./definitions/ProjectAsResponse").ProjectAsResponse>;
    /**
  * Deletes a project.
  
  You can't delete a project if it's archived. To delete an archived project, restore the project and then delete it. To restore a project, use the Jira UI.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-delete
  * @param options Request options.
  */
    deleteProject<T = Project.DeleteProject.Response.OK>(options: Project.DeleteProject.Options): Promise<undefined>;
    /**
  * Returns the valid statuses for a project. The statuses are grouped by issue type, as each project has a set of valid issue types and each issue type has a set of valid statuses.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-statuses-get
  * @param options Request options.
  */
    getStatuses<T = Project.GetStatuses.Response.OK>(options: Project.GetStatuses.Options): Promise<Project.GetStatuses.Response.OK>;
}
declare class ProjectComponentGroup extends BaseGroup {
    /**
  * Creates a component. Use components to provide containers for issues within a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-post
  * @param options Request options.
  */
    createComponent<T = Project.Component.CreateComponent.Response.OK>(options: Project.Component.CreateComponent.Options): Promise<import("./definitions/ProjectComponentAsResponse").ProjectComponentAsResponse>;
    /**
  * Returns a component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-get
  * @param options Request options.
  */
    getComponent<T = Project.Component.GetComponent.Response.OK>(options: Project.Component.GetComponent.Options): Promise<import("./definitions/ProjectComponentAsResponse").ProjectComponentAsResponse>;
    /**
  * Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-put
  * @param options Request options.
  */
    updateComponent<T = Project.Component.UpdateComponent.Response.OK>(options: Project.Component.UpdateComponent.Options): Promise<import("./definitions/ComponentAsResponse").ComponentAsResponse>;
    /**
  * Deletes a component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-delete
  * @param options Request options.
  */
    deleteComponent<T = Project.Component.DeleteComponent.Response.OK>(options: Project.Component.DeleteComponent.Options): Promise<undefined>;
    /**
  * Returns the counts of issues assigned to the component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-relatedIssueCounts-get
  * @param options Request options.
  */
    getIssueCount<T = Project.Component.GetIssueCount.Response.OK>(options: Project.Component.GetIssueCount.Options): Promise<import("./definitions/ComponentIssuesCountAsResponse").ComponentIssuesCountAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-component-get
  * @param options Request options.
  */
    getComponentsPaginated<T = Project.Component.GetComponentsPaginated.Response.OK>(options: Project.Component.GetComponentsPaginated.Options): Promise<import("./definitions/PageBeanComponentWithIssueCountAsResponse").PageBeanComponentWithIssueCountAsResponse>;
    /**
  * Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-components-get
  * @param options Request options.
  */
    getComponents<T = Project.Component.GetComponents.Response.OK>(options: Project.Component.GetComponents.Options): Promise<Project.Component.GetComponents.Response.OK>;
}
declare class ProjectRoleGroup extends BaseGroup {
    Actor: ProjectRoleActorGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a list of [project roles](https://confluence.atlassian.com/x/3odKLg) for the project returning the name and self URL for each role.
  
  Note that all project roles are shared with all projects in Jira Cloud. See [Get all project roles](#api-rest-api-3-role-get) for more information.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for any project on the site or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-get
  * @param options Request options.
  */
    getRolesForProject<T = Project.Role.GetRolesForProject.Response.OK>(options: Project.Role.GetRolesForProject.Options): Promise<Project.Role.GetRolesForProject.Response.OK>;
    /**
  * Returns a project role's details and actors associated with the project. The list of actors is sorted by display name.
  
  To check whether a user belongs to a role based on their group memberships, use [Get user](#api-rest-api-3-user-get) with the `groups` expand parameter selected. Then check whether the user keys and groups match with the actors returned for the project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-get
  * @param options Request options.
  */
    getRoleForProject<T = Project.Role.GetRoleForProject.Response.OK>(options: Project.Role.GetRoleForProject.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Returns all [project roles](https://confluence.atlassian.com/x/3odKLg) and the details for each role. Note that the list of project roles is common to all projects.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-roledetails-get
  * @param options Request options.
  */
    getDetails<T = Project.Role.GetDetails.Response.OK>(options: Project.Role.GetDetails.Options): Promise<Project.Role.GetDetails.Response.OK>;
    /**
  * Gets a list of all project roles, complete with project role details and default actors.
  
  ### About project roles ###
  
  [Project roles](https://confluence.atlassian.com/x/3odKLg) are a flexible way to to associate users and groups with projects. In Jira Cloud, the list of project roles is shared globally with all projects, but each project can have a different set of actors associated with it (unlike groups, which have the same membership throughout all Jira applications).
  
  Project roles are used in [permission schemes](#api-rest-api-3-permissionscheme-get), [email notification schemes](#api-rest-api-3-notificationscheme-get), [issue security levels](#api-rest-api-3-issuesecurityschemes-get), [comment visibility](#api-rest-api-3-comment-list-post), and workflow conditions.
  
  #### Members and actors ####
  
  In the Jira REST API, a member of a project role is called an *actor*. An *actor* is a group or user associated with a project role.
  
  Actors may be set as [default members](https://confluence.atlassian.com/x/3odKLg#Managingprojectroles-Specifying'defaultmembers'foraprojectrole) of the project role or set at the project level:
  
   *  Default actors: Users and groups that are assigned to the project role for all newly created projects. The default actors can be removed at the project level later if desired.
   *  Actors: Users and groups that are associated with a project role for a project, which may differ from the default actors. This enables you to assign a user to different roles in different projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-get
  * @param options Request options.
  */
    getRoles<T = Project.Role.GetRoles.Response.OK>(options?: Project.Role.GetRoles.Options): Promise<Project.Role.GetRoles.Response.OK>;
    /**
  * Creates a new project role with no [default actors](#api-rest-api-3-resolution-get). You can use the [Add default actors to project role](#api-rest-api-3-role-id-actors-post) operation to add default actors to the project role after creating it.
  
  *Note that although a new project role is available to all projects upon creation, any default actors that are associated with the project role are not added to projects that existed prior to the role being created.*<
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-post
  * @param options Request options.
  */
    createRole<T = Project.Role.CreateRole.Response.OK>(options: Project.Role.CreateRole.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Gets the project role details and the default actors associated with the role. The list of default actors is sorted by display name.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-get
  * @param options Request options.
  */
    getRole<T = Project.Role.GetRole.Response.OK>(options: Project.Role.GetRole.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Updates the project role's name and description. You must include both a name and a description in the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-put
  * @param options Request options.
  */
    fullyUpdateRole<T = Project.Role.FullyUpdateRole.Response.OK>(options: Project.Role.FullyUpdateRole.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Updates either the project role's name or its description.
  
  You cannot update both the name and description at the same time using this operation. If you send a request with a name and a description only the name is updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-post
  * @param options Request options.
  */
    partiallyUpdateRole<T = Project.Role.PartiallyUpdateRole.Response.OK>(options: Project.Role.PartiallyUpdateRole.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Deletes a project role. You must specify a replacement project role if you wish to delete a project role that is in use.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-delete
  * @param options Request options.
  */
    deleteRole<T = Project.Role.DeleteRole.Response.OK>(options: Project.Role.DeleteRole.Options): Promise<undefined>;
}
declare class ProjectRoleActorGroup extends BaseGroup {
    Default: ProjectRoleActorDefaultGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Sets the actors for a project role for a project, replacing all existing actors.
  
  To add actors to the project without overwriting the existing list, use [Add actors to project role](#api-rest-api-3-project-projectIdOrKey-role-id-post).
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-put
  * @param options Request options.
  */
    setActors<T = Project.Role.Actor.SetActors.Response.OK>(options: Project.Role.Actor.SetActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Adds actors to a project role for the project.
  
  To replace all actors for the project, use [Set actors for project role](#api-rest-api-3-project-projectIdOrKey-role-id-put).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-post
  * @param options Request options.
  */
    addActors<T = Project.Role.Actor.AddActors.Response.OK>(options: Project.Role.Actor.AddActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Deletes actors from a project role for the project.
  
  To remove default actors from the project role, use [Delete default actors from project role](#api-rest-api-3-role-id-actors-delete).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-delete
  * @param options Request options.
  */
    deleteActors<T = Project.Role.Actor.DeleteActors.Response.OK>(options: Project.Role.Actor.DeleteActors.Options): Promise<undefined>;
}
declare class ProjectRoleActorDefaultGroup extends BaseGroup {
    /**
  * Returns the [default actors](#api-rest-api-3-resolution-get) for the project role.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-get
  * @param options Request options.
  */
    getActors<T = Project.Role.Actor.Default.GetActors.Response.OK>(options: Project.Role.Actor.Default.GetActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Adds [default actors](#api-rest-api-3-resolution-get) to a role. You may add groups or users, but you cannot add groups and users in the same request.
  
  Changing a project role's default actors does not affect project role members for projects already created.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-post
  * @param options Request options.
  */
    addActors<T = Project.Role.Actor.Default.AddActors.Response.OK>(options: Project.Role.Actor.Default.AddActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Deletes the [default actors](#api-rest-api-3-resolution-get) from a project role. You may delete a group or user, but you cannot delete a group and a user in the same request.
  
  Changing a project role's default actors does not affect project role members for projects already created.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-delete
  * @param options Request options.
  */
    deleteActors<T = Project.Role.Actor.Default.DeleteActors.Response.OK>(options: Project.Role.Actor.Default.DeleteActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
}
declare class ProjectVersionGroup extends BaseGroup {
    Count: ProjectVersionCountGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a [paginated](#pagination) list of all versions in a project. See the [Get project versions](#api-rest-api-3-project-projectIdOrKey-versions-get) resource if you want to get a full list of versions without pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-version-get
  * @param options Request options.
  */
    getVersionsPaginated<T = Project.Version.GetVersionsPaginated.Response.OK>(options: Project.Version.GetVersionsPaginated.Options): Promise<import("./definitions/PageBeanVersionAsResponse").PageBeanVersionAsResponse>;
    /**
  * Returns all versions in a project. The response is not paginated. Use [Get project versions paginated](#api-rest-api-3-project-projectIdOrKey-version-get) if you want to get the versions in a project with pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-versions-get
  * @param options Request options.
  */
    getVersions<T = Project.Version.GetVersions.Response.OK>(options: Project.Version.GetVersions.Options): Promise<Project.Version.GetVersions.Response.OK>;
    /**
  * Creates a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the version is added to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-post
  * @param options Request options.
  */
    createVersion<T = Project.Version.CreateVersion.Response.OK>(options: Project.Version.CreateVersion.Options): Promise<import("./definitions/VersionAsResponse").VersionAsResponse>;
    /**
  * Returns a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-get
  * @param options Request options.
  */
    getVersion<T = Project.Version.GetVersion.Response.OK>(options: Project.Version.GetVersion.Options): Promise<import("./definitions/VersionAsResponse").VersionAsResponse>;
    /**
  * Updates a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-put
  * @param options Request options.
  */
    updateVersion<T = Project.Version.UpdateVersion.Response.OK>(options: Project.Version.UpdateVersion.Options): Promise<import("./definitions/VersionAsResponse").VersionAsResponse>;
    /**
  * Merges two project versions. The merge is completed by deleting the version specified in `id` and replacing any occurrences of its ID in `fixVersion` with the version ID specified in `moveIssuesTo`.
  
  Consider using [ Delete and replace version](#api-rest-api-3-version-id-removeAndSwap-post) instead. This resource supports swapping version values in `fixVersion`, `affectedVersion`, and custom fields.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-mergeto-moveIssuesTo-put
  * @param options Request options.
  */
    mergeVersions<T = Project.Version.MergeVersions.Response.OK>(options: Project.Version.MergeVersions.Options): Promise<any>;
    /**
  * Modifies the version's sequence within the project, which affects the display order of the versions in Jira.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-move-post
  * @param options Request options.
  */
    moveVersion<T = Project.Version.MoveVersion.Response.OK>(options: Project.Version.MoveVersion.Options): Promise<import("./definitions/VersionAsResponse").VersionAsResponse>;
    /**
  * Deletes a project version.
  
  Alternative versions can be provided to update issues that use the deleted version in `fixVersion`, `affectedVersion`, or any version picker custom fields. If alternatives are not provided, occurrences of `fixVersion`, `affectedVersion`, and any version picker custom field, that contain the deleted version, are cleared. Any replacement version must be in the same project as the version being deleted and cannot be the version being deleted.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-removeAndSwap-post
  * @param options Request options.
  */
    deleteAndReplaceVersion<T = Project.Version.DeleteAndReplaceVersion.Response.OK>(options: Project.Version.DeleteAndReplaceVersion.Options): Promise<any>;
}
declare class ProjectVersionCountGroup extends BaseGroup {
    /**
  * Returns the following counts for a version:
  
   *  Number of issues where the `fixVersion` is set to the version.
   *  Number of issues where the `affectedVersion` is set to the version.
   *  Number of issues where a version custom field is set to the version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-relatedIssueCounts-get
  * @param options Request options.
  */
    getRelatedIssueCount<T = Project.Version.Count.GetRelatedIssueCount.Response.OK>(options: Project.Version.Count.GetRelatedIssueCount.Options): Promise<import("./definitions/VersionIssueCountsAsResponse").VersionIssueCountsAsResponse>;
    /**
  * Returns counts of the issues and unresolved issues for the project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-unresolvedIssueCount-get
  * @param options Request options.
  */
    getUnresolvedIssueCount<T = Project.Version.Count.GetUnresolvedIssueCount.Response.OK>(options: Project.Version.Count.GetUnresolvedIssueCount.Options): Promise<import("./definitions/VersionUnresolvedIssuesCountAsResponse").VersionUnresolvedIssuesCountAsResponse>;
}
declare class ProjectIssueTypeGroup extends BaseGroup {
    /**
  * Get the issue type hierarchy for a next-gen project.
  
  The issue type hierarchy for a project consists of:
  
   *  *Epic* at level 1 (optional).
   *  One or more issue types at level 0 such as *Story*, *Task*, or *Bug*. Where the issue type *Epic* is defined, these issue types are used to break down the content of an epic.
   *  *Subtask* at level -1 (optional). This issue type enables level 0 issue types to be broken down into components. Issues based on a level -1 issue type must have a parent issue.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectId-hierarchy-get
  * @param options Request options.
  * @deprecated
  */
    getHierarchy<T = Project.IssueType.GetHierarchy.Response.OK>(options: Project.IssueType.GetHierarchy.Options): Promise<import("./definitions/ProjectIssueTypeHierarchyAsResponse").ProjectIssueTypeHierarchyAsResponse>;
}
declare class ProjectValidationGroup extends BaseGroup {
    /**
  * Validates a project key by confirming the key is a valid string and not in use.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-key-get
  * @param options Request options.
  */
    validateProjectKey<T = Project.Validation.ValidateProjectKey.Response.OK>(options: Project.Validation.ValidateProjectKey.Options): Promise<import("./definitions/ErrorCollectionAsResponse").ErrorCollectionAsResponse>;
    /**
  * Validates a project key and, if the key is invalid or in use, generates a valid random string for the project key.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-validProjectKey-get
  * @param options Request options.
  */
    getValidProjectKey<T = Project.Validation.GetValidProjectKey.Response.OK>(options: Project.Validation.GetValidProjectKey.Options): Promise<string>;
    /**
  * Checks that a project name isn't in use. If the name isn't in use, the passed string is returned. If the name is in use, this operation attempts to generate a valid project name based on the one supplied, usually by adding a sequence number. If a valid project name cannot be generated, a 404 response is returned.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-validProjectName-get
  * @param options Request options.
  */
    getValidProjectName<T = Project.Validation.GetValidProjectName.Response.OK>(options: Project.Validation.GetValidProjectName.Options): Promise<string>;
}
declare class ProjectTypeGroup extends BaseGroup {
    /**
  * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw), whether or not the instance has a valid license for each type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-get
  * @param options Request options.
  */
    getTypes<T = Project.Type.GetTypes.Response.OK>(options?: Project.Type.GetTypes.Options): Promise<Project.Type.GetTypes.Response.OK>;
    /**
     * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw) with a valid license.
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-accessible-get
     * @param options Request options.
     */
    getLicensedTypes<T = Project.Type.GetLicensedTypes.Response.OK>(options?: Project.Type.GetLicensedTypes.Options): Promise<Project.Type.GetLicensedTypes.Response.OK>;
    /**
  * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-get
  * @param options Request options.
  */
    getTypeByKey<T = Project.Type.GetTypeByKey.Response.OK>(options: Project.Type.GetTypeByKey.Options): Promise<import("./definitions/ProjectTypeAsResponse").ProjectTypeAsResponse>;
    /**
  * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw) if it is accessible to the user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-accessible-get
  * @param options Request options.
  */
    getAccessibleTypeByKey<T = Project.Type.GetAccessibleTypeByKey.Response.OK>(options: Project.Type.GetAccessibleTypeByKey.Options): Promise<import("./definitions/ProjectTypeAsResponse").ProjectTypeAsResponse>;
}
declare class ProjectCategoryGroup extends BaseGroup {
    /**
  * Returns all project categories.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-get
  * @param options Request options.
  */
    getCategories<T = Project.Category.GetCategories.Response.OK>(options?: Project.Category.GetCategories.Options): Promise<Project.Category.GetCategories.Response.OK>;
    /**
  * Creates a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-post
  * @param options Request options.
  */
    createCategory<T = Project.Category.CreateCategory.Response.OK>(options: Project.Category.CreateCategory.Options): Promise<import("./definitions/ProjectCategoryAsResponse").ProjectCategoryAsResponse>;
    /**
  * Returns a project category.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-get
  * @param options Request options.
  */
    getCategory<T = Project.Category.GetCategory.Response.OK>(options: Project.Category.GetCategory.Options): Promise<import("./definitions/ProjectCategoryAsResponse").ProjectCategoryAsResponse>;
    /**
  * Updates a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-put
  * @param options Request options.
  */
    updateCategory<T = Project.Category.UpdateCategory.Response.OK>(options: Project.Category.UpdateCategory.Options): Promise<import("./definitions/UpdatedProjectCategoryAsResponse").UpdatedProjectCategoryAsResponse>;
    /**
  * Deletes a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-delete
  * @param options Request options.
  */
    deleteCategory<T = Project.Category.DeleteCategory.Response.OK>(options: Project.Category.DeleteCategory.Options): Promise<undefined>;
}
declare class ProjectNotificationGroup extends BaseGroup {
    Scheme: ProjectNotificationSchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class ProjectNotificationSchemeGroup extends BaseGroup {
    /**
  * Gets a [notification scheme](https://confluence.atlassian.com/x/8YdKLg) associated with the project. See the [Get notification scheme](#api-rest-api-3-notificationscheme-id-get) resource for more information about notification schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectkeyorid-notificationscheme-get
  * @param options Request options.
  */
    getScheme<T = Project.Notification.Scheme.GetScheme.Response.OK>(options: Project.Notification.Scheme.GetScheme.Options): Promise<import("./definitions/NotificationSchemeAsResponse").NotificationSchemeAsResponse>;
}
declare class ProjectPermissionGroup extends BaseGroup {
    Scheme: ProjectPermissionSchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class ProjectPermissionSchemeGroup extends BaseGroup {
    /**
  * Assigns a permission scheme with a project. See [Managing project permissions](https://confluence.atlassian.com/x/yodKLg) for more information about permission schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-put
  * @param options Request options.
  */
    assignScheme<T = Project.Permission.Scheme.AssignScheme.Response.OK>(options: Project.Permission.Scheme.AssignScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Gets the [permission scheme](https://confluence.atlassian.com/x/yodKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-get
  * @param options Request options.
  */
    getScheme<T = Project.Permission.Scheme.GetScheme.Response.OK>(options: Project.Permission.Scheme.GetScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Returns all [issue security](https://confluence.atlassian.com/x/J4lKLg) levels for the project that the user has access to.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project, however, issue security levels are only returned for authenticated user with *Set Issue Security* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-securitylevel-get
  * @param options Request options.
  */
    getIssueSecurityLevels<T = Project.Permission.Scheme.GetIssueSecurityLevels.Response.OK>(options: Project.Permission.Scheme.GetIssueSecurityLevels.Options): Promise<import("./definitions/ProjectIssueSecurityLevelsAsResponse").ProjectIssueSecurityLevelsAsResponse>;
}
declare class ProjectSecurityGroup extends BaseGroup {
    Scheme: ProjectSecuritySchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class ProjectSecuritySchemeGroup extends BaseGroup {
    /**
  * Returns the [issue security scheme](https://confluence.atlassian.com/x/J4lKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or the *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-issuesecuritylevelscheme-get
  * @param options Request options.
  */
    getIssueScheme<T = Project.Security.Scheme.GetIssueScheme.Response.OK>(options: Project.Security.Scheme.GetIssueScheme.Options): Promise<import("./definitions/SecuritySchemeAsResponse").SecuritySchemeAsResponse>;
}
declare class ProjectPropertyGroup extends BaseGroup {
    /**
  * Returns all [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys for the project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-get
  * @param options Request options.
  */
    getPropertyKeys<T = Project.Property.GetPropertyKeys.Response.OK>(options: Project.Property.GetPropertyKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the value of a [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-get
  * @param options Request options.
  */
    getProperty<T = Project.Property.GetProperty.Response.OK>(options: Project.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of the [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). You can use project properties to store custom data against the project.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the property is created.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-put
  * @param options Request options.
  */
    setProperty<T = Project.Property.SetProperty.Response.OK>(options: Project.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes the [property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) from a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-delete
  * @param options Request options.
  */
    deleteProperty<T = Project.Property.DeleteProperty.Response.OK>(options: Project.Property.DeleteProperty.Options): Promise<undefined>;
}
declare class FilterGroup extends BaseGroup {
    Favourite: FilterFavouriteGroup;
    Column: FilterColumnGroup;
    Share: FilterShareGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Creates a filter. The filter is shared according to the [default share scope](#api-rest-api-3-filter-post). The filter is not selected as a favorite.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-post
  * @param options Request options.
  */
    createFilter<T = Filter.CreateFilter.Response.OK>(options: Filter.CreateFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Returns the filters owned by the user. If `includeFavourites` is `true`, the user's visible favorite filters are also returned.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, a favorite filters is only visible to the user where the filter is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  
  For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-my-get
  * @param options Request options.
  */
    getMyFilters<T = Filter.GetMyFilters.Response.OK>(options?: Filter.GetMyFilters.Options): Promise<Filter.GetMyFilters.Response.OK>;
    /**
  * Returns a [paginated](#pagination) list of filters. Use this operation to get:
  
   *  specific filters, by defining `id` only.
   *  filters that match all of the specified attributes. For example, all filters for a user with a particular word in their name. When multiple attributes are specified only filters matching all attributes are returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, only the following filters that match the query parameters are returned:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-search-get
  * @param options Request options.
  */
    searchFilters<T = Filter.SearchFilters.Response.OK>(options?: Filter.SearchFilters.Options): Promise<import("./definitions/PageBeanFilterDetailsAsResponse").PageBeanFilterDetailsAsResponse>;
    /**
  * Returns a filter.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, the filter is only returned where it is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-get
  * @param options Request options.
  */
    getFilter<T = Filter.GetFilter.Response.OK>(options: Filter.GetFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-put
  * @param options Request options.
  */
    updateFilter<T = Filter.UpdateFilter.Response.OK>(options: Filter.UpdateFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Delete a filter.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however filters can only be deleted by the creator of the filter or a user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-delete
  * @param options Request options.
  */
    deleteFilter<T = Filter.DeleteFilter.Response.OK>(options: Filter.DeleteFilter.Options): Promise<undefined>;
}
declare class FilterFavouriteGroup extends BaseGroup {
    /**
  * Returns the visible favorite filters of the user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** A favorite filter is only visible to the user where the filter is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  
  For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-favourite-get
  * @param options Request options.
  */
    getFilters<T = Filter.Favourite.GetFilters.Response.OK>(options?: Filter.Favourite.GetFilters.Options): Promise<Filter.Favourite.GetFilters.Response.OK>;
    /**
  * Add a filter as a favorite for the user.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, the user can only favorite:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-favourite-put
  * @param options Request options.
  */
    addFilter<T = Filter.Favourite.AddFilter.Response.OK>(options: Filter.Favourite.AddFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Removes a filter as a favorite for the user. Note that this operation only removes filters visible to the user from the user's favorites list. For example, if the user favorites a public filter that is subsequently made private (and is therefore no longer visible on their favorites list) they cannot remove it from their favorites list.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-favourite-delete
  * @param options Request options.
  */
    removeFilter<T = Filter.Favourite.RemoveFilter.Response.OK>(options: Filter.Favourite.RemoveFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
}
declare class FilterColumnGroup extends BaseGroup {
    /**
  * Returns the columns configured for a filter. The column configuration is used when the filter's results are viewed in *List View* with the *Columns* set to *Filter*.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, column details are only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-get
  * @param options Request options.
  */
    getColumns<T = Filter.Column.GetColumns.Response.OK>(options: Filter.Column.GetColumns.Options): Promise<Filter.Column.GetColumns.Response.OK>;
    /**
  * Sets the columns for a filter. Only navigable fields can be set as columns. Use [Get fields](#api-rest-api-3-field-get) to get the list fields in Jira. A navigable field has `navigable` set to `true`.
  
  The parameters for this resource are expressed as HTML form data. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/filter/10000/columns`
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only set for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-put
  * @param options Request options.
  */
    setColumns<T = Filter.Column.SetColumns.Response.OK>(options: Filter.Column.SetColumns.Options): Promise<any>;
    /**
  * Reset the user's column configuration for the filter to the default.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only reset for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-delete
  * @param options Request options.
  */
    resetColumns<T = Filter.Column.ResetColumns.Response.OK>(options: Filter.Column.ResetColumns.Options): Promise<undefined>;
}
declare class FilterShareGroup extends BaseGroup {
    Permission: FilterSharePermissionGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns the default sharing settings for new filters and dashboards for a user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-defaultsharescope-get
  * @param options Request options.
  */
    getDefaultScope<T = Filter.Share.GetDefaultScope.Response.OK>(options?: Filter.Share.GetDefaultScope.Options): Promise<import("./definitions/DefaultShareScopeAsResponse").DefaultShareScopeAsResponse>;
    /**
  * Sets the default sharing for new filters and dashboards for a user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-defaultsharescope-put
  * @param options Request options.
  */
    setDefaultScope<T = Filter.Share.SetDefaultScope.Response.OK>(options: Filter.Share.SetDefaultScope.Options): Promise<import("./definitions/DefaultShareScopeAsResponse").DefaultShareScopeAsResponse>;
}
declare class FilterSharePermissionGroup extends BaseGroup {
    /**
  * Returns the share permissions for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, share permissions are only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-get
  * @param options Request options.
  */
    getPermissions<T = Filter.Share.Permission.GetPermissions.Response.OK>(options: Filter.Share.Permission.GetPermissions.Options): Promise<Filter.Share.Permission.GetPermissions.Response.OK>;
    /**
  * Add a share permissions to a filter. If you add a global share permission (one for all logged-in users or the public) it will overwrite all share permissions for the filter.
  
  Be aware that this operation uses different objects for updating share permissions compared to [Update filter](#api-rest-api-3-filter-id-put).
  
  **[Permissions](#permissions) required:** *Share dashboards and filters* [global permission](https://confluence.atlassian.com/x/x4dKLg) and the user must own the filter.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-post
  * @param options Request options.
  */
    addPermission<T = Filter.Share.Permission.AddPermission.Response.OK>(options: Filter.Share.Permission.AddPermission.Options): Promise<Filter.Share.Permission.AddPermission.Response.OK>;
    /**
  * Returns a share permission for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, a share permission is only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-get
  * @param options Request options.
  */
    getPermission<T = Filter.Share.Permission.GetPermission.Response.OK>(options: Filter.Share.Permission.GetPermission.Options): Promise<import("./definitions/SharePermissionAsResponse").SharePermissionAsResponse>;
    /**
  * Deletes a share permission from a filter.
  
  **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-delete
  * @param options Request options.
  */
    deletePermission<T = Filter.Share.Permission.DeletePermission.Response.OK>(options: Filter.Share.Permission.DeletePermission.Options): Promise<undefined>;
}
declare class GroupGroup extends BaseGroup {
    User: GroupUserGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Creates a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-post
  * @param options Request options.
  */
    createGroup<T = Group.CreateGroup.Response.OK>(options: Group.CreateGroup.Options): Promise<import("./definitions/GroupAsResponse").GroupAsResponse>;
    /**
  * Deletes a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* strategic [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-delete
  * @param options Request options.
  */
    removeGroup<T = Group.RemoveGroup.Response.OK>(options: Group.RemoveGroup.Options): Promise<undefined>;
    /**
  * Returns a list of groups whose names contain a query string. A list of group names can be provided to exclude groups from the results.
  
  The primary use case for this resource is to populate a group picker suggestions list. To this end, the returned object includes the `html` field where the matched query term is highlighted in the group name with the HTML strong tag. Also, the groups list is wrapped in a response object that contains a header for use in the picker, specifically *Showing X of Y matching groups*.
  
  The list returns with the groups sorted. If no groups match the list criteria, an empty list is returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg). Anonymous calls and calls by users without the required permission return an empty list.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-groups-picker-get
  * @param options Request options.
  */
    findGroups<T = Group.FindGroups.Response.OK>(options?: Group.FindGroups.Options): Promise<import("./definitions/FoundGroupsAsResponse").FoundGroupsAsResponse>;
}
declare class GroupUserGroup extends BaseGroup {
    /**
  * Returns a [paginated](#pagination) list of all users in a group.
  
  Note that users are ordered by username, however the username is not returned in the results due to privacy reasons.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-member-get
  * @param options Request options.
  */
    getUsers<T = Group.User.GetUsers.Response.OK>(options: Group.User.GetUsers.Options): Promise<import("./definitions/PageBeanUserDetailsAsResponse").PageBeanUserDetailsAsResponse>;
    /**
  * Adds a user to a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-post
  * @param options Request options.
  */
    addUser<T = Group.User.AddUser.Response.OK>(options: Group.User.AddUser.Options): Promise<import("./definitions/GroupAsResponse").GroupAsResponse>;
    /**
  * Removes a user from a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-delete
  * @param options Request options.
  */
    removeUser<T = Group.User.RemoveUser.Response.OK>(options: Group.User.RemoveUser.Options): Promise<undefined>;
}
declare class GroupAndUserPickerGroup extends BaseGroup {
    /**
  * Returns a list of users and groups matching a string. The string is used:
  
   *  for users, to find a case-insensitive match with display name and e-mail address. Note that if a user has hidden their email address in their user profile, partial matches of the email address will not find the user. An exact match is required.
   *  for groups, to find a case-sensitive match with group name.
  
  For example, if the string *tin* is used, records with the display name *Tina*, email address *sarah@tinplatetraining.com*, and the group *accounting* would be returned.
  
  Optionally, the search can be refined to:
  
   *  the projects and issue types associated with a custom field, such as a user picker. The search can then be further refined to return only users and groups that have permission to view specific:
      
       *  projects.
       *  issue types.
      
      If multiple projects or issue types are specified, they must be a subset of those enabled for the custom field or no results are returned. For example, if a field is enabled for projects A, B, and C then the search could be limited to projects B and C. However, if the search is limited to projects B and D, nothing is returned.
   *  not return Connect app users and groups.
   *  return groups that have a case-insensitive match with the query.
  
  The primary use case for this resource is to populate a picker field suggestion list with users or groups. To this end, the returned object includes an `html` field for each list. This field highlights the matched query term in the item name with the HTML strong tag. Also, each list is wrapped in a response object that contains a header for use in a picker, specifically *Showing X of Y matching groups*.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-groupuserpicker-get
  * @param options Request options.
  */
    findUsersAndGroups<T = GroupAndUserPicker.FindUsersAndGroups.Response.OK>(options: GroupAndUserPicker.FindUsersAndGroups.Options): Promise<import("./definitions/FoundUsersAndGroupsAsResponse").FoundUsersAndGroupsAsResponse>;
}
declare class JqlGroup extends BaseGroup {
    /**
  * Parses and validates JQL queries.
  
  Validation is performed in context of the current user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-jql-parse-post
  * @param options Request options.
  */
    parseQuery<T = Jql.ParseQuery.Response.OK>(options: Jql.ParseQuery.Options): Promise<import("./definitions/ParsedJqlQueriesAsResponse").ParsedJqlQueriesAsResponse>;
    /**
  * Converts one or more JQL queries with user identifiers (username or user key) to equivalent JQL queries with account IDs.
  
  You may wish to use this operation if your system stores JQL queries and you want to make them GDPR-compliant. For more information about GDPR-related changes, see the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/).
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-jql-pdcleaner-post
  * @param options Request options.
  */
    convertUserIdentifiersToAccountIdsInQueries<T = Jql.ConvertUserIdentifiersToAccountIdsInQueries.Response.OK>(options: Jql.ConvertUserIdentifiersToAccountIdsInQueries.Options): Promise<import("./definitions/ConvertedJQLQueriesAsResponse").ConvertedJQLQueriesAsResponse>;
    /**
  * Returns reference data for JQL searches. This is a downloadable version of the documentation provided in [Advanced searching - fields reference](https://confluence.atlassian.com/x/gwORLQ) and [Advanced searching - functions reference](https://confluence.atlassian.com/x/hgORLQ), along with a list of JQL-reserved words. Use this information to assist with the programmatic creation of JQL queries or the validation of queries built in a custom query builder.
  
  To filter visible field details by project or collapse non-unique fields by field type then [Get field reference data (POST)](#api-rest-api-3-jql-autocompletedata-post) can be used.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-autocompletedata-get
  * @param options Request options.
  */
    getReferenceData<T = Jql.GetReferenceData.Response.OK>(options?: Jql.GetReferenceData.Options): Promise<import("./definitions/JQLReferenceDataAsResponse").JQLReferenceDataAsResponse>;
}
declare class LabelGroup extends BaseGroup {
    /**
     * Returns a [paginated](#pagination) list of labels.
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-label-get
     * @param options Request options.
     */
    getLabels<T = Label.GetLabels.Response.OK>(options?: Label.GetLabels.Options): Promise<import("./definitions/PageBeanStringAsResponse").PageBeanStringAsResponse>;
}
declare class PermissionGroup extends BaseGroup {
    Scheme: PermissionSchemeGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a list of permissions indicating which permissions the user has. Details of the user's permissions can be obtained in a global, project, or issue context.
  
  The user is reported as having a project permission:
  
   *  in the global context, if the user has the project permission in any project.
   *  for a project, where the project permission is determined using issue data, if the user meets the permission's criteria for any issue in the project. Otherwise, if the user has the project permission in the project.
   *  for an issue, where a project permission is determined using issue data, if the user has the permission in the issue. Otherwise, if the user has the project permission in the project containing the issue.
  
  This means that users may be shown as having an issue permission (such as EDIT\_ISSUES) in the global context or a project context but may not have the permission for any or all issues. For example, if Reporters have the EDIT\_ISSUES permission a user would be shown as having this permission in the global context or the context of a project, because any user can be a reporter. However, if they are not the user who reported the issue queried they would not have EDIT\_ISSUES permission for that issue.
  
  Global permissions are unaffected by context.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypermissions-get
  * @param options Request options.
  */
    getMyPermissions<T = Permission.GetMyPermissions.Response.OK>(options: Permission.GetMyPermissions.Options): Promise<import("./definitions/PermissionsAsResponse").PermissionsAsResponse>;
    /**
  * Returns all permissions, including:
  
   *  global permissions.
   *  project permissions.
   *  global permissions added by plugins.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-permissions-get
  * @param options Request options.
  */
    getPermissions<T = Permission.GetPermissions.Response.OK>(options?: Permission.GetPermissions.Options): Promise<import("./definitions/PermissionsAsResponse").PermissionsAsResponse>;
    /**
  * Returns:
  
   *  for a list of global permissions, the global permissions granted to a user.
   *  for a list of project permissions and lists of projects and issues, for each project permission a list of the projects and issues a user can access or manipulate.
  
  If no account ID is provided, the operation returns details for the logged in user.
  
  Note that:
  
   *  Invalid project and issue IDs are ignored.
   *  A maximum of 1000 projects and 1000 issues can be checked.
   *  Null values in `globalPermissions`, `projectPermissions`, `projectPermissions.projects`, and `projectPermissions.issues` are ignored.
   *  Empty strings in `projectPermissions.permissions` are ignored.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to check the permissions for other users, otherwise none. However, Connect apps can make a call from the app server to the product to obtain permission details for any user, without admin permission. This Connect app ability doesn't apply to calls made using AP.request() in a browser.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-permissions-check-post
  * @param options Request options.
  */
    getBulkPermissions<T = Permission.GetBulkPermissions.Response.OK>(options: Permission.GetBulkPermissions.Options): Promise<import("./definitions/BulkPermissionGrantsAsResponse").BulkPermissionGrantsAsResponse>;
    /**
  * Returns all the projects where the user is granted a list of project permissions.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-permissions-project-post
  * @param options Request options.
  */
    getPermittedProjects<T = Permission.GetPermittedProjects.Response.OK>(options: Permission.GetPermittedProjects.Options): Promise<import("./definitions/PermittedProjectsAsResponse").PermittedProjectsAsResponse>;
}
declare class PermissionSchemeGroup extends BaseGroup {
    Grant: PermissionSchemeGrantGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns all permission schemes.
  
  ### About permission schemes and grants ###
  
  A permission scheme is a collection of permission grants. A permission grant consists of a `holder` and a `permission`.
  
  #### Holder object ####
  
  The `holder` object contains information about the user or group being granted the permission. For example, the *Administer projects* permission is granted to a group named *Teams in space administrators*. In this case, the type is `"type": "group"`, and the parameter is the group name, `"parameter": "Teams in space administrators"`. The `holder` object is defined by the following properties:
  
   *  `type` Identifies the user or group (see the list of types below).
   *  `parameter` The value of this property depends on the `type`. For example, if the `type` is a group, then you need to specify the group name.
  
  The following `types` are available. The expected values for the `parameter` are given in parenthesis (some `types` may not have a `parameter`):
  
   *  `anyone` Grant for anonymous users.
   *  `applicationRole` Grant for users with access to the specified application (application name). See [Update product access settings](https://confluence.atlassian.com/x/3YxjL) for more information.
   *  `assignee` Grant for the user currently assigned to an issue.
   *  `group` Grant for the specified group (group name).
   *  `groupCustomField` Grant for a user in the group selected in the specified custom field (custom field ID).
   *  `projectLead` Grant for a project lead.
   *  `projectRole` Grant for the specified project role (project role ID).
   *  `reporter` Grant for the user who reported the issue.
   *  `sd.customer.portal.only` Jira Service Desk only. Grants customers permission to access the customer portal but not Jira. See [Customizing Jira Service Desk permissions](https://confluence.atlassian.com/x/24dKLg) for more information.
   *  `user` Grant for the specified user (user ID - historically this was the userkey but that is deprecated and the account ID should be used).
   *  `userCustomField` Grant for a user selected in the specified custom field (custom field ID).
  
  #### Built-in permissions ####
  
  The [built-in Jira permissions](https://confluence.atlassian.com/x/yodKLg) are listed below. Apps can also define custom permissions. See the [project permission](https://developer.atlassian.com/cloud/jira/platform/modules/project-permission/) and [global permission](https://developer.atlassian.com/cloud/jira/platform/modules/global-permission/) module documentation for more information.
  
  **Project permissions**
  
   *  `ADMINISTER_PROJECTS`
   *  `BROWSE_PROJECTS`
   *  `MANAGE_SPRINTS_PERMISSION` (Jira Software only)
   *  `SERVICEDESK_AGENT` (Jira Service Desk only)
   *  `VIEW_DEV_TOOLS` (Jira Software only)
   *  `VIEW_READONLY_WORKFLOW`
  
  **Issue permissions**
  
   *  `ASSIGNABLE_USER`
   *  `ASSIGN_ISSUES`
   *  `CLOSE_ISSUES`
   *  `CREATE_ISSUES`
   *  `DELETE_ISSUES`
   *  `EDIT_ISSUES`
   *  `LINK_ISSUES`
   *  `MODIFY_REPORTER`
   *  `MOVE_ISSUES`
   *  `RESOLVE_ISSUES`
   *  `SCHEDULE_ISSUES`
   *  `SET_ISSUE_SECURITY`
   *  `TRANSITION_ISSUES`
  
  **Voters and watchers permissions**
  
   *  `MANAGE_WATCHERS`
   *  `VIEW_VOTERS_AND_WATCHERS`
  
  **Comments permissions**
  
   *  `ADD_COMMENTS`
   *  `DELETE_ALL_COMMENTS`
   *  `DELETE_OWN_COMMENTS`
   *  `EDIT_ALL_COMMENTS`
   *  `EDIT_OWN_COMMENTS`
  
  **Attachments permissions**
  
   *  `CREATE_ATTACHMENTS`
   *  `DELETE_ALL_ATTACHMENTS`
   *  `DELETE_OWN_ATTACHMENTS`
  
  **Time tracking permissions**
  
   *  `DELETE_ALL_WORKLOGS`
   *  `DELETE_OWN_WORKLOGS`
   *  `EDIT_ALL_WORKLOGS`
   *  `EDIT_OWN_WORKLOGS`
   *  `WORK_ON_ISSUES`
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-get
  * @param options Request options.
  */
    getSchemes<T = Permission.Scheme.GetSchemes.Response.OK>(options?: Permission.Scheme.GetSchemes.Options): Promise<import("./definitions/PermissionSchemesAsResponse").PermissionSchemesAsResponse>;
    /**
  * Creates a new permission scheme. You can create a permission scheme with or without defining a set of permission grants.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-post
  * @param options Request options.
  */
    createScheme<T = Permission.Scheme.CreateScheme.Response.OK>(options: Permission.Scheme.CreateScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Returns a permission scheme.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-get
  * @param options Request options.
  */
    getScheme<T = Permission.Scheme.GetScheme.Response.OK>(options: Permission.Scheme.GetScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Updates a permission scheme. Below are some important things to note when using this resource:
  
   *  If a permissions list is present in the request, then it is set in the permission scheme, overwriting *all existing* grants.
   *  If you want to update only the name and description, then do not send a permissions list in the request.
   *  Sending an empty list will remove all permission grants from the permission scheme.
  
  If you want to add or delete a permission grant instead of updating the whole list, see [Create permission grant](#api-rest-api-3-permissionscheme-schemeId-permission-post) or [Delete permission scheme entity](#api-rest-api-3-permissionscheme-schemeId-permission-permissionId-delete).
  
  See [About permission schemes and grants](#about-permission-schemes) for more details.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-put
  * @param options Request options.
  */
    updateScheme<T = Permission.Scheme.UpdateScheme.Response.OK>(options: Permission.Scheme.UpdateScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Deletes a permission scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-delete
  * @param options Request options.
  */
    deleteScheme<T = Permission.Scheme.DeleteScheme.Response.OK>(options: Permission.Scheme.DeleteScheme.Options): Promise<undefined>;
}
declare class PermissionSchemeGrantGroup extends BaseGroup {
    /**
  * Returns all permission grants for a permission scheme.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-get
  * @param options Request options.
  */
    getGrants<T = Permission.Scheme.Grant.GetGrants.Response.OK>(options: Permission.Scheme.Grant.GetGrants.Options): Promise<import("./definitions/PermissionGrantsAsResponse").PermissionGrantsAsResponse>;
    /**
  * Creates a permission grant in a permission scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-post
  * @param options Request options.
  */
    createGrant<T = Permission.Scheme.Grant.CreateGrant.Response.OK>(options: Permission.Scheme.Grant.CreateGrant.Options): Promise<import("./definitions/PermissionGrantAsResponse").PermissionGrantAsResponse>;
    /**
  * Returns a permission grant.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-get
  * @param options Request options.
  */
    getGrant<T = Permission.Scheme.Grant.GetGrant.Response.OK>(options: Permission.Scheme.Grant.GetGrant.Options): Promise<import("./definitions/PermissionGrantAsResponse").PermissionGrantAsResponse>;
    /**
  * Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-delete
  * @param options Request options.
  */
    deleteGrant<T = Permission.Scheme.Grant.DeleteGrant.Response.OK>(options: Permission.Scheme.Grant.DeleteGrant.Options): Promise<undefined>;
}
declare class MyselfGroup extends BaseGroup {
    /**
  * Returns the value of a preference of the current user.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default this is not set and the user takes the locale of the instance.
   *  *jira.user.timezone* The time zone of the user. By default this is not set and the user takes the timezone of the instance.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-get
  * @param options Request options.
  */
    getPreference<T = Myself.GetPreference.Response.OK>(options: Myself.GetPreference.Options): Promise<string>;
    /**
  * Creates a preference for the user or updates a preference's value by sending a plain text string. For example, `false`. An arbitrary preference can be created with the value containing up to 255 characters. In addition, the following keys define system preferences that can be set or created:
  
   *  *user.notifications.mimetype* The mime type used in notifications sent to the user. Defaults to `html`.
   *  *user.notify.own.changes* Whether the user gets notified of their own changes. Defaults to `false`.
   *  *user.default.share.private* Whether new [ filters](https://confluence.atlassian.com/x/eQiiLQ) are set to private. Defaults to `true`.
   *  *user.keyboard.shortcuts.disabled* Whether keyboard shortcuts are disabled. Defaults to `false`.
   *  *user.autowatch.disabled* Whether the user automatically watches issues they create or add a comment to. By default, not set: the user takes the instance autowatch setting.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
   *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-put
  * @param options Request options.
  */
    setPreference<T = Myself.SetPreference.Response.OK>(options: Myself.SetPreference.Options): Promise<any>;
    /**
  * Deletes a preference of the user, which restores the default value of system defined settings.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
   *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-delete
  * @param options Request options.
  */
    deletePreference<T = Myself.DeletePreference.Response.OK>(options: Myself.DeletePreference.Options): Promise<undefined>;
    /**
  * Returns the locale for the user.
  
  If the user has no language preference set (which is the default setting) or this resource is accessed anonymous, the browser locale detected by Jira is returned. Jira detects the browser locale using the *Accept-Language* header in the request. However, if this doesn't match a locale available Jira, the site default locale is returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-locale-get
  * @param options Request options.
  */
    getLocale<T = Myself.GetLocale.Response.OK>(options?: Myself.GetLocale.Options): Promise<import("./definitions/LocaleAsResponse").LocaleAsResponse>;
    /**
  * Returns details for the current user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-myself-get
  * @param options Request options.
  */
    getCurrentUser<T = Myself.GetCurrentUser.Response.OK>(options?: Myself.GetCurrentUser.Options): Promise<import("./definitions/UserAsResponse").UserAsResponse>;
}
declare class WorkflowGroup extends BaseGroup {
    Status: WorkflowStatusGroup;
    Scheme: WorkflowSchemeGroup;
    Transition: WorkflowTransitionGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a [paginated](#pagination) list of published classic workflows. When workflow names are specified, details of those workflows are returned. Otherwise, all published classic workflows are returned.
  
  This operation does not return next-gen workflows.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflow-search-get
  * @param options Request options.
  */
    getWorkflows<T = Workflow.GetWorkflows.Response.OK>(options?: Workflow.GetWorkflows.Options): Promise<import("./definitions/PageBeanWorkflowAsResponse").PageBeanWorkflowAsResponse>;
}
declare class WorkflowStatusGroup extends BaseGroup {
    Category: WorkflowStatusCategoryGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a list of all statuses associated with workflows.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-status-get
  * @param options Request options.
  */
    getStatuses<T = Workflow.Status.GetStatuses.Response.OK>(options?: Workflow.Status.GetStatuses.Options): Promise<Workflow.Status.GetStatuses.Response.OK>;
    /**
  * Returns a status. The status must be associated with a workflow to be returned.
  
  If a name is used on more than one status, only the status found first is returned. Therefore, identifying the status by its ID may be preferable.
  
  This operation can be accessed anonymously.
  
  [Permissions](#permissions) required: None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-status-idOrName-get
  * @param options Request options.
  */
    getStatus<T = Workflow.Status.GetStatus.Response.OK>(options: Workflow.Status.GetStatus.Options): Promise<import("./definitions/StatusDetailsAsResponse").StatusDetailsAsResponse>;
}
declare class WorkflowStatusCategoryGroup extends BaseGroup {
    /**
  * Returns a list of all status categories.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-get
  * @param options Request options.
  */
    getCategories<T = Workflow.Status.Category.GetCategories.Response.OK>(options?: Workflow.Status.Category.GetCategories.Options): Promise<Workflow.Status.Category.GetCategories.Response.OK>;
    /**
  * Returns a status category. Status categories provided a mechanism for categorizing [statuses](#api-rest-api-3-status-idOrName-get).
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-idorkey-get
  * @param options Request options.
  */
    getCategory<T = Workflow.Status.Category.GetCategory.Response.OK>(options: Workflow.Status.Category.GetCategory.Options): Promise<import("./definitions/StatusCategoryAsResponse").StatusCategoryAsResponse>;
}
declare class WorkflowSchemeGroup extends BaseGroup {
    Project: WorkflowSchemeProjectGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a [paginated](#pagination) list of all workflow schemes, not including draft workflow schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-workflowscheme-get
  * @param options Request options.
  */
    getSchemes<T = Workflow.Scheme.GetSchemes.Response.OK>(options?: Workflow.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanWorkflowSchemeAsResponse").PageBeanWorkflowSchemeAsResponse>;
    /**
  * Creates a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-post
  * @param options Request options.
  */
    createScheme<T = Workflow.Scheme.CreateScheme.Response.OK>(options: Workflow.Scheme.CreateScheme.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Returns a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-get
  * @param options Request options.
  */
    getScheme<T = Workflow.Scheme.GetScheme.Response.OK>(options: Workflow.Scheme.GetScheme.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Updates a workflow scheme, including the name, default workflow, issue type to project mappings, and more. If the workflow scheme is active (that is, being used by at least one project), then a draft workflow scheme is created or updated instead, provided that `updateDraftIfNeeded` is set to `true`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-put
  * @param options Request options.
  */
    updateScheme<T = Workflow.Scheme.UpdateScheme.Response.OK>(options: Workflow.Scheme.UpdateScheme.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Deletes a workflow scheme. Note that a workflow scheme cannot be deleted if it is active (that is, being used by at least one project).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-delete
  * @param options Request options.
  */
    deleteScheme<T = Workflow.Scheme.DeleteScheme.Response.OK>(options: Workflow.Scheme.DeleteScheme.Options): Promise<undefined>;
    /**
  * Returns the issue type-workflow mapping for an issue type in a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-get
  * @param options Request options.
  */
    getWorkflowForIssueType<T = Workflow.Scheme.GetWorkflowForIssueType.Response.OK>(options: Workflow.Scheme.GetWorkflowForIssueType.Options): Promise<import("./definitions/IssueTypeWorkflowMappingAsResponse").IssueTypeWorkflowMappingAsResponse>;
    /**
  * Sets the workflow for an issue type in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new issue type-workflow mapping. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-put
  * @param options Request options.
  */
    setWorkflowForIssueType<T = Workflow.Scheme.SetWorkflowForIssueType.Response.OK>(options: Workflow.Scheme.SetWorkflowForIssueType.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Deletes the issue type-workflow mapping for an issue type in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the issue type-workflow mapping deleted. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-delete
  * @param options Request options.
  */
    deleteWorkflowForIssueType<T = Workflow.Scheme.DeleteWorkflowForIssueType.Response.OK>(options: Workflow.Scheme.DeleteWorkflowForIssueType.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Returns the workflow-issue type mappings for a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-get
  * @param options Request options.
  */
    getIssueTypesForWorkflow<T = Workflow.Scheme.GetIssueTypesForWorkflow.Response.OK>(options: Workflow.Scheme.GetIssueTypesForWorkflow.Options): Promise<Workflow.Scheme.GetIssueTypesForWorkflow.Response.OK>;
    /**
  * Sets the issue types for a workflow in a workflow scheme. The workflow can also be set as the default workflow for the workflow scheme. Unmapped issues types are mapped to the default workflow.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new workflow-issue types mappings. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-put
  * @param options Request options.
  */
    setIssueTypesForWorkflow<T = Workflow.Scheme.SetIssueTypesForWorkflow.Response.OK>(options: Workflow.Scheme.SetIssueTypesForWorkflow.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Deletes the workflow-issue type mapping for a workflow in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the workflow-issue type mapping deleted. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-delete
  * @param options Request options.
  */
    deleteIssueTypesForWorkflow<T = Workflow.Scheme.DeleteIssueTypesForWorkflow.Response.OK>(options: Workflow.Scheme.DeleteIssueTypesForWorkflow.Options): Promise<undefined>;
    /**
  * Returns the default workflow for a workflow scheme. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-get
  * @param options Request options.
  */
    getDefaultWorkflow<T = Workflow.Scheme.GetDefaultWorkflow.Response.OK>(options: Workflow.Scheme.GetDefaultWorkflow.Options): Promise<import("./definitions/DefaultWorkflowAsResponse").DefaultWorkflowAsResponse>;
    /**
  * Sets the default workflow for a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request object and a draft workflow scheme is created or updated with the new default workflow. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-put
  * @param options Request options.
  */
    updateDefaultWorkflow<T = Workflow.Scheme.UpdateDefaultWorkflow.Response.OK>(options: Workflow.Scheme.UpdateDefaultWorkflow.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Resets the default workflow for a workflow scheme. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the default workflow reset. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-delete
  * @param options Request options.
  */
    deleteDefaultWorkflow<T = Workflow.Scheme.DeleteDefaultWorkflow.Response.OK>(options: Workflow.Scheme.DeleteDefaultWorkflow.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
}
declare class WorkflowSchemeProjectGroup extends BaseGroup {
    /**
  * Returns a list of the workflow schemes associated with a list of projects. Each returned workflow scheme includes a list of the requested projects associated with it. Any team-managed or non-existent projects in the request are ignored and no errors are returned.
  
  If the project is associated with the `Default Workflow Scheme` no ID is returned. This is because the way the `Default Workflow Scheme` is stored means it has no ID.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-get
  * @param options Request options.
  */
    getProjectAssociations<T = Workflow.Scheme.Project.GetProjectAssociations.Response.OK>(options: Workflow.Scheme.Project.GetProjectAssociations.Options): Promise<import("./definitions/ContainerOfWorkflowSchemeAssociationsAsResponse").ContainerOfWorkflowSchemeAssociationsAsResponse>;
    /**
  * Assigns a workflow scheme to a project. This operation is performed only when there are no issues in the project.
  
  Workflow schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-put
  * @param options Request options.
  */
    assignWorkflow<T = Workflow.Scheme.Project.AssignWorkflow.Response.OK>(options: Workflow.Scheme.Project.AssignWorkflow.Options): Promise<any>;
}
declare class WorkflowTransitionGroup extends BaseGroup {
    Property: WorkflowTransitionPropertyGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class WorkflowTransitionPropertyGroup extends BaseGroup {
    /**
  * Updates a workflow transition by changing the property value. Trying to update a property that does not exist results in a new property being added to the transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-put
  * @param options Request options.
  */
    updateProperty<T = Workflow.Transition.Property.UpdateProperty.Response.OK>(options: Workflow.Transition.Property.UpdateProperty.Options): Promise<import("./definitions/WorkflowTransitionPropertyAsResponse").WorkflowTransitionPropertyAsResponse>;
    /**
  * Adds a property to a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-post
  * @param options Request options.
  */
    createProperty<T = Workflow.Transition.Property.CreateProperty.Response.OK>(options: Workflow.Transition.Property.CreateProperty.Options): Promise<import("./definitions/WorkflowTransitionPropertyAsResponse").WorkflowTransitionPropertyAsResponse>;
    /**
  * Deletes a property from a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-delete
  * @param options Request options.
  */
    deleteProperty<T = Workflow.Transition.Property.DeleteProperty.Response.OK>(options: Workflow.Transition.Property.DeleteProperty.Options): Promise<undefined>;
}
declare class ScreenGroup extends BaseGroup {
    Scheme: ScreenSchemeGroup;
    Tab: ScreenTabGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns a [paginated](#pagination) list of the screens a field is used in.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-field-fieldid-screens-get
  * @param options Request options.
  */
    getScreensForField<T = Screen.GetScreensForField.Response.OK>(options: Screen.GetScreensForField.Options): Promise<import("./definitions/PageBeanScreenWithTabAsResponse").PageBeanScreenWithTabAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-get
  * @param options Request options.
  */
    getScreens<T = Screen.GetScreens.Response.OK>(options?: Screen.GetScreens.Options): Promise<import("./definitions/PageBeanScreenAsResponse").PageBeanScreenAsResponse>;
    /**
  * Creates a screen with a default field tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-post
  * @param options Request options.
  */
    createScreen<T = Screen.CreateScreen.Response.OK>(options: Screen.CreateScreen.Options): Promise<import("./definitions/ScreenAsResponse").ScreenAsResponse>;
    /**
  * Adds a field to the default tab of the default screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-addtodefault-fieldid-post
  * @param options Request options.
  */
    addFieldToDefaultScreen<T = Screen.AddFieldToDefaultScreen.Response.OK>(options: Screen.AddFieldToDefaultScreen.Options): Promise<"CREATED">;
    /**
  * Returns the fields that can be added to a tab on a screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-availablefields-get
  * @param options Request options.
  */
    getAvailableScreenFields<T = Screen.GetAvailableScreenFields.Response.OK>(options: Screen.GetAvailableScreenFields.Options): Promise<Screen.GetAvailableScreenFields.Response.OK>;
    /**
  * Updates a screen. Only screens used in classic projects can be updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-put
  * @param options Request options.
  */
    updateScreen<T = Screen.UpdateScreen.Response.OK>(options: Screen.UpdateScreen.Options): Promise<import("./definitions/ScreenAsResponse").ScreenAsResponse>;
    /**
  * Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.
  
  Only screens used in classic projects can be deleted.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-delete
  * @param options Request options.
  */
    deleteScreen<T = Screen.DeleteScreen.Response.OK>(options: Screen.DeleteScreen.Options): Promise<undefined>;
}
declare class ScreenSchemeGroup extends BaseGroup {
    /**
  * Returns a [paginated](#pagination) list of screen schemes.
  
  Only screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-screenscheme-get
  * @param options Request options.
  */
    getSchemes<T = Screen.Scheme.GetSchemes.Response.OK>(options?: Screen.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanScreenSchemeAsResponse").PageBeanScreenSchemeAsResponse>;
    /**
  * Creates a screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-post
  * @param options Request options.
  */
    createScheme<T = Screen.Scheme.CreateScheme.Response.OK>(options: Screen.Scheme.CreateScheme.Options): Promise<import("./definitions/ScreenSchemeIdAsResponse").ScreenSchemeIdAsResponse>;
    /**
  * Updates a screen scheme. Only screen schemes used in classic projects can be updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-put
  * @param options Request options.
  */
    updateScheme<T = Screen.Scheme.UpdateScheme.Response.OK>(options: Screen.Scheme.UpdateScheme.Options): Promise<any>;
    /**
  * Deletes a screen scheme. A screen scheme cannot be deleted if it is used in an issue type screen scheme.
  
  Only screens schemes used in classic projects can be deleted.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-delete
  * @param options Request options.
  */
    deleteScheme<T = Screen.Scheme.DeleteScheme.Response.OK>(options: Screen.Scheme.DeleteScheme.Options): Promise<undefined>;
}
declare class ScreenTabGroup extends BaseGroup {
    Field: ScreenTabFieldGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
  * Returns the list of tabs for a screen.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-get
  * @param options Request options.
  */
    getTabs<T = Screen.Tab.GetTabs.Response.OK>(options: Screen.Tab.GetTabs.Options): Promise<Screen.Tab.GetTabs.Response.OK>;
    /**
  * Creates a tab for a screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-post
  * @param options Request options.
  */
    createTab<T = Screen.Tab.CreateTab.Response.OK>(options: Screen.Tab.CreateTab.Options): Promise<import("./definitions/ScreenableTabAsResponse").ScreenableTabAsResponse>;
    /**
  * Updates the name of a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-put
  * @param options Request options.
  */
    updateTab<T = Screen.Tab.UpdateTab.Response.OK>(options: Screen.Tab.UpdateTab.Options): Promise<import("./definitions/ScreenableTabAsResponse").ScreenableTabAsResponse>;
    /**
  * Deletes a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-delete
  * @param options Request options.
  */
    deleteTab<T = Screen.Tab.DeleteTab.Response.OK>(options: Screen.Tab.DeleteTab.Options): Promise<undefined>;
    /**
  * Moves a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-move-pos-post
  * @param options Request options.
  */
    moveTab<T = Screen.Tab.MoveTab.Response.OK>(options: Screen.Tab.MoveTab.Options): Promise<any>;
}
declare class ScreenTabFieldGroup extends BaseGroup {
    /**
  * Returns all fields for a screen tab.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-get
  * @param options Request options.
  */
    getFields<T = Screen.Tab.Field.GetFields.Response.OK>(options: Screen.Tab.Field.GetFields.Options): Promise<Screen.Tab.Field.GetFields.Response.OK>;
    /**
  * Adds a field to a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-post
  * @param options Request options.
  */
    addField<T = Screen.Tab.Field.AddField.Response.OK>(options: Screen.Tab.Field.AddField.Options): Promise<import("./definitions/ScreenableFieldAsResponse").ScreenableFieldAsResponse>;
    /**
  * Removes a field from a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-delete
  * @param options Request options.
  */
    removeField<T = Screen.Tab.Field.RemoveField.Response.OK>(options: Screen.Tab.Field.RemoveField.Options): Promise<undefined>;
    /**
  * Moves a screen tab field.
  
  If `after` and `position` are provided in the request, `position` is ignored.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-move-post
  * @param options Request options.
  */
    moveField<T = Screen.Tab.Field.MoveField.Response.OK>(options: Screen.Tab.Field.MoveField.Options): Promise<any>;
}
declare class AvatarGroup extends BaseGroup {
    /**
  * Returns the system and custom avatars for a project or issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  for custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
   *  for custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
   *  for system avatars, none.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-entityid-get
  * @param options Request options.
  */
    getAvatars<T = Avatar.GetAvatars.Response.OK>(options: Avatar.GetAvatars.Options): Promise<import("./definitions/AvatarsAsResponse").AvatarsAsResponse>;
    /**
  * Loads a custom avatar for a project or issue type.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST `
  
  `--user email@example.com:<api_token> `
  
  `--header 'X-Atlassian-Token: no-check' `
  
  `--header 'Content-Type: image/< image_type>' `
  
  `--data-binary "<@/path/to/file/with/your/avatar>" `
  
  `--url 'https://your-domain.atlassian.net/rest/api/3/universal_avatar/type/{type}/owner/{entityId}'`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar use:
  
   *  [Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
   *  [Set project avatar](#api-rest-api-3-project-projectIdOrKey-avatar-put) to set it as the project's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-entityid-post
  * @param options Request options.
  */
    loadAvatar<T = Avatar.LoadAvatar.Response.OK>(options: Avatar.LoadAvatar.Options): Promise<import("./definitions/AvatarAsResponse").AvatarAsResponse>;
    /**
  * Deletes an avatar from a project or issue type.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-owningobjectid-avatar-id-delete
  * @param options Request options.
  */
    deleteAvatar<T = Avatar.DeleteAvatar.Response.OK>(options: Avatar.DeleteAvatar.Options): Promise<undefined>;
}
declare class AllGroup extends BaseGroup {
    private issueHelper;
    constructor(connection: string, options: ConnectionOptions, issueHelper: IssueHelper);
    /**
  * Creates an issue or, where the option to create subtasks is enabled in Jira, a subtask. A transition may be applied, to move the issue or subtask to a workflow step other than the default start step, and issue properties set.
  
  The content of the issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issue's create screen. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Creating a subtask differs from creating an issue as follows:
  
   *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
   *  `parent` must contain the ID or key of the parent issue.
  
  In a next-gen project any issue may be made a child providing that the parent and child are members of the same project. In a classic project the parent field is only valid for subtasks.
  
  **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which the issue or subtask is created.
  * Recommended usage: Issue.createIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-post
  * @param options Request options.
  */
    createIssue<T = Issue.CreateIssue.Response.OK>(options: Issue.CreateIssue.Options): Promise<import("./definitions/CreatedIssueAsResponse").CreatedIssueAsResponse>;
    /**
  * Creates issues and, where the option to create subtasks is enabled in Jira, subtasks. Transitions may be applied, to move the issues or subtasks to a workflow step other than the default start step, and issue properties set.
  
  The content of each issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issues' create screens. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Creating a subtask differs from creating an issue as follows:
  
   *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
   *  `parent` the must contain the ID or key of the parent issue.
  
  **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which each issue or subtask is created.
  * Recommended usage: Issue.createIssues
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-bulk-post
  * @param options Request options.
  */
    createIssues<T = Issue.CreateIssues.Response.OK>(options: Issue.CreateIssues.Options): Promise<import("./definitions/CreatedIssuesAsResponse").CreatedIssuesAsResponse>;
    /**
  * Returns the details for an issue.
  
  The issue is identified by its ID or key, however, if the identifier doesn't match an issue, a case-insensitive search and check for moved issues is performed. If a matching issue is found its details are returned, a 302 or other redirect is **not** returned. The issue key returned in the response is the key of the issue found.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.getIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-get
  * @param options Request options.
  */
    getIssue<T = ManagedIssue.Read.Response>(options: Issue.GetIssue.Options): Promise<T>;
    /**
  * Edits an issue. A transition may be applied and issue properties updated as part of the edit.
  
  The edits to the issue's fields are defined using `update` and `fields`. The fields that can be edited are determined using [ Get edit issue metadata](#api-rest-api-3-issue-issueIdOrKey-editmeta-get).
  
  The parent field may be set by key or ID. For standard issue types, the parent may be removed by setting `update.parent.set.none` to *true*. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Connect app users with admin permissions (from user permissions and app scopes) can override the screen security configuration using `overrideScreenSecurity` and `overrideEditableFlag`.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.editIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-put
  * @param options Request options.
  */
    editIssue<T = undefined>(options: Issue.EditIssue.Options): Promise<Issue.EditIssue.Response.OK>;
    /**
  * Deletes an issue.
  
  An issue cannot be deleted if it has one or more subtasks. To delete an issue with subtasks, set `deleteSubtasks`. This causes the issue's subtasks to be deleted with the issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Delete issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.deleteIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-delete
  * @param options Request options.
  */
    deleteIssue<T = Issue.DeleteIssue.Response.OK>(options: Issue.DeleteIssue.Options): Promise<undefined>;
    /**
  * Assigns an issue to a user. Use this operation when the calling user does not have the *Edit Issues* permission but has the *Assign issue* permission for the project that the issue is in.
  
  If `name` or `accountId` is set to:
  
   *  `"-1"`, the issue is assigned to the default assignee for the project.
   *  `null`, the issue is set to unassigned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* and *Assign Issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.assignIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-assignee-put
  * @param options Request options.
  */
    assignIssue<T = Issue.AssignIssue.Response.OK>(options: Issue.AssignIssue.Options): Promise<any>;
    /**
  * Returns a [paginated](#pagination) list of all changelogs for an issue sorted by date, starting from the oldest.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.getChangeLogs
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-changelog-get
  * @param options Request options.
  */
    getIssueChangeLogs<T = Issue.GetChangeLogs.Response.OK>(options: Issue.GetChangeLogs.Options): Promise<import("./definitions/PageBeanChangelogAsResponse").PageBeanChangelogAsResponse>;
    /**
  * Returns changelogs for an issue specified by a list of changelog IDs.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.getChangeLogsById
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-changelog-list-post
  * @param options Request options.
  */
    getIssueChangeLogsById<T = Issue.GetChangeLogsById.Response.OK>(options: Issue.GetChangeLogsById.Options): Promise<import("./definitions/PageOfChangelogsAsResponse").PageOfChangelogsAsResponse>;
    /**
  * Creates an email notification for an issue and adds it to the mail queue.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.sendNotification
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-notify-post
  * @param options Request options.
  */
    sendNotificationForIssue<T = Issue.SendNotification.Response.OK>(options: Issue.SendNotification.Options): Promise<any>;
    /**
  * Returns all issue types.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issue types are only returned as follows:
  
   *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), all issue types are returned.
   *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for one or more projects, the issue types associated with the projects the user has permission to browse are returned.
  * Recommended usage: Issue.Type.getTypesForUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-get
  * @param options Request options.
  */
    getIssueTypesForUser<T = Issue.Type.GetTypesForUser.Response.OK>(options?: Issue.Type.GetTypesForUser.Options): Promise<Issue.Type.GetTypesForUser.Response.OK>;
    /**
  * Creates an issue type and adds it to the default issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.createType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-post
  * @param options Request options.
  */
    createIssueType<T = Issue.Type.CreateType.Response.OK>(options: Issue.Type.CreateType.Options): Promise<import("./definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
    /**
  * Returns issue types for a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in the relevant project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.getTypesForProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-project-get
  * @param options Request options.
  */
    getIssueTypesForProject<T = Issue.Type.GetTypesForProject.Response.OK>(options: Issue.Type.GetTypesForProject.Options): Promise<Issue.Type.GetTypesForProject.Response.OK>;
    /**
  * Returns an issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in a project the issue type is associated with or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.getType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-get
  * @param options Request options.
  */
    getIssueType<T = Issue.Type.GetType.Response.OK>(options: Issue.Type.GetType.Options): Promise<import("./definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
    /**
  * Updates the issue type.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.updateType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-put
  * @param options Request options.
  */
    updateIssueType<T = Issue.Type.UpdateType.Response.OK>(options: Issue.Type.UpdateType.Options): Promise<import("./definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
    /**
  * Deletes the issue type. If the issue type is in use, all uses are updated with the alternative issue type (`alternativeIssueTypeId`). A list of alternative issue types are obtained from the [Get alternative issue types](#api-rest-api-3-issuetype-id-alternatives-get) resource.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.deleteType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-delete
  * @param options Request options.
  */
    deleteIssueType<T = Issue.Type.DeleteType.Response.OK>(options: Issue.Type.DeleteType.Options): Promise<undefined>;
    /**
  * Returns a list of issue types that can be used to replace the issue type. The alternative issue types are those assigned to the same workflow scheme, field configuration scheme, and screen scheme.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Issue.Type.getAlternativeTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-alternatives-get
  * @param options Request options.
  */
    getAlternativeIssueTypes<T = Issue.Type.GetAlternativeTypes.Response.OK>(options: Issue.Type.GetAlternativeTypes.Options): Promise<Issue.Type.GetAlternativeTypes.Response.OK>;
    /**
  * Loads an avatar for the issue type.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST \ --user email@example.com:<api_token> \ --header 'X-Atlassian-Token: no-check' \ --header 'Content-Type: image/< image_type>' \ --data-binary "<@/path/to/file/with/your/avatar>" \ --url 'https://your-domain.atlassian.net/rest/api/3/issuetype/{issueTypeId}'This`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar, use [ Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.loadTypeAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-avatar2-post
  * @param options Request options.
  */
    loadIssueTypeAvatar<T = Issue.Type.LoadTypeAvatar.Response.OK>(options: Issue.Type.LoadTypeAvatar.Options): Promise<import("./definitions/AvatarAsResponse").AvatarAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.
  
  Only company-managed projects associated with an issue type screen scheme are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.getProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-project-get
  * @param options Request options.
  */
    getIssueTypeScreenSchemeProjects<T = Issue.Type.Screen.Scheme.GetProjects.Response.OK>(options: Issue.Type.Screen.Scheme.GetProjects.Options): Promise<import("./definitions/PageBeanProjectDetailsAsResponse").PageBeanProjectDetailsAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type screen schemes.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-get
  * @param options Request options.
  */
    getIssueTypeScreenSchemes<T = Issue.Type.Screen.Scheme.GetSchemes.Response.OK>(options?: Issue.Type.Screen.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanIssueTypeScreenSchemeAsResponse").PageBeanIssueTypeScreenSchemeAsResponse>;
    /**
  * Creates an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-post
  * @param options Request options.
  */
    createIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.CreateScheme.Response.OK>(options: Issue.Type.Screen.Scheme.CreateScheme.Options): Promise<import("./definitions/IssueTypeScreenSchemeIdAsResponse").IssueTypeScreenSchemeIdAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type screen scheme items.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.getSchemeItems
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-mapping-get
  * @param options Request options.
  */
    getIssueTypeScreenSchemeItems<T = Issue.Type.Screen.Scheme.GetSchemeItems.Response.OK>(options?: Issue.Type.Screen.Scheme.GetSchemeItems.Options): Promise<import("./definitions/PageBeanIssueTypeScreenSchemeItemAsResponse").PageBeanIssueTypeScreenSchemeItemAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.getSchemesForProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-project-get
  * @param options Request options.
  */
    getIssueTypeScreenSchemesForProjects<T = Issue.Type.Screen.Scheme.GetSchemesForProjects.Response.OK>(options: Issue.Type.Screen.Scheme.GetSchemesForProjects.Options): Promise<import("./definitions/PageBeanIssueTypeScreenSchemesProjectsAsResponse").PageBeanIssueTypeScreenSchemesProjectsAsResponse>;
    /**
  * Assigns an issue type screen scheme to a project.
  
  Issue type screen schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.assignSchemeToProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-put
  * @param options Request options.
  */
    assignIssueTypeScreenSchemeToProject<T = Issue.Type.Screen.Scheme.AssignSchemeToProject.Response.OK>(options: Issue.Type.Screen.Scheme.AssignSchemeToProject.Options): Promise<any>;
    /**
  * Updates an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-put
  * @param options Request options.
  */
    updateIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.UpdateScheme.Response.OK>(options: Issue.Type.Screen.Scheme.UpdateScheme.Options): Promise<any>;
    /**
  * Deletes an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-delete
  * @param options Request options.
  */
    deleteIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.DeleteScheme.Response.OK>(options: Issue.Type.Screen.Scheme.DeleteScheme.Options): Promise<any>;
    /**
  * Appends issue type to screen scheme mappings to an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.appendMappings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-put
  * @param options Request options.
  */
    appendMappingsToIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.AppendMappings.Response.OK>(options: Issue.Type.Screen.Scheme.AppendMappings.Options): Promise<any>;
    /**
  * Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.updateDefaultScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-default-put
  * @param options Request options.
  */
    updateDefaultIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.UpdateDefaultScheme.Response.OK>(options: Issue.Type.Screen.Scheme.UpdateDefaultScheme.Options): Promise<any>;
    /**
  * Removes issue type to screen scheme mappings from an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Screen.Scheme.removeMappings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-remove-post
  * @param options Request options.
  */
    removeMappingsFromIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.RemoveMappings.Response.OK>(options: Issue.Type.Screen.Scheme.RemoveMappings.Options): Promise<any>;
    /**
  * Returns all the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys of the issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the property keys of any issue type.
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the property keys of any issue types associated with the projects the user has permission to browse.
  * Recommended usage: Issue.Type.Property.getPropertyKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-get
  * @param options Request options.
  */
    getIssueTypePropertyKeys<T = Issue.Type.Property.GetPropertyKeys.Response.OK>(options: Issue.Type.Property.GetPropertyKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the key and value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the details of any issue type.
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the details of any issue types associated with the projects the user has permission to browse.
  * Recommended usage: Issue.Type.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-get
  * @param options Request options.
  */
    getIssueTypeProperty<T = Issue.Type.Property.GetProperty.Response.OK>(options: Issue.Type.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Creates or updates the value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). Use this resource to store and update data against an issue type.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-put
  * @param options Request options.
  */
    setIssueTypeProperty<T = Issue.Type.Property.SetProperty.Response.OK>(options: Issue.Type.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-delete
  * @param options Request options.
  */
    deleteIssueTypeProperty<T = Issue.Type.Property.DeleteProperty.Response.OK>(options: Issue.Type.Property.DeleteProperty.Options): Promise<undefined>;
    /**
  * Returns a [paginated](#pagination) list of issue type schemes.
  
  Only issue type schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-get
  * @param options Request options.
  */
    getIssueTypeSchemes<T = Issue.Type.Scheme.GetSchemes.Response.OK>(options?: Issue.Type.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanIssueTypeSchemeAsResponse").PageBeanIssueTypeSchemeAsResponse>;
    /**
  * Creates an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-post
  * @param options Request options.
  */
    createIssueTypeScheme<T = Issue.Type.Scheme.CreateScheme.Response.OK>(options: Issue.Type.Scheme.CreateScheme.Options): Promise<import("./definitions/IssueTypeSchemeIDAsResponse").IssueTypeSchemeIDAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type scheme items.
  
  Only issue type scheme items used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.getSchemeItems
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-mapping-get
  * @param options Request options.
  */
    getIssueTypeSchemeItems<T = Issue.Type.Scheme.GetSchemeItems.Response.OK>(options?: Issue.Type.Scheme.GetSchemeItems.Options): Promise<import("./definitions/PageBeanIssueTypeSchemeMappingAsResponse").PageBeanIssueTypeSchemeMappingAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of issue type schemes and, for each issue type scheme, a list of the projects that use it.
  
  Only issue type schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.getSchemesForProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-project-get
  * @param options Request options.
  */
    getIssueTypeSchemesForProjects<T = Issue.Type.Scheme.GetSchemesForProjects.Response.OK>(options: Issue.Type.Scheme.GetSchemesForProjects.Options): Promise<import("./definitions/PageBeanIssueTypeSchemeProjectsAsResponse").PageBeanIssueTypeSchemeProjectsAsResponse>;
    /**
  * Assigns an issue type scheme to a project.
  
  If any issues in the project are assigned issue types not present in the new scheme, the operation will fail. To complete the assignment those issues must be updated to use issue types in the new scheme.
  
  Issue type schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.assignToProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-put
  * @param options Request options.
  */
    assignIssueTypeSchemeToProject<T = Issue.Type.Scheme.AssignToProject.Response.OK>(options: Issue.Type.Scheme.AssignToProject.Options): Promise<any>;
    /**
  * Adds issue types to an issue type scheme.
  
  The added issue types are appended to the issue types list.
  
  If any of the issue types exist in the issue type scheme, the operation fails and no issue types are added.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.addIssueTypesToScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-put
  * @param options Request options.
  */
    addIssueTypesToIssueTypeScheme<T = Issue.Type.Scheme.AddIssueTypesToScheme.Response.OK>(options: Issue.Type.Scheme.AddIssueTypesToScheme.Options): Promise<any>;
    /**
  * Updates an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-put
  * @param options Request options.
  */
    updateIssueTypeScheme<T = Issue.Type.Scheme.UpdateScheme.Response.OK>(options: Issue.Type.Scheme.UpdateScheme.Options): Promise<any>;
    /**
  * Deletes an issue type scheme.
  
  Only issue type schemes used in classic projects can be deleted.
  
  Any projects assigned to the scheme are reassigned to the default issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-delete
  * @param options Request options.
  */
    deleteIssueTypeScheme<T = Issue.Type.Scheme.DeleteScheme.Response.OK>(options: Issue.Type.Scheme.DeleteScheme.Options): Promise<any>;
    /**
  * Changes the order of issue types in an issue type scheme.
  
  The request body parameters must meet the following requirements:
  
   *  all of the issue types must belong to the issue type scheme.
   *  either `after` or `position` must be provided.
   *  the issue type in `after` must not be in the issue type list.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.changeIssueTypesOrder
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-move-put
  * @param options Request options.
  */
    changeIssueTypeSchemeIssueTypesOrder<T = Issue.Type.Scheme.ChangeIssueTypesOrder.Response.OK>(options: Issue.Type.Scheme.ChangeIssueTypesOrder.Options): Promise<any>;
    /**
  * Removes an issue type from an issue type scheme.
  
  This operation cannot remove:
  
   *  any issue type used by issues.
   *  any issue types from the default issue type scheme.
   *  the last standard issue type from an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.Scheme.removeIssueTypesFromScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-issuetypeid-delete
  * @param options Request options.
  */
    removeIssueTypesFromIssueTypeScheme<T = Issue.Type.Scheme.RemoveIssueTypesFromScheme.Response.OK>(options: Issue.Type.Scheme.RemoveIssueTypesFromScheme.Options): Promise<any>;
    /**
  * Returns system and custom issue fields according to the following rules:
  
   *  Fields that cannot be added to the issue navigator are always returned.
   *  Fields that cannot be placed on an issue screen are always returned.
   *  Fields that depend on global Jira settings are only returned if the setting is enabled. That is, timetracking fields, subtasks, votes, and watches.
   *  For all other fields, this operation only returns the fields that the user has permission to view (that is, the field is used in at least one project that the user has *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.)
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Issue.Field.getFields
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-field-get
  * @param options Request options.
  */
    getIssueFields<T = Issue.Field.GetFields.Response.OK>(options?: Issue.Field.GetFields.Options): Promise<Issue.Field.GetFields.Response.OK>;
    /**
  * Returns a [paginated](#pagination) list of fields for Classic Jira projects. The list can include:
  
   *  all fields.
   *  specific fields, by defining `id`.
   *  fields that contain a string in the field name or description, by defining `query`.
   *  specific fields that contain a string in the field name or description, by defining `id` and `query`.
  
  Only custom fields can be queried, `type` must be set to `custom`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.getFieldsPaginated
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-field-search-get
  * @param options Request options.
  */
    getFieldsPaginated<T = Issue.Field.GetFieldsPaginated.Response.OK>(options?: Issue.Field.GetFieldsPaginated.Options): Promise<import("./definitions/PageBeanFieldAsResponse").PageBeanFieldAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of the contexts a field is used in. Deprecated, use [ Get custom field contexts](#api-rest-api-3-field-fieldId-context-get).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.getContexts
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-contexts-get
  * @param options Request options.
  * @deprecated
  */
    getFieldContexts<T = Issue.Field.GetContexts.Response.OK>(options: Issue.Field.GetContexts.Options): Promise<import("./definitions/PageBeanContextAsResponse").PageBeanContextAsResponse>;
    /**
  * Deletes a custom field. The custom field is deleted whether it is in the trash or not. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  This operation is [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.deleteField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-delete
  * @param options Request options.
  */
    deleteIssueCustomField<T = Issue.Field.DeleteField.Response.OK>(options: Issue.Field.DeleteField.Options): Promise<undefined>;
    /**
  * Restores a custom field from trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.restoreField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-restore-post
  * @param options Request options.
  */
    restoreIssueCustomField<T = Issue.Field.RestoreField.Response.OK>(options: Issue.Field.RestoreField.Options): Promise<any>;
    /**
  * Moves a custom field to trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.moveToTrash
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-trash-post
  * @param options Request options.
  */
    moveIssueCustomFieldToTrash<T = Issue.Field.MoveToTrash.Response.OK>(options: Issue.Field.MoveToTrash.Options): Promise<any>;
    /**
  * Creates a field configuration. The field configuration is created with the same field properties as the default configuration, with all the fields being optional.
  
  This operation can only create configurations for use in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.createConfiguration
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-post
  * @param options Request options.
  */
    createIssueFieldConfiguration<T = Issue.Field.Configuration.CreateConfiguration.Response.OK>(options: Issue.Field.Configuration.CreateConfiguration.Options): Promise<import("./definitions/FieldConfigurationAsResponse").FieldConfigurationAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of field configurations. The list can be for all field configurations or a subset determined by any combination of these criteria:
  
   *  a list of field configuration item IDs.
   *  whether the field configuration is a default.
   *  whether the field configuration name or description contains a query string.
  
  Only field configurations used in company-managed (classic) projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.getConfigurations
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-get
  * @param options Request options.
  */
    getIssueFieldConfigurations<T = Issue.Field.Configuration.GetConfigurations.Response.OK>(options?: Issue.Field.Configuration.GetConfigurations.Options): Promise<import("./definitions/PageBeanFieldConfigurationDetailsAsResponse").PageBeanFieldConfigurationDetailsAsResponse>;
    /**
  * Updates a field configuration. The name and the description provided in the request override the existing values.
  
  This operation can only update configurations used in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.updateConfiguration
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-put
  * @param options Request options.
  */
    updateIssueFieldConfiguration<T = Issue.Field.Configuration.UpdateConfiguration.Response.OK>(options: Issue.Field.Configuration.UpdateConfiguration.Options): Promise<any>;
    /**
  * Deletes a field configuration.
  
  This operation can only delete configurations used in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.deleteConfiguration
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-delete
  * @param options Request options.
  */
    deleteIssueFieldConfiguration<T = Issue.Field.Configuration.DeleteConfiguration.Response.OK>(options: Issue.Field.Configuration.DeleteConfiguration.Options): Promise<any>;
    /**
  * Returns a [paginated](#pagination) list of all fields for a configuration.
  
  Only the fields from configurations used in company-managed (classic) projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.getConfigurationItems
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-id-fields-get
  * @param options Request options.
  */
    getIssueFieldConfigurationItems<T = Issue.Field.Configuration.GetConfigurationItems.Response.OK>(options: Issue.Field.Configuration.GetConfigurationItems.Options): Promise<import("./definitions/PageBeanFieldConfigurationItemAsResponse").PageBeanFieldConfigurationItemAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of field configuration issue type items.
  
  Only items used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.getConfigurationIssueTypeItems
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfigurationscheme-mapping-get
  * @param options Request options.
  */
    getIssueFieldConfigurationIssueTypeItems<T = Issue.Field.Configuration.GetConfigurationIssueTypeItems.Response.OK>(options?: Issue.Field.Configuration.GetConfigurationIssueTypeItems.Options): Promise<import("./definitions/PageBeanFieldConfigurationIssueTypeItemAsResponse").PageBeanFieldConfigurationIssueTypeItemAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of field configuration schemes.
  
  Only field configuration schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-get
  * @param options Request options.
  */
    getIssueFieldConfigurationSchemes<T = Issue.Field.Configuration.GetSchemes.Response.OK>(options?: Issue.Field.Configuration.GetSchemes.Options): Promise<import("./definitions/PageBeanFieldConfigurationSchemeAsResponse").PageBeanFieldConfigurationSchemeAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of field configuration schemes and, for each scheme, a list of the projects that use it.
  
  The list is sorted by field configuration scheme ID. The first item contains the list of project IDs assigned to the default field configuration scheme.
  
  Only field configuration schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.Scheme.getSchemesForProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfigurationscheme-project-get
  * @param options Request options.
  */
    getIssueFieldConfigurationSchemesForProjects<T = Issue.Field.Configuration.Scheme.GetSchemesForProjects.Response.OK>(options: Issue.Field.Configuration.Scheme.GetSchemesForProjects.Options): Promise<import("./definitions/PageBeanFieldConfigurationSchemeProjectsAsResponse").PageBeanFieldConfigurationSchemeProjectsAsResponse>;
    /**
  * Assigns a field configuration scheme to a project. If the field configuration scheme ID is `null`, the operation assigns the default field configuration scheme.
  
  Field configuration schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Configuration.Scheme.assignSchemeToProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-project-put
  * @param options Request options.
  */
    assignIssueFieldConfigurationSchemeToProject<T = Issue.Field.Configuration.Scheme.AssignSchemeToProject.Response.OK>(options: Issue.Field.Configuration.Scheme.AssignSchemeToProject.Options): Promise<any>;
    /**
  * Creates a custom field.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.createField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-field-post
  * @param options Request options.
  */
    createIssueCustomField<T = Issue.Field.Custom.CreateField.Response.OK>(options: Issue.Field.Custom.CreateField.Options): Promise<import("./definitions/FieldDetailsAsResponse").FieldDetailsAsResponse>;
    /**
  * Updates a custom field.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.updateField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-put
  * @param options Request options.
  */
    updateIssueCustomField<T = Issue.Field.Custom.UpdateField.Response.OK>(options: Issue.Field.Custom.UpdateField.Options): Promise<any>;
    /**
  * Returns a custom field option. For example, an option in a select list.
  
  Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The custom field option is returned as follows:
  
   *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the custom field is used in, and the field is visible in at least one layout the user has permission to view.
  * Recommended usage: Issue.Field.Custom.Option.getOption
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-customFieldOption-id-get
  * @param options Request options.
  * @deprecated
  */
    getIssueCustomFieldOption<T = Issue.Field.Custom.Option.GetOption.Response.OK>(options: Issue.Field.Custom.Option.GetOption.Options): Promise<import("./definitions/CustomFieldOptionAsResponse").CustomFieldOptionAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of [ contexts](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html) for a custom field. Contexts can be returned as follows:
  
   *  With no other parameters set, all contexts.
   *  By defining `id` only, all contexts from the list of IDs.
   *  By defining `isAnyIssueType`, limit the list of contexts returned to either those that apply to all issue types (true) or those that apply to only a subset of issue types (false)
   *  By defining `isGlobalContext`, limit the list of contexts return to either those that apply to all projects (global contexts) (true) or those that apply to only a subset of projects (false).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.getContexts
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-get
  * @param options Request options.
  */
    getIssueCustomFieldContexts<T = Issue.Field.Custom.Context.GetContexts.Response.OK>(options: Issue.Field.Custom.Context.GetContexts.Options): Promise<import("./definitions/PageBeanCustomFieldContextAsResponse").PageBeanCustomFieldContextAsResponse>;
    /**
  * Creates a custom field context.
  
  If `projectIds` is empty, a global context is created. A global context is one that applies to all project. If `issueTypeIds` is empty, the context applies to all issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.createContext
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-post
  * @param options Request options.
  */
    createIssueCustomFieldContext<T = Issue.Field.Custom.Context.CreateContext.Response.OK>(options: Issue.Field.Custom.Context.CreateContext.Options): Promise<import("./definitions/CreateCustomFieldContextAsResponse").CreateCustomFieldContextAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of defaults for a custom field. The results can be filtered by `contextId`, otherwise all values are returned. If no defaults are set for a context, nothing is returned.
  The returned object depends on type of the custom field:
  
   *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
   *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
   *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
   *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
   *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
   *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
   *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
   *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group picker.
   *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group picker.
   *  `CustomFieldContextDefaultValueURL` (type `url`) for URL.
   *  `CustomFieldContextDefaultValueProject` (type `project`) for project picker.
   *  `CustomFieldContextDefaultValueFloat` (type `float`) for float (a floating-point number).
   *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
   *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text field.
   *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area field.
   *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) field.
   *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version picker.
   *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version picker.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.getDefaultContexts
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-get
  * @param options Request options.
  */
    getIssueCustomFieldDefaultContexts<T = Issue.Field.Custom.Context.GetDefaultContexts.Response.OK>(options: Issue.Field.Custom.Context.GetDefaultContexts.Options): Promise<import("./definitions/PageBeanCustomFieldContextDefaultValueAsResponse").PageBeanCustomFieldContextDefaultValueAsResponse>;
    /**
  * Sets default for contexts of a custom field. Default are defined using these objects:
  
   *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
   *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
   *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
   *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
   *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
   *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
   *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
   *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group picker.
   *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group picker.
   *  `CustomFieldContextDefaultValueURL` (type `url`) for URL.
   *  `CustomFieldContextDefaultValueProject` (type `project`) for project picker.
   *  `CustomFieldContextDefaultValueFloat` (type `float`) for float (a floating-point number).
   *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
   *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text field.
   *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area field.
   *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) field.
   *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version picker.
   *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version picker.
  
  Only one type of default object can be included in a request. To remove a default for a context, set the default parameter to `null`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.setDefaultContexts
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-put
  * @param options Request options.
  */
    setIssueCustomFieldDefaultContexts<T = Issue.Field.Custom.Context.SetDefaultContexts.Response.OK>(options: Issue.Field.Custom.Context.SetDefaultContexts.Options): Promise<any>;
    /**
  * Returns a [paginated](#pagination) list of context to issue type mappings for a custom field. Mappings are returned for all contexts or a list of contexts. Mappings are ordered first by context ID and then by issue type ID.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.getIssueTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-issuetypemapping-get
  * @param options Request options.
  */
    getIssueCustomFieldIssueTypesForContext<T = Issue.Field.Custom.Context.GetIssueTypes.Response.OK>(options: Issue.Field.Custom.Context.GetIssueTypes.Options): Promise<import("./definitions/PageBeanIssueTypeToContextMappingAsResponse").PageBeanIssueTypeToContextMappingAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of context to project mappings for a custom field. The result can be filtered by `contextId`. Otherwise, all mappings are returned. Invalid IDs are ignored.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.getProjectMappings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-projectmapping-get
  * @param options Request options.
  */
    getIssueCustomFieldContextToProjectMappings<T = Issue.Field.Custom.Context.GetProjectMappings.Response.OK>(options: Issue.Field.Custom.Context.GetProjectMappings.Options): Promise<import("./definitions/PageBeanCustomFieldContextProjectMappingAsResponse").PageBeanCustomFieldContextProjectMappingAsResponse>;
    /**
  * Updates a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.updateContext
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-put
  * @param options Request options.
  */
    updateIssueCustomFieldContext<T = Issue.Field.Custom.Context.UpdateContext.Response.OK>(options: Issue.Field.Custom.Context.UpdateContext.Options): Promise<any>;
    /**
  * Adds issue types to a custom field context, appending the issue types to the issue types list.
  
  A custom field context without any issue types applies to all issue types. Adding issue types to such a custom field context would result in it applying to only the listed issue types.
  
  If any of the issue types exists in the custom field context, the operation fails and no issue types are added.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.addIssueTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-put
  * @param options Request options.
  */
    addIssueTypesToIssueCustomFieldContext<T = Issue.Field.Custom.Context.AddIssueTypes.Response.OK>(options: Issue.Field.Custom.Context.AddIssueTypes.Options): Promise<any>;
    /**
  * Removes issue types from a custom field context.
  
  A custom field context without any issue types applies to all issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.removeIssueTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-remove-post
  * @param options Request options.
  */
    removeIssueTypesFromIssueCustomFieldContext<T = Issue.Field.Custom.Context.RemoveIssueTypes.Response.OK>(options: Issue.Field.Custom.Context.RemoveIssueTypes.Options): Promise<any>;
    /**
  * Assigns a custom field context to projects.
  
  If any project in the request is assigned to any context of the custom field, the operation fails.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.assignToProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-put
  * @param options Request options.
  */
    assignIssueCustomFieldContextToProjects<T = Issue.Field.Custom.Context.AssignToProjects.Response.OK>(options: Issue.Field.Custom.Context.AssignToProjects.Options): Promise<any>;
    /**
  * Removes a custom field context from projects.
  
  A custom field context without any projects applies to all projects. Removing all projects from a custom field context would result in it applying to all projects.
  
  If any project in the request is not assigned to the context, or the operation would result in two global contexts for the field, the operation fails.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.removeFromProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-remove-post
  * @param options Request options.
  */
    removeIssueCustomFieldContextFromProjects<T = Issue.Field.Custom.Context.RemoveFromProjects.Response.OK>(options: Issue.Field.Custom.Context.RemoveFromProjects.Options): Promise<any>;
    /**
  * Returns a [paginated](#pagination) list of all custom field option for a context. Options are returned first then cascading options, in the order they display in Jira.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.Option.getOptions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-get
  * @param options Request options.
  */
    getIssueCustomFieldContextOptions<T = Issue.Field.Custom.Context.Option.GetOptions.Response.OK>(options: Issue.Field.Custom.Context.Option.GetOptions.Options): Promise<import("./definitions/PageBeanCustomFieldContextOptionAsResponse").PageBeanCustomFieldContextOptionAsResponse>;
    /**
  * Creates options and, where the custom select field is of the type Select List (cascading), cascading options for a custom select field. The options are added to a context of the field.
  
  The maximum number of options that can be created per request is 1000 and each field can have a maximum of 10000 options.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.Option.createOptions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-post
  * @param options Request options.
  */
    createIssueCustomFieldContextOptions<T = Issue.Field.Custom.Context.Option.CreateOptions.Response.OK>(options: Issue.Field.Custom.Context.Option.CreateOptions.Options): Promise<import("./definitions/CustomFieldCreatedContextOptionsListAsResponse").CustomFieldCreatedContextOptionsListAsResponse>;
    /**
  * Updates the options of a custom field.
  
  If any of the options are not found, no options are updated. Options where the values in the request match the current values aren't updated and aren't reported in the response.
  
  Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.Option.updateOptions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-put
  * @param options Request options.
  */
    updateIssueCustomFieldContextOptions<T = Issue.Field.Custom.Context.Option.UpdateOptions.Response.OK>(options: Issue.Field.Custom.Context.Option.UpdateOptions.Options): Promise<import("./definitions/CustomFieldUpdatedContextOptionsListAsResponse").CustomFieldUpdatedContextOptionsListAsResponse>;
    /**
  * Changes the order of custom field options or cascading options in a context.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.Option.reorderOptions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-move-put
  * @param options Request options.
  */
    reorderIssueCustomFieldContextOptions<T = Issue.Field.Custom.Context.Option.ReorderOptions.Response.OK>(options: Issue.Field.Custom.Context.Option.ReorderOptions.Options): Promise<any>;
    /**
  * Deletes a custom field option.
  
  Options with cascading options cannot be deleted without deleting the cascading options first.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Field.Custom.Context.Option.deleteOption
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-optionid-delete
  * @param options Request options.
  */
    deleteIssueCustomFieldContextOption<T = Issue.Field.Custom.Context.Option.DeleteOption.Response.OK>(options: Issue.Field.Custom.Context.Option.DeleteOption.Options): Promise<undefined>;
    /**
  * Returns worklogs for an issue, starting from the oldest worklog or from the worklog started on or after a date and time.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Workloads are only returned where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Worklog.getWorklogs
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-get
  * @param options Request options.
  */
    getIssueWorklogs<T = Issue.Worklog.GetWorklogs.Response.OK>(options: Issue.Worklog.GetWorklogs.Options): Promise<import("./definitions/PageOfWorklogsAsResponse").PageOfWorklogsAsResponse>;
    /**
  * Adds a worklog to an issue.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Work on issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Worklog.addWorklog
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-post
  * @param options Request options.
  */
    addIssueWorklog<T = Issue.Worklog.AddWorklog.Response.OK>(options: Issue.Worklog.AddWorklog.Options): Promise<import("./definitions/WorklogAsResponse").WorklogAsResponse>;
    /**
  * Returns a worklog.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Worklog.getWorklog
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-get
  * @param options Request options.
  */
    getIssueWorklog<T = Issue.Worklog.GetWorklog.Response.OK>(options: Issue.Worklog.GetWorklog.Options): Promise<import("./definitions/WorklogAsResponse").WorklogAsResponse>;
    /**
  * Updates a worklog.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Worklog.updateWorklog
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-put
  * @param options Request options.
  */
    updateIssueWorklog<T = Issue.Worklog.UpdateWorklog.Response.OK>(options: Issue.Worklog.UpdateWorklog.Options): Promise<import("./definitions/WorklogAsResponse").WorklogAsResponse>;
    /**
  * Deletes a worklog from an issue.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Delete all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any worklog or *Delete own worklogs* to delete worklogs created by the user,
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Worklog.deleteWorklog
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-worklog-id-delete
  * @param options Request options.
  */
    deleteIssueWorklog<T = Issue.Worklog.DeleteWorklog.Response.OK>(options: Issue.Worklog.DeleteWorklog.Options): Promise<undefined>;
    /**
  * Returns a list of IDs and delete timestamps for worklogs deleted after a date and time.
  
  This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
  
  This resource does not return worklogs deleted during the minute preceding the request.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Issue.Worklog.getDeletedIds
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-deleted-get
  * @param options Request options.
  */
    getDeletedIssueWorklogIds<T = Issue.Worklog.GetDeletedIds.Response.OK>(options?: Issue.Worklog.GetDeletedIds.Options): Promise<import("./definitions/ChangedWorklogsAsResponse").ChangedWorklogsAsResponse>;
    /**
  * Returns worklog details for a list of worklog IDs.
  
  The returned list of worklogs is limited to 1000 items.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
  
   *  the worklog is set as *Viewable by All Users*.
   *  the user is a member of a project role or group with permission to view the worklog.
  * Recommended usage: Issue.Worklog.getFromIds
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-list-post
  * @param options Request options.
  */
    getIssueWorklogsFromIds<T = Issue.Worklog.GetFromIds.Response.OK>(options: Issue.Worklog.GetFromIds.Options): Promise<Issue.Worklog.GetFromIds.Response.OK>;
    /**
  * Returns a list of IDs and update timestamps for worklogs updated after a date and time.
  
  This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
  
  This resource does not return worklogs updated during the minute preceding the request.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
  
   *  the worklog is set as *Viewable by All Users*.
   *  the user is a member of a project role or group with permission to view the worklog.
  * Recommended usage: Issue.Worklog.getUpdatedIds
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-worklog-updated-get
  * @param options Request options.
  */
    getUpdatedIssueWorklogIds<T = Issue.Worklog.GetUpdatedIds.Response.OK>(options?: Issue.Worklog.GetUpdatedIds.Options): Promise<import("./definitions/ChangedWorklogsAsResponse").ChangedWorklogsAsResponse>;
    /**
  * Returns the keys of all properties for a worklog.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Worklog.Property.getKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-get
  * @param options Request options.
  */
    getWorklogPropertyKeys<T = Issue.Worklog.Property.GetKeys.Response.OK>(options: Issue.Worklog.Property.GetKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the value of a worklog property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Worklog.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-get
  * @param options Request options.
  */
    getWorklogProperty<T = Issue.Worklog.Property.GetProperty.Response.OK>(options: Issue.Worklog.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of a worklog property. Use this operation to store custom data against the worklog.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Worklog.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-put
  * @param options Request options.
  */
    setWorklogProperty<T = Issue.Worklog.Property.SetProperty.Response.OK>(options: Issue.Worklog.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes a worklog property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Worklog.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-delete
  * @param options Request options.
  */
    deleteWorklogProperty<T = Issue.Worklog.Property.DeleteProperty.Response.OK>(options: Issue.Worklog.Property.DeleteProperty.Options): Promise<undefined>;
    /**
  * Deletes an attachment from an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the project holding the issue containing the attachment:
  
   *  *Delete own attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by the calling user.
   *  *Delete all attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by any user.
  * Recommended usage: Issue.Attachment.deleteAttachment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-delete
  * @param options Request options.
  */
    deleteIssueAttachment<T = Issue.Attachment.DeleteAttachment.Response.OK>(options: Issue.Attachment.DeleteAttachment.Options): Promise<undefined>;
    /**
  * Adds one or more attachments to an issue. Attachments are posted as multipart/form-data ([RFC 1867](https://www.ietf.org/rfc/rfc1867.txt)).
  
  Note that:
  
   *  The request must have a `X-Atlassian-Token: no-check` header, if not it is blocked. See [Special headers](#special-request-headers) for more information.
   *  The name of the multipart/form-data parameter that contains the attachments must be `file`.
  
  The following examples upload a file called *myfile.txt* to the issue *TEST-123*:
  
  #### curl ####
  
      curl --location --request POST 'https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments'
       -u 'email@example.com:<api_token>'
       -H 'X-Atlassian-Token: no-check'
       --form 'file=@"myfile.txt"'
  
  #### Node.js ####
  
      // This code sample uses the 'node-fetch' and 'form-data' libraries:
       // https://www.npmjs.com/package/node-fetch
       // https://www.npmjs.com/package/form-data
       const fetch = require('node-fetch');
       const FormData = require('form-data');
       const fs = require('fs');
      
       const filePath = 'myfile.txt';
       const form = new FormData();
       const stats = fs.statSync(filePath);
       const fileSizeInBytes = stats.size;
       const fileStream = fs.createReadStream(filePath);
      
       form.append('file', fileStream, {knownLength: fileSizeInBytes});
      
       fetch('https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments', {
           method: 'POST',
           body: form,
           headers: {
               'Authorization': `Basic ${Buffer.from(
                   'email@example.com:'
               ).toString('base64')}`,
               'Accept': 'application/json',
               'X-Atlassian-Token': 'no-check'
           }
       })
           .then(response => {
               console.log(
                   `Response: ${response.status} ${response.statusText}`
               );
               return response.text();
           })
           .then(text => console.log(text))
           .catch(err => console.error(err));
  
  #### Java ####
  
      // This code sample uses the  'Unirest' library:
       // http://unirest.io/java.html
       HttpResponse response = Unirest.post("https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments")
               .basicAuth("email@example.com", "")
               .header("Accept", "application/json")
               .header("X-Atlassian-Token", "no-check")
               .field("file", new File("myfile.txt"))
               .asJson();
      
               System.out.println(response.getBody());
  
  #### Python ####
  
      # This code sample uses the 'requests' library:
       # http://docs.python-requests.org
       import requests
       from requests.auth import HTTPBasicAuth
       import json
      
       url = "https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments"
      
       auth = HTTPBasicAuth("email@example.com", "")
      
       headers = {
          "Accept": "application/json",
          "X-Atlassian-Token": "no-check"
       }
      
       response = requests.request(
          "POST",
          url,
          headers = headers,
          auth = auth,
          files = {
               "file": ("myfile.txt", open("myfile.txt","rb"), "application-type")
          }
       )
      
       print(json.dumps(json.loads(response.text), sort_keys=True, indent=4, separators=(",", ": ")))
  
  #### PHP ####
  
      // This code sample uses the 'Unirest' library:
       // http://unirest.io/php.html
       Unirest\Request::auth('email@example.com', '');
      
       $headers = array(
         'Accept' => 'application/json',
         'X-Atlassian-Token' => 'no-check'
       );
      
       $parameters = array(
         'file' => File::add('myfile.txt')
       );
      
       $response = Unirest\Request::post(
         'https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments',
         $headers,
         $parameters
       );
      
       var_dump($response)
  
  #### Forge ####
  
      // This sample uses Atlassian Forge and the `form-data` library.
       // https://developer.atlassian.com/platform/forge/
       // https://www.npmjs.com/package/form-data
       import api from "@forge/api";
       import FormData from "form-data";
      
       const form = new FormData();
       form.append('file', fileStream, {knownLength: fileSizeInBytes});
      
       const response = await api.asApp().requestJira('/rest/api/2/issue/{issueIdOrKey}/attachments', {
           method: 'POST',
           body: form,
           headers: {
               'Accept': 'application/json',
               'X-Atlassian-Token': 'no-check'
           }
       });
      
       console.log(`Response: ${response.status} ${response.statusText}`);
       console.log(await response.json());
  
  Tip: Use a client library. Many client libraries have classes for handling multipart POST operations. For example, in Java, the Apache HTTP Components library provides a [MultiPartEntity](http://hc.apache.org/httpcomponents-client-ga/httpmime/apidocs/org/apache/http/entity/mime/MultipartEntity.html) class for multipart POST operations.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* and *Create attachments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Attachment.addAttachments
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-attachments-post
  * @param options Request options.
  */
    addIssueAttachments<T = Issue.Attachment.AddAttachments.Response.OK>(options: Issue.Attachment.AddAttachments.Options): Promise<Issue.Attachment.AddAttachments.Response.OK>;
    /**
  * Returns the metadata for an attachment. Note that the attachment itself is not returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Attachment.Metadata.getMetadata
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-get
  * @param options Request options.
  */
    getIssueAttachmentMetadata<T = Issue.Attachment.Metadata.GetMetadata.Response.OK>(options: Issue.Attachment.Metadata.GetMetadata.Options): Promise<import("./definitions/AttachmentMetadataAsResponse").AttachmentMetadataAsResponse>;
    /**
  * Returns the metadata for the contents of an attachment, if it is an archive, and metadata for the attachment itself. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned and metadata for the ZIP archive. Currently, only the ZIP archive format is supported.
  
  Use this operation to retrieve data that is presented to the user, as this operation returns the metadata for the attachment itself, such as the attachment's ID and name. Otherwise, use [ Get contents metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-raw-get), which only returns the metadata for the attachment's contents.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Attachment.Metadata.getMetadataForExpandedAttachment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-expand-human-get
  * @param options Request options.
  */
    getMetadataForExpandedIssueAttachment<T = Issue.Attachment.Metadata.GetMetadataForExpandedAttachment.Response.OK>(options: Issue.Attachment.Metadata.GetMetadataForExpandedAttachment.Options): Promise<import("./definitions/AttachmentArchiveMetadataReadableAsResponse").AttachmentArchiveMetadataReadableAsResponse>;
    /**
  * Returns the metadata for the contents of an attachment, if it is an archive. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned. Currently, only the ZIP archive format is supported.
  
  Use this operation if you are processing the data without presenting it to the user, as this operation only returns the metadata for the contents of the attachment. Otherwise, to retrieve data to present to the user, use [ Get all metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-human-get) which also returns the metadata for the attachment itself, such as the attachment's ID and name.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Attachment.Metadata.getContentsMetadataForExpandedAttachment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-expand-raw-get
  * @param options Request options.
  */
    getContentsMetadataForExpandedIssueAttachment<T = Issue.Attachment.Metadata.GetContentsMetadataForExpandedAttachment.Response.OK>(options: Issue.Attachment.Metadata.GetContentsMetadataForExpandedAttachment.Options): Promise<import("./definitions/AttachmentArchiveImplAsResponse").AttachmentArchiveImplAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of comments specified by a list of comment IDs.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Comments are returned where the user:
  
   *  has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Comment.getCommentsByIds
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-list-post
  * @param options Request options.
  */
    getIssueCommentsByIds<T = Issue.Comment.GetCommentsByIds.Response.OK>(options: Issue.Comment.GetCommentsByIds.Options): Promise<import("./definitions/PageBeanCommentAsResponse").PageBeanCommentAsResponse>;
    /**
  * Returns all comments for an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Comments are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is role visibility is restricted to.
  * Recommended usage: Issue.Comment.getComments
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-get
  * @param options Request options.
  */
    getIssueComments<T = Issue.Comment.GetComments.Response.OK>(options: Issue.Comment.GetComments.Options): Promise<import("./definitions/PageOfCommentsAsResponse").PageOfCommentsAsResponse>;
    /**
  * Adds a comment to an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Add comments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Comment.addComment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-post
  * @param options Request options.
  */
    addIssueComment<T = Issue.Comment.AddComment.Response.OK>(options: Issue.Comment.AddComment.Options): Promise<import("./definitions/CommentAsResponse").CommentAsResponse>;
    /**
  * Returns a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Comment.getComment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-get
  * @param options Request options.
  */
    getIssueComment<T = Issue.Comment.GetComment.Response.OK>(options: Issue.Comment.GetComment.Options): Promise<import("./definitions/CommentAsResponse").CommentAsResponse>;
    /**
  * Updates a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any comment or *Edit own comments* to update comment created by the user.
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Comment.updateComment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-put
  * @param options Request options.
  */
    updateIssueComment<T = Issue.Comment.UpdateComment.Response.OK>(options: Issue.Comment.UpdateComment.Options): Promise<import("./definitions/CommentAsResponse").CommentAsResponse>;
    /**
  * Deletes a comment.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Delete all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any comment or *Delete own comments* to delete comment created by the user,
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Comment.deleteComment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-delete
  * @param options Request options.
  */
    deleteIssueComment<T = Issue.Comment.DeleteComment.Response.OK>(options: Issue.Comment.DeleteComment.Options): Promise<undefined>;
    /**
  * Returns the keys of all the properties of a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Comment.Property.getKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-get
  * @param options Request options.
  */
    getIssueCommentPropertyKeys<T = Issue.Comment.Property.GetKeys.Response.OK>(options: Issue.Comment.Property.GetKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the value of a comment property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Comment.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-get
  * @param options Request options.
  */
    getIssueCommentProperty<T = Issue.Comment.Property.GetProperty.Response.OK>(options: Issue.Comment.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Creates or updates the value of a property for a comment. Use this resource to store custom data against a comment.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on any comment.
   *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on a comment created by the user.
  
  Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
  * Recommended usage: Issue.Comment.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-put
  * @param options Request options.
  */
    setIssueCommentProperty<T = Issue.Comment.Property.SetProperty.Response.OK>(options: Issue.Comment.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes a comment property.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from any comment.
   *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from a comment created by the user.
  
  Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
  * Recommended usage: Issue.Comment.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-delete
  * @param options Request options.
  */
    deleteIssueCommentProperty<T = Issue.Comment.Property.DeleteProperty.Response.OK>(options: Issue.Comment.Property.DeleteProperty.Options): Promise<undefined>;
    /**
  * Returns details of projects, issue types within projects, and, when requested, the create screen fields for each issue type for the user. Use the information to populate the requests in [ Create issue](#api-rest-api-3-issue-post) and [Create issues](#api-rest-api-3-issue-bulk-post).
  
  The request can be restricted to specific projects or issue types using the query parameters. The response will contain information for the valid projects, issue types, or project and issue type combinations requested. Note that invalid project, issue type, or project and issue type combinations do not generate errors.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Create issues* [project permission](https://confluence.atlassian.com/x/yodKLg) in the requested projects.
  * Recommended usage: Issue.Metadata.getCreateMetadata
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-createmeta-get
  * @param options Request options.
  */
    getCreateIssueMetadata<T = Issue.Metadata.GetCreateMetadata.Response.OK>(options?: Issue.Metadata.GetCreateMetadata.Options): Promise<import("./definitions/IssueCreateMetadataAsResponse").IssueCreateMetadataAsResponse>;
    /**
  * Returns the edit screen fields for an issue that are visible to and editable by the user. Use the information to populate the requests in [Edit issue](#api-rest-api-3-issue-issueIdOrKey-put).
  
  Connect app users with admin permission (from user permissions and app scopes) and Forge app users with the `manage:jira-configuration` scope can return additional details using:
  
   *  `overrideScreenSecurity` Returns hidden fields.
   *  `overrideEditableFlag` Returns uneditable fields. For example, where an issue has a workflow status of closed none of its fields are editable.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  Note: For any fields to be editable the user must have the *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the issue.
  * Recommended usage: Issue.Metadata.getEditMetadata
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-editmeta-get
  * @param options Request options.
  */
    getEditIssueMetadata<T = Issue.Metadata.GetEditMetadata.Response.OK>(options: Issue.Metadata.GetEditMetadata.Options): Promise<import("./definitions/IssueUpdateMetadataAsResponse").IssueUpdateMetadataAsResponse>;
    /**
  * Returns the URLs and keys of an issue's properties.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Property details are only returned where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Property.getKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-get
  * @param options Request options.
  */
    getIssuePropertyKeys<T = Issue.Property.GetKeys.Response.OK>(options: Issue.Property.GetKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the key and value of an issue's property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-get
  * @param options Request options.
  */
    getIssueProperty<T = Issue.Property.GetProperty.Response.OK>(options: Issue.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of an issue's property. Use this resource to store custom data against an issue.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-put
  * @param options Request options.
  */
    setIssueProperty<T = Issue.Property.SetProperty.Response.OK>(options: Issue.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes an issue's property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-delete
  * @param options Request options.
  */
    deleteIssueProperty<T = Issue.Property.DeleteProperty.Response.OK>(options: Issue.Property.DeleteProperty.Options): Promise<undefined>;
    /**
  * Creates a link between two issues. Use this operation to indicate a relationship between two issues and optionally add a comment to the from (outward) issue. To use this resource the site must have [Issue Linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This resource returns nothing on the creation of an issue link. To obtain the ID of the issue link, use `https://your-domain.atlassian.net/rest/api/3/issue/[linked issue key]?fields=issuelinks`.
  
  If the link request duplicates a link, the response indicates that the issue link was created. If the request included a comment, the comment is added.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues to be linked,
   *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) on the project containing the from (outward) issue,
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Recommended usage: Issue.Link.createLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLink-post
  * @param options Request options.
  */
    createIssueLink<T = Issue.Link.CreateLink.Response.OK>(options: Issue.Link.CreateLink.Options): Promise<any>;
    /**
  * Returns an issue link.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the linked issues.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
  * Recommended usage: Issue.Link.getLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLink-linkId-get
  * @param options Request options.
  */
    getIssueLink<T = Issue.Link.GetLink.Response.OK>(options: Issue.Link.GetLink.Options): Promise<import("./definitions/IssueLinkAsResponse").IssueLinkAsResponse>;
    /**
  * Deletes an issue link.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  Browse project [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues in the link.
   *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one of the projects containing issues in the link.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
  * Recommended usage: Issue.Link.deleteLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLink-linkId-delete
  * @param options Request options.
  */
    deleteIssueLink<T = Issue.Link.DeleteLink.Response.OK>(options: Issue.Link.DeleteLink.Options): Promise<undefined>;
    /**
  * Returns the remote issue links for an issue. When a remote issue link global ID is provided the record with that global ID is returned, otherwise all remote issue links are returned. Where a global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Link.Remote.getLinks
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-get
  * @param options Request options.
  */
    getRemoteIssueLinks<T = Issue.Link.Remote.GetLinks.Response.OK>(options: Issue.Link.Remote.GetLinks.Options): Promise<import("./definitions/RemoteIssueLinkAsResponse").RemoteIssueLinkAsResponse>;
    /**
  * Creates or updates a remote issue link for an issue.
  
  If a `globalId` is provided and a remote issue link with that global ID is found it is updated. Any fields without values in the request are set to null. Otherwise, the remote issue link is created.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Link.Remote.createOrUpdateLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-post
  * @param options Request options.
  */
    createOrUpdateRemoteIssueLink<T = Issue.Link.Remote.CreateOrUpdateLink.Response.OK>(options: Issue.Link.Remote.CreateOrUpdateLink.Options): Promise<import("./definitions/RemoteIssueLinkIdentifiesAsResponse").RemoteIssueLinkIdentifiesAsResponse>;
    /**
  * Deletes the remote issue link from the issue using the link's global ID. Where the global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is implemented, issue-level security permission to view the issue.
  * Recommended usage: Issue.Link.Remote.deleteLinkByGlobalId
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-delete
  * @param options Request options.
  */
    deleteRemoteIssueLinkByGlobalId<T = Issue.Link.Remote.DeleteLinkByGlobalId.Response.OK>(options: Issue.Link.Remote.DeleteLinkByGlobalId.Options): Promise<undefined>;
    /**
  * Returns a remote issue link for an issue.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Link.Remote.getLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-get
  * @param options Request options.
  */
    getRemoteIssueLink<T = Issue.Link.Remote.GetLink.Response.OK>(options: Issue.Link.Remote.GetLink.Options): Promise<import("./definitions/RemoteIssueLinkAsResponse").RemoteIssueLinkAsResponse>;
    /**
  * Updates a remote issue link for an issue.
  
  Note: Fields without values in the request are set to null.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Link.Remote.updateLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-put
  * @param options Request options.
  */
    updateRemoteIssueLink<T = Issue.Link.Remote.UpdateLink.Response.OK>(options: Issue.Link.Remote.UpdateLink.Options): Promise<any>;
    /**
  * Deletes a remote issue link from an issue.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects*, *Edit issues*, and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Link.Remote.deleteLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-delete
  * @param options Request options.
  */
    deleteRemoteIssueLink<T = Issue.Link.Remote.DeleteLink.Response.OK>(options: Issue.Link.Remote.DeleteLink.Options): Promise<undefined>;
    /**
  * Returns a list of all issue link types.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
  * Recommended usage: Issue.Link.Type.getTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-get
  * @param options Request options.
  */
    getIssueLinkTypes<T = Issue.Link.Type.GetTypes.Response.OK>(options?: Issue.Link.Type.GetTypes.Options): Promise<import("./definitions/IssueLinkTypesAsResponse").IssueLinkTypesAsResponse>;
    /**
  * Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Link.Type.createType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-post
  * @param options Request options.
  */
    createIssueLinkType<T = Issue.Link.Type.CreateType.Response.OK>(options: Issue.Link.Type.CreateType.Options): Promise<import("./definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
    /**
  * Returns an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
  * Recommended usage: Issue.Link.Type.getType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-get
  * @param options Request options.
  */
    getIssueLinkType<T = Issue.Link.Type.GetType.Response.OK>(options: Issue.Link.Type.GetType.Options): Promise<import("./definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
    /**
  * Updates an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Link.Type.updateType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-put
  * @param options Request options.
  */
    updateIssueLinkType<T = Issue.Link.Type.UpdateType.Response.OK>(options: Issue.Link.Type.UpdateType.Options): Promise<import("./definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
    /**
  * Deletes an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Link.Type.deleteType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-delete
  * @param options Request options.
  */
    deleteIssueLinkType<T = Issue.Link.Type.DeleteType.Response.OK>(options: Issue.Link.Type.DeleteType.Options): Promise<undefined>;
    /**
  * Returns either all transitions or a transition that can be performed by the user on an issue, based on the issue's status.
  
  Note, if a request is made for a transition that does not exist or cannot be performed on the issue, given its status, the response will return any empty transitions list.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required: A list or transition is returned only when the user has:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  However, if the user does not have the *Transition issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) the response will not list any transitions.
  * Recommended usage: Issue.Transition.getTransitions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-transitions-get
  * @param options Request options.
  */
    getIssueTransitions<T = Issue.Transition.GetTransitions.Response.OK>(options: Issue.Transition.GetTransitions.Options): Promise<import("./definitions/TransitionsAsResponse").TransitionsAsResponse>;
    /**
  * Performs an issue transition and, if the transition has a screen, updates the fields from the transition screen.
  
  sortByCategory To update the fields on the transition screen, specify the fields in the `fields` or `update` parameters in the request body. Get details about the fields using [ Get transitions](#api-rest-api-3-issue-issueIdOrKey-transitions-get) with the `transitions.fields` expand.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Transition issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Transition.performTransition
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-transitions-post
  * @param options Request options.
  */
    performIssueTransition<T = Issue.Transition.PerformTransition.Response.OK>(options: Issue.Transition.PerformTransition.Options): Promise<Issue.Transition.PerformTransition.Response.OK>;
    /**
  * Returns details about the votes on an issue.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  Note that users with the necessary permissions for this operation but without the *View voters and watchers* project permissions are not returned details in the `voters` field.
  * Recommended usage: Issue.Vote.getVotes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-get
  * @param options Request options.
  */
    getIssueVotes<T = Issue.Vote.GetVotes.Response.OK>(options: Issue.Vote.GetVotes.Options): Promise<import("./definitions/VotesAsResponse").VotesAsResponse>;
    /**
  * Adds the user's vote to an issue. This is the equivalent of the user clicking *Vote* on an issue in Jira.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Vote.addVote
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-post
  * @param options Request options.
  */
    addIssueVote<T = Issue.Vote.AddVote.Response.OK>(options: Issue.Vote.AddVote.Options): Promise<any>;
    /**
  * Deletes a user's vote from an issue. This is the equivalent of the user clicking *Unvote* on an issue in Jira.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Vote.deleteVote
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-delete
  * @param options Request options.
  */
    deleteIssueVote<T = Issue.Vote.DeleteVote.Response.OK>(options: Issue.Vote.DeleteVote.Options): Promise<undefined>;
    /**
  * Returns the watchers for an issue.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To see details of users on the watchlist other than themselves, *View voters and watchers* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Recommended usage: Issue.Watcher.getWatchers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-get
  * @param options Request options.
  */
    getIssueWatchers<T = Issue.Watcher.GetWatchers.Response.OK>(options: Issue.Watcher.GetWatchers.Options): Promise<import("./definitions/WatchersAsResponse").WatchersAsResponse>;
    /**
  * Adds a user as a watcher of an issue by passing the account ID of the user. For example, `"5b10ac8d82e05b22cc7d4ef5"`. If no user is specified the calling user is added.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To add users other than themselves to the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Recommended usage: Issue.Watcher.addWatcher
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-post
  * @param options Request options.
  */
    addIssueWatcher<T = Issue.Watcher.AddWatcher.Response.OK>(options: Issue.Watcher.AddWatcher.Options): Promise<any>;
    /**
  * Deletes a user as a watcher of an issue.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To remove users other than themselves from the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Recommended usage: Issue.Watcher.deleteWatcher
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-delete
  * @param options Request options.
  */
    deleteIssueWatcher<T = Issue.Watcher.DeleteWatcher.Response.OK>(options: Issue.Watcher.DeleteWatcher.Options): Promise<undefined>;
    /**
  * Checks whether one or more issues would be returned by one or more JQL queries.
  
  **[Permissions](#permissions) required:** None, however, issues are only matched against JQL queries where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Search.checkAgainstJql
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-search-post
  * @param options Request options.
  */
    checkIssuesAgainstJql<T = Issue.Search.CheckAgainstJql.Response.OK>(options: Issue.Search.CheckAgainstJql.Options): Promise<import("./definitions/IssueMatchesAsResponse").IssueMatchesAsResponse>;
    /**
  * Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ).
  
  There is a [GET](#api-rest-api-3-search-get) version of this resource that can be used for smaller JQL query expressions.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issues are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Recommended usage: Issue.Search.searchByJql
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-search-get
  * @param options Request options.
  */
    searchIssuesByJql<T = Issue.Search.SearchByJql.Response.OK>(options: Issue.Search.SearchByJql.Options): Promise<import("./definitions/SearchResultsAsResponse").SearchResultsAsResponse>;
    /**
  * Returns the list of all issue priorities.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Issue.Priority.getPriorities
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-priority-get
  * @param options Request options.
  */
    getIssuePriorities<T = Issue.Priority.GetPriorities.Response.OK>(options?: Issue.Priority.GetPriorities.Options): Promise<Issue.Priority.GetPriorities.Response.OK>;
    /**
  * Returns an issue priority.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Issue.Priority.getPriority
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-priority-id-get
  * @param options Request options.
  */
    getIssuePriority<T = Issue.Priority.GetPriority.Response.OK>(options: Issue.Priority.GetPriority.Options): Promise<import("./definitions/PriorityAsResponse").PriorityAsResponse>;
    /**
  * Returns a list of all issue resolution values.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Issue.Resolution.getResolutions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-resolution-get
  * @param options Request options.
  */
    getIssueResolutions<T = Issue.Resolution.GetResolutions.Response.OK>(options?: Issue.Resolution.GetResolutions.Options): Promise<Issue.Resolution.GetResolutions.Response.OK>;
    /**
  * Returns an issue resolution value.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Issue.Resolution.getResolution
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-resolution-id-get
  * @param options Request options.
  */
    getIssueResolution<T = Issue.Resolution.GetResolution.Response.OK>(options: Issue.Resolution.GetResolution.Options): Promise<import("./definitions/ResolutionAsResponse").ResolutionAsResponse>;
    /**
  * Returns issue security level members.
  
  Only issue security level members in context of classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Security.getMembers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuesecurityschemes-issueSecuritySchemeId-members-get
  * @param options Request options.
  */
    getIssueSecurityMembers<T = Issue.Security.GetMembers.Response.OK>(options: Issue.Security.GetMembers.Options): Promise<import("./definitions/PageBeanIssueSecurityLevelMemberAsResponse").PageBeanIssueSecurityLevelMemberAsResponse>;
    /**
  * Returns details of an issue security level.
  
  Use [Get issue security scheme](#api-rest-api-3-issuesecurityschemes-id-get) to obtain the IDs of issue security levels associated with the issue security scheme.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Issue.Security.getLevel
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-level/#api-rest-api-3-securitylevel-id-get
  * @param options Request options.
  */
    getIssueSecurityLevel<T = Issue.Security.GetLevel.Response.OK>(options: Issue.Security.GetLevel.Options): Promise<import("./definitions/SecurityLevelAsResponse").SecurityLevelAsResponse>;
    /**
  * Returns all [issue security schemes](https://confluence.atlassian.com/x/J4lKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Security.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-get
  * @param options Request options.
  */
    getIssueSecuritySchemes<T = Issue.Security.Scheme.GetSchemes.Response.OK>(options?: Issue.Security.Scheme.GetSchemes.Options): Promise<import("./definitions/SecuritySchemesAsResponse").SecuritySchemesAsResponse>;
    /**
  * Returns an issue security scheme along with its security levels.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project that uses the requested issue security scheme.
  * Recommended usage: Issue.Security.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-id-get
  * @param options Request options.
  */
    getIssueSecurityScheme<T = Issue.Security.Scheme.GetScheme.Response.OK>(options: Issue.Security.Scheme.GetScheme.Options): Promise<import("./definitions/SecuritySchemeAsResponse").SecuritySchemeAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of [notification schemes](https://confluence.atlassian.com/x/8YdKLg) ordered by display name.
  
  ### About notification schemes ###
  
  A notification scheme is a list of events and recipients who will receive notifications for those events. The list is contained within the `notificationSchemeEvents` object and contains pairs of `events` and `notifications`:
  
   *  `event` Identifies the type of event. The events can be [Jira system events](https://confluence.atlassian.com/x/8YdKLg#Creatinganotificationscheme-eventsEvents) or [custom events](https://confluence.atlassian.com/x/AIlKLg).
   *  `notifications` Identifies the [recipients](https://confluence.atlassian.com/x/8YdKLg#Creatinganotificationscheme-recipientsRecipients) of notifications for each event. Recipients can be any of the following types:
      
       *  `CurrentAssignee`
       *  `Reporter`
       *  `CurrentUser`
       *  `ProjectLead`
       *  `ComponentLead`
       *  `User` (the `parameter` is the user key)
       *  `Group` (the `parameter` is the group name)
       *  `ProjectRole` (the `parameter` is the project role ID)
       *  `EmailAddress`
       *  `AllWatchers`
       *  `UserCustomField` (the `parameter` is the ID of the custom field)
       *  `GroupCustomField`(the `parameter` is the ID of the custom field)
  
  *Note that you should allow for events without recipients to appear in responses.*
  
  **[Permissions](#permissions) required:** Permission to access Jira, however the user must have permission to administer at least one project associated with a notification scheme for it to be returned.
  * Recommended usage: Issue.Notification.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-notification-schemes/#api-rest-api-3-notificationscheme-get
  * @param options Request options.
  */
    getIssueNotificationSchemes<T = Issue.Notification.Scheme.GetSchemes.Response.OK>(options?: Issue.Notification.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanNotificationSchemeAsResponse").PageBeanNotificationSchemeAsResponse>;
    /**
  * Returns a [notification scheme](https://confluence.atlassian.com/x/8YdKLg), including the list of events and the recipients who will receive notifications for those events.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however the user must have permission to administer at least one project associated with the notification scheme.
  * Recommended usage: Issue.Notification.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-notification-schemes/#api-rest-api-3-notificationscheme-id-get
  * @param options Request options.
  */
    getIssueNotificationScheme<T = Issue.Notification.Scheme.GetScheme.Response.OK>(options: Issue.Notification.Scheme.GetScheme.Options): Promise<import("./definitions/NotificationSchemeAsResponse").NotificationSchemeAsResponse>;
    /**
  * Returns the default issue navigator columns.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Navigator.getDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-get
  * @param options Request options.
  */
    getIssueNavigatorDefaultColumns<T = Issue.Navigator.GetDefaultColumns.Response.OK>(options?: Issue.Navigator.GetDefaultColumns.Options): Promise<Issue.Navigator.GetDefaultColumns.Response.OK>;
    /**
  * Sets the default issue navigator columns.
  
  The `columns` parameter accepts a navigable field value and is expressed as HTML form data. To specify multiple columns, pass multiple `columns` parameters. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/settings/columns`
  
  If no column details are sent, then all default columns are removed.
  
  A navigable field is one that can be used as a column on the issue navigator. Find details of navigable issue columns using [Get fields](#api-rest-api-3-field-get).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Navigator.setDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-put
  * @param options Request options.
  */
    setIssueNavigatorDefaultColumns<T = Issue.Navigator.SetDefaultColumns.Response.OK>(options: Issue.Navigator.SetDefaultColumns.Options): Promise<any>;
    /**
  * Returns a list of dashboards owned by or shared with the user. The list may be filtered to include only favorite or owned dashboards.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Dashboard.getDashboards
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-get
  * @param options Request options.
  */
    getDashboards<T = Dashboard.GetDashboards.Response.OK>(options?: Dashboard.GetDashboards.Options): Promise<import("./definitions/PageOfDashboardsAsResponse").PageOfDashboardsAsResponse>;
    /**
  * Creates a dashboard.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Dashboard.createDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-post
  * @param options Request options.
  */
    createDashboard<T = Dashboard.CreateDashboard.Response.OK>(options: Dashboard.CreateDashboard.Options): Promise<import("./definitions/DashboardAsResponse").DashboardAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of dashboards. This operation is similar to [Get dashboards](#api-rest-api-3-dashboard-get) except that the results can be refined to include dashboards that have specific attributes. For example, dashboards with a particular name. When multiple attributes are specified only filters matching all attributes are returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The following dashboards that match the query parameters are returned:
  
   *  Dashboards owned by the user. Not returned for anonymous users.
   *  Dashboards shared with a group that the user is a member of. Not returned for anonymous users.
   *  Dashboards shared with a private project that the user can browse. Not returned for anonymous users.
   *  Dashboards shared with a public project.
   *  Dashboards shared with the public.
  * Recommended usage: Dashboard.searchDashboards
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-search-get
  * @param options Request options.
  */
    searchDashboards<T = Dashboard.SearchDashboards.Response.OK>(options?: Dashboard.SearchDashboards.Options): Promise<import("./definitions/PageBeanDashboardAsResponse").PageBeanDashboardAsResponse>;
    /**
  * Returns a dashboard.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  
  However, to get a dashboard, the dashboard must be shared with the user or the user must own it. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users.
  * Recommended usage: Dashboard.getDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-get
  * @param options Request options.
  */
    getDashboard<T = Dashboard.GetDashboard.Response.OK>(options: Dashboard.GetDashboard.Options): Promise<import("./definitions/DashboardAsResponse").DashboardAsResponse>;
    /**
  * Updates a dashboard, replacing all the dashboard details with those provided.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be updated must be owned by the user.
  * Recommended usage: Dashboard.updateDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-put
  * @param options Request options.
  */
    updateDashboard<T = Dashboard.UpdateDashboard.Response.OK>(options: Dashboard.UpdateDashboard.Options): Promise<import("./definitions/DashboardAsResponse").DashboardAsResponse>;
    /**
  * Deletes a dashboard.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be deleted must be owned by the user.
  * Recommended usage: Dashboard.deleteDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-delete
  * @param options Request options.
  */
    deleteDashboard<T = Dashboard.DeleteDashboard.Response.OK>(options: Dashboard.DeleteDashboard.Options): Promise<undefined>;
    /**
  * Copies a dashboard. Any values provided in the `dashboard` parameter replace those in the copied dashboard.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be copied must be owned by or shared with the user.
  * Recommended usage: Dashboard.copyDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-copy-post
  * @param options Request options.
  */
    copyDashboard<T = Dashboard.CopyDashboard.Response.OK>(options: Dashboard.CopyDashboard.Options): Promise<import("./definitions/DashboardAsResponse").DashboardAsResponse>;
    /**
  * Returns the keys of all properties for a dashboard item.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira’s anonymous access is permitted.
  * Recommended usage: Dashboard.Property.getPropertyKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-get
  * @param options Request options.
  */
    getDashboardItemPropertyKeys<T = Dashboard.Property.GetPropertyKeys.Response.OK>(options: Dashboard.Property.GetPropertyKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the key and value of a dashboard item property.
  
  A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
  
  When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
  
  There is no resource to set or get dashboard items.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira’s anonymous access is permitted.
  * Recommended usage: Dashboard.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-get
  * @param options Request options.
  */
    getDashboardItemProperty<T = Dashboard.Property.GetProperty.Response.OK>(options: Dashboard.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of a dashboard item property. Use this resource in apps to store custom data against a dashboard item.
  
  A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
  
  When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
  
  There is no resource to set or get dashboard items.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
  * Recommended usage: Dashboard.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-put
  * @param options Request options.
  */
    setDashboardItemProperty<T = Dashboard.Property.SetProperty.Response.OK>(options: Dashboard.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes a dashboard item property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
  * Recommended usage: Dashboard.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-delete
  * @param options Request options.
  */
    deleteDashboardItemProperty<T = Dashboard.Property.DeleteProperty.Response.OK>(options: Dashboard.Property.DeleteProperty.Options): Promise<undefined>;
    /**
  * Returns all application roles. In Jira, application roles are managed using the [Application access configuration](https://confluence.atlassian.com/x/3YxjL) page.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Application.Role.getRoles
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-get
  * @param options Request options.
  */
    getApplicationRoles<T = Application.Role.GetRoles.Response.OK>(options?: Application.Role.GetRoles.Options): Promise<Application.Role.GetRoles.Response.OK>;
    /**
  * Returns an application role.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Application.Role.getRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-key-get
  * @param options Request options.
  */
    getApplicationRole<T = Application.Role.GetRole.Response.OK>(options: Application.Role.GetRole.Options): Promise<import("./definitions/ApplicationRoleAsResponse").ApplicationRoleAsResponse>;
    /**
  * Returns the default [issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If `accountId` is not passed in the request, the calling user's details are returned.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLgl), to get the column details for any user.
   *  Permission to access Jira, to get the calling user's column details.
  * Recommended usage: User.getDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-get
  * @param options Request options.
  */
    getUserDefaultColumns<T = User.GetDefaultColumns.Response.OK>(options?: User.GetDefaultColumns.Options): Promise<User.GetDefaultColumns.Response.OK>;
    /**
  * Sets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If an account ID is not passed, the calling user's default columns are set. If no column details are sent, then all default columns are removed.
  
  The parameters for this resource are expressed as HTML form data. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/user/columns?accountId=5b10ac8d82e05b22cc7d4ef5'`
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
   *  Permission to access Jira, to set the calling user's columns.
  * Recommended usage: User.setDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-put
  * @param options Request options.
  */
    setUserDefaultColumns<T = User.SetDefaultColumns.Response.OK>(options: User.SetDefaultColumns.Options): Promise<any>;
    /**
  * Resets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user to the system default. If `accountId` is not passed, the calling user's default columns are reset.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
   *  Permission to access Jira, to set the calling user's columns.
  * Recommended usage: User.resetDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-delete
  * @param options Request options.
  */
    resetUserDefaultColumns<T = User.ResetDefaultColumns.Response.OK>(options?: User.ResetDefaultColumns.Options): Promise<undefined>;
    /**
  * Returns a user.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: User.getUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-get
  * @param options Request options.
  */
    getUser<T = User.GetUser.Response.OK>(options?: User.GetUser.Options): Promise<import("./definitions/UserAsResponse").UserAsResponse>;
    /**
  * Creates a user. This resource is retained for legacy compatibility. As soon as a more suitable alternative is available this resource will be deprecated.
  
  If the user exists and has access to Jira, the operation returns a 201 status. If the user exists but does not have access to Jira, the operation returns a 400 status.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: User.createUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-post
  * @param options Request options.
  */
    createUser<T = User.CreateUser.Response.OK>(options: User.CreateUser.Options): Promise<import("./definitions/UserAsResponse").UserAsResponse>;
    /**
  * Deletes a user.
  
  **[Permissions](#permissions) required:** Site administration (that is, membership of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Recommended usage: User.deleteUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-delete
  * @param options Request options.
  */
    deleteUser<T = User.DeleteUser.Response.OK>(options: User.DeleteUser.Options): Promise<undefined>;
    /**
  * Returns the account IDs for the users specified in the `key` or `username` parameters. Note that multiple `key` or `username` parameters can be specified.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: User.getAccountIdsForUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-bulk-migration-get
  * @param options Request options.
  */
    getAccountIdsForUsers<T = User.GetAccountIdsForUsers.Response.OK>(options?: User.GetAccountIdsForUsers.Options): Promise<User.GetAccountIdsForUsers.Response.OK>;
    /**
     * Returns a user's email address. This API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
     * Recommended usage: User.getEmail
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-email-get
     * @param options Request options.
     */
    getUserEmail<T = User.GetEmail.Response.OK>(options: User.GetEmail.Options): Promise<import("./definitions/UnrestrictedUserEmailAsResponse").UnrestrictedUserEmailAsResponse>;
    /**
  * Returns the groups to which a user belongs.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: User.getGroups
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-groups-get
  * @param options Request options.
  */
    getUserGroups<T = User.GetGroups.Response.OK>(options: User.GetGroups.Options): Promise<User.GetGroups.Response.OK>;
    /**
  * Returns a list of all (active and inactive) users.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: User.getUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-users-search-get
  * @param options Request options.
  */
    getUsers<T = User.GetUsers.Response.OK>(options?: User.GetUsers.Options): Promise<User.GetUsers.Response.OK>;
    /**
  * Returns a list of users who can be assigned issues in one or more projects. The list may be restricted to users whose attributes match a string.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned issues in the projects. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned issues in the projects, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: User.Search.findUsersAssignableToProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-assignable-multiProjectSearch-get
  * @param options Request options.
  */
    findUsersAssignableToProjects<T = User.Search.FindUsersAssignableToProjects.Response.OK>(options: User.Search.FindUsersAssignableToProjects.Options): Promise<User.Search.FindUsersAssignableToProjects.Response.OK>;
    /**
  * Returns a list of users that can be assigned to an issue. Use this operation to find the list of users who can be assigned to:
  
   *  a new issue, by providing the `projectKeyOrId`.
   *  an updated issue, by providing the `issueKey`.
   *  to an issue during a transition (workflow action), by providing the `issueKey` and the transition id in `actionDescriptorId`. You can obtain the IDs of an issue's valid transitions using the `transitions` option in the `expand` parameter of [ Get issue](#api-rest-api-3-issue-issueIdOrKey-get).
  
  In all these cases, you can pass an account ID to determine if a user can be assigned to an issue. The user is returned in the response if they can be assigned to the issue or issue transition.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned the issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned the issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: User.Search.findUsersAssignableToIssues
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-assignable-search-get
  * @param options Request options.
  */
    findUsersAssignableToIssues<T = User.Search.FindUsersAssignableToIssues.Response.OK>(options?: User.Search.FindUsersAssignableToIssues.Options): Promise<User.Search.FindUsersAssignableToIssues.Response.OK>;
    /**
  * Returns a list of users who fulfill these criteria:
  
   *  their user attributes match a search string.
   *  they have a set of permissions for a project or issue.
  
  If no search string is provided, a list of all users with the permissions is returned.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission for the project or issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission for the project or issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get users for any project.
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project, to get users for that project.
  * Recommended usage: User.Search.findUsersWithPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-permission-search-get
  * @param options Request options.
  */
    findUsersWithPermissions<T = User.Search.FindUsersWithPermissions.Response.OK>(options: User.Search.FindUsersWithPermissions.Options): Promise<User.Search.FindUsersWithPermissions.Response.OK>;
    /**
  * Returns a list of users whose attributes match the query term. The returned object includes the `html` field where the matched query term is highlighted with the HTML strong tag. A list of account IDs can be provided to exclude users from the results.
  
  This operation takes the users in the range defined by `maxResults`, up to the thousandth user, and then returns only the users from that range that match the query term. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the query term, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return search results for an exact name match only.
  * Recommended usage: User.Search.findUsersForPicker
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-picker-get
  * @param options Request options.
  */
    findUsersForPicker<T = User.Search.FindUsersForPicker.Response.OK>(options: User.Search.FindUsersForPicker.Options): Promise<import("./definitions/FoundUsersAsResponse").FoundUsersAsResponse>;
    /**
  * Returns a list of users that match the search string and property.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and property. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and property, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls or calls by users without the required permission return empty search results.
  * Recommended usage: User.Search.findUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-search-get
  * @param options Request options.
  */
    findUsers<T = User.Search.FindUsers.Response.OK>(options?: User.Search.FindUsers.Options): Promise<User.Search.FindUsers.Response.OK>;
    /**
  * Finds users with a structured query and returns a [paginated](#pagination) list of user details.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  
  The query statements are:
  
   *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
   *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
   *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
   *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
   *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
   *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
   *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
   *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value.
  
  The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
  
  `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
  * Recommended usage: User.Search.findUsersByQuery
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-search-query-get
  * @param options Request options.
  */
    findUsersByQuery<T = User.Search.FindUsersByQuery.Response.OK>(options: User.Search.FindUsersByQuery.Options): Promise<import("./definitions/PageBeanUserAsResponse").PageBeanUserAsResponse>;
    /**
  * Finds users with a structured query and returns a [paginated](#pagination) list of user keys.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  
  The query statements are:
  
   *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
   *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
   *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
   *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
   *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
   *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
   *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
   *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value.
  
  The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
  
  `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
  * Recommended usage: User.Search.findUserKeysByQuery
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-search-query-key-get
  * @param options Request options.
  */
    findUserKeysByQuery<T = User.Search.FindUserKeysByQuery.Response.OK>(options: User.Search.FindUserKeysByQuery.Options): Promise<import("./definitions/PageBeanUserKeyAsResponse").PageBeanUserKeyAsResponse>;
    /**
  * Returns a list of users who fulfill these criteria:
  
   *  their user attributes match a search string.
   *  they have permission to browse issues.
  
  Use this resource to find users who can browse:
  
   *  an issue, by providing the `issueKey`.
   *  any issue in a project, by providing the `projectKey`.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission to browse issues. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission to browse issues, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return empty search results.
  * Recommended usage: User.Search.findUsersWithBrowsePermission
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-viewissue-search-get
  * @param options Request options.
  */
    findUsersWithBrowsePermission<T = User.Search.FindUsersWithBrowsePermission.Response.OK>(options?: User.Search.FindUsersWithBrowsePermission.Options): Promise<User.Search.FindUsersWithBrowsePermission.Response.OK>;
    /**
  * Returns the keys of all properties for a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to access the property keys on any user.
   *  Access to Jira, to access the calling user's property keys.
  * Recommended usage: User.Property.getPropertyKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-get
  * @param options Request options.
  */
    getUserPropertyKeys<T = User.Property.GetPropertyKeys.Response.OK>(options: User.Property.GetPropertyKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the value of a user's property.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get a property from any user.
   *  Access to Jira, to get a property from the calling user's record.
  * Recommended usage: User.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-get
  * @param options Request options.
  */
    getUserProperty<T = User.Property.GetProperty.Response.OK>(options: User.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of a user's property. Use this resource to store custom data against a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set a property on any user.
   *  Access to Jira, to set a property on the calling user's record.
  * Recommended usage: User.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-put
  * @param options Request options.
  */
    setUserProperty<T = User.Property.SetProperty.Response.OK>(options: User.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes a property from a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to delete a property from any user.
   *  Access to Jira, to delete a property from the calling user's record.
  * Recommended usage: User.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-delete
  * @param options Request options.
  */
    deleteUserProperty<T = User.Property.DeleteProperty.Response.OK>(options: User.Property.DeleteProperty.Options): Promise<undefined>;
    /**
  * Changes the value of an application property. For example, you can change the value of the `jira.clone.prefix` from its default value of *CLONE -* to *Clone -* if you prefer sentence case capitalization. Editable properties are described below along with their default values.
  
  #### Advanced settings ####
  
  The advanced settings below are also accessible in [Jira](https://confluence.atlassian.com/x/vYXKM).
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.clone.prefix` | The string of text prefixed to the title of a cloned issue. | `CLONE -` |
  | `jira.date.picker.java.format` | The date format for the Java (server-side) generated dates. This must be the same as the `jira.date.picker.javascript.format` format setting. | `d/MMM/yy` |
  | `jira.date.picker.javascript.format` | The date format for the JavaScript (client-side) generated dates. This must be the same as the `jira.date.picker.java.format` format setting. | `%e/%b/%y` |
  | `jira.date.time.picker.java.format` | The date format for the Java (server-side) generated date times. This must be the same as the `jira.date.time.picker.javascript.format` format setting. | `dd/MMM/yy h:mm a` |
  | `jira.date.time.picker.javascript.format` | The date format for the JavaScript (client-side) generated date times. This must be the same as the `jira.date.time.picker.java.format` format setting. | `%e/%b/%y %I:%M %p` |
  | `jira.issue.actions.order` | The default order of actions (such as *Comments* or *Change history*) displayed on the issue view. | `asc` |
  | `jira.table.cols.subtasks` | The columns to show while viewing subtask issues in a table. For example, a list of subtasks on an issue. | `issuetype, status, assignee, progress` |
  | `jira.view.issue.links.sort.order` | The sort order of the list of issue links on the issue view. | `type, status, priority` |
  | `jira.comment.collapsing.minimum.hidden` | The minimum number of comments required for comment collapsing to occur. A value of `0` disables comment collapsing. | `4` |
  | `jira.newsletter.tip.delay.days` | The number of days before a prompt to sign up to the Jira Insiders newsletter is shown. A value of `-1` disables this feature. | `7` |
  
  
  #### Look and feel ####
  
  The settings listed below adjust the [look and feel](https://confluence.atlassian.com/x/VwCLLg).
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.lf.date.time` | The [ time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `h:mm a` |
  | `jira.lf.date.day` | The [ day format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `EEEE h:mm a` |
  | `jira.lf.date.complete` | The [ date and time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy h:mm a` |
  | `jira.lf.date.dmy` | The [ date format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy` |
  | `jira.date.time.picker.use.iso8061` | When enabled, sets Monday as the first day of the week in the date picker, as specified by the ISO8601 standard. | `false` |
  | `jira.lf.logo.url` | The URL of the logo image file. | `/images/icon-jira-logo.png` |
  | `jira.lf.logo.show.application.title` | Controls the visibility of the application title on the sidebar. | `false` |
  | `jira.lf.favicon.url` | The URL of the favicon. | `/favicon.ico` |
  | `jira.lf.favicon.hires.url` | The URL of the high-resolution favicon. | `/images/64jira.png` |
  | `jira.lf.navigation.bgcolour` | The background color of the sidebar. | `#0747A6` |
  | `jira.lf.navigation.highlightcolour` | The color of the text and logo of the sidebar. | `#DEEBFF` |
  | `jira.lf.hero.button.base.bg.colour` | The background color of the hero button. | `#3b7fc4` |
  | `jira.title` | The text for the application title. The application title can also be set in *General settings*. | `Jira` |
  | `jira.option.globalsharing` | Whether filters and dashboards can be shared with anyone signed into Jira. | `true` |
  | `xflow.product.suggestions.enabled` | Whether to expose product suggestions for other Atlassian products within Jira. | `true` |
  
  
  #### Other settings ####
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.issuenav.criteria.autoupdate` | Whether instant updates to search criteria is active. | `true` |
  
  
  *Note: Be careful when changing [application properties and advanced settings](https://confluence.atlassian.com/x/vYXKM).*
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Instance.setApplicationProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-application-properties-id-put
  * @param options Request options.
  */
    setApplicationProperty<T = Instance.SetApplicationProperty.Response.OK>(options: Instance.SetApplicationProperty.Options): Promise<import("./definitions/ApplicationPropertyAsResponse").ApplicationPropertyAsResponse>;
    /**
  * Returns all application properties or an application property.
  
  If you specify a value for the `key` parameter, then an application property is returned as an object (not in an array). Otherwise, an array of all editable application properties is returned. See [Set application property](#api-rest-api-3-application-properties-id-put) for descriptions of editable properties.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Instance.getApplicationProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-application-properties-get
  * @param options Request options.
  */
    getApplicationProperty<T = Instance.GetApplicationProperty.Response.OK>(options?: Instance.GetApplicationProperty.Options): Promise<Instance.GetApplicationProperty.Response.OK>;
    /**
  * Returns the application properties that are accessible on the *Advanced Settings* page. To navigate to the *Advanced Settings* page in Jira, choose the Jira icon > **Jira settings** > **System**, **General Configuration** and then click **Advanced Settings** (in the upper right).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Instance.getAdvancedSettings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-application-properties-advanced-settings-get
  * @param options Request options.
  */
    getAdvancedSettings<T = Instance.GetAdvancedSettings.Response.OK>(options?: Instance.GetAdvancedSettings.Options): Promise<Instance.GetAdvancedSettings.Response.OK>;
    /**
  * Returns the attachment settings, that is, whether attachments are enabled and the maximum attachment size allowed.
  
  Note that there are also [project permissions](https://confluence.atlassian.com/x/yodKLg) that restrict whether users can create and delete attachments.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Instance.getAttachmentSettings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-meta-get
  * @param options Request options.
  */
    getJiraAttachmentSettings<T = Instance.GetAttachmentSettings.Response.OK>(options?: Instance.GetAttachmentSettings.Options): Promise<import("./definitions/AttachmentSettingsAsResponse").AttachmentSettingsAsResponse>;
    /**
  * Returns the [global settings](https://confluence.atlassian.com/x/qYXKM) in Jira. These settings determine whether optional features (for example, subtasks, time tracking, and others) are enabled. If time tracking is enabled, this operation also returns the time tracking configuration.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Instance.getGlobalSettings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-configuration-get
  * @param options Request options.
  */
    getGlobalSettings<T = Instance.GetGlobalSettings.Response.OK>(options?: Instance.GetGlobalSettings.Options): Promise<import("./definitions/ConfigurationAsResponse").ConfigurationAsResponse>;
    /**
  * Returns information about the Jira instance.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Instance.getInfo
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-serverInfo-get
  * @param options Request options.
  */
    getJiraInstanceInfo<T = Instance.GetInfo.Response.OK>(options?: Instance.GetInfo.Options): Promise<import("./definitions/ServerInformationAsResponse").ServerInformationAsResponse>;
    /**
  * Returns licensing information about the Jira instance.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Instance.getLicense
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-instance-information/#api-rest-api-3-instance-license-get
  * @param options Request options.
  */
    getLicense<T = Instance.GetLicense.Response.OK>(options?: Instance.GetLicense.Options): Promise<import("./definitions/LicenseAsResponse").LicenseAsResponse>;
    /**
  * Creates a project based on a project type template, as shown in the following table:
  
  | Project Type Key | Project Template Key |
  |--|--|
  | `business` | `com.atlassian.jira-core-project-templates:jira-core-simplified-content-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-document-approval`, `com.atlassian.jira-core-project-templates:jira-core-simplified-lead-tracking`, `com.atlassian.jira-core-project-templates:jira-core-simplified-process-control`, `com.atlassian.jira-core-project-templates:jira-core-simplified-procurement`, `com.atlassian.jira-core-project-templates:jira-core-simplified-project-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-recruitment`, `com.atlassian.jira-core-project-templates:jira-core-simplified-task-tracking` |
  | `service_desk` | `com.atlassian.servicedesk:simplified-it-service-management`, `com.atlassian.servicedesk:simplified-general-service-desk`, `com.atlassian.servicedesk:simplified-internal-service-desk`, `com.atlassian.servicedesk:simplified-external-service-desk`, `com.atlassian.servicedesk:simplified-hr-service-desk`, `com.atlassian.servicedesk:simplified-facilities-service-desk`, `com.atlassian.servicedesk:simplified-legal-service-desk` |
  | `software` | `com.pyxis.greenhopper.jira:gh-simplified-agility-kanban`, `com.pyxis.greenhopper.jira:gh-simplified-agility-scrum`, `com.pyxis.greenhopper.jira:gh-simplified-basic`, `com.pyxis.greenhopper.jira:gh-simplified-kanban-classic`, `com.pyxis.greenhopper.jira:gh-simplified-scrum-classic` |
  The project types are available according to the installed Jira features as follows:
  
   *  Jira Core, the default, enables `business` projects.
   *  Jira Service Management enables `service_desk` projects.
   *  Jira Software enables `software` projects.
  
  To determine which features are installed, go to **Jira settings** > **Apps** > **Manage apps** and review the System Apps list. To add Jira Software or Jira Service Management into a JIRA instance, use **Jira settings** > **Apps** > **Finding new apps**. For more information, see [ Managing add-ons](https://confluence.atlassian.com/x/S31NLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.createProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-post
  * @param options Request options.
  */
    createProject<T = Project.CreateProject.Response.OK>(options: Project.CreateProject.Options): Promise<import("./definitions/ProjectIdentifiersAsResponse").ProjectIdentifiersAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of projects visible to the user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Projects are returned only where the user has one of:
  
   *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.getProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-search-get
  * @param options Request options.
  */
    getProjects<T = Project.GetProjects.Response.OK>(options?: Project.GetProjects.Options): Promise<import("./definitions/PageBeanProjectAsResponse").PageBeanProjectAsResponse>;
    /**
  * Returns the [project details](https://confluence.atlassian.com/x/ahLpNw) for a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.getProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-get
  * @param options Request options.
  */
    getProject<T = Project.GetProject.Response.OK>(options: Project.GetProject.Options): Promise<import("./definitions/ProjectAsResponse").ProjectAsResponse>;
    /**
  * Updates the [project details](https://confluence.atlassian.com/x/ahLpNw) of a project.
  
  All parameters are optional in the body of the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.updateProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-put
  * @param options Request options.
  */
    updateProject<T = Project.UpdateProject.Response.OK>(options: Project.UpdateProject.Options): Promise<import("./definitions/ProjectAsResponse").ProjectAsResponse>;
    /**
  * Deletes a project.
  
  You can't delete a project if it's archived. To delete an archived project, restore the project and then delete it. To restore a project, use the Jira UI.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.deleteProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-delete
  * @param options Request options.
  */
    deleteProject<T = Project.DeleteProject.Response.OK>(options: Project.DeleteProject.Options): Promise<undefined>;
    /**
  * Returns the valid statuses for a project. The statuses are grouped by issue type, as each project has a set of valid issue types and each issue type has a set of valid statuses.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.getStatuses
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-statuses-get
  * @param options Request options.
  */
    getStatusesForProject<T = Project.GetStatuses.Response.OK>(options: Project.GetStatuses.Options): Promise<Project.GetStatuses.Response.OK>;
    /**
  * Creates a component. Use components to provide containers for issues within a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Component.createComponent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-post
  * @param options Request options.
  */
    createProjectComponent<T = Project.Component.CreateComponent.Response.OK>(options: Project.Component.CreateComponent.Options): Promise<import("./definitions/ProjectComponentAsResponse").ProjectComponentAsResponse>;
    /**
  * Returns a component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
  * Recommended usage: Project.Component.getComponent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-get
  * @param options Request options.
  */
    getProjectComponent<T = Project.Component.GetComponent.Response.OK>(options: Project.Component.GetComponent.Options): Promise<import("./definitions/ProjectComponentAsResponse").ProjectComponentAsResponse>;
    /**
  * Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Component.updateComponent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-put
  * @param options Request options.
  */
    updateProjectComponent<T = Project.Component.UpdateComponent.Response.OK>(options: Project.Component.UpdateComponent.Options): Promise<import("./definitions/ComponentAsResponse").ComponentAsResponse>;
    /**
  * Deletes a component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Component.deleteComponent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-delete
  * @param options Request options.
  */
    deleteProjectComponent<T = Project.Component.DeleteComponent.Response.OK>(options: Project.Component.DeleteComponent.Options): Promise<undefined>;
    /**
  * Returns the counts of issues assigned to the component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Project.Component.getIssueCount
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-relatedIssueCounts-get
  * @param options Request options.
  */
    getProjectComponentIssueCount<T = Project.Component.GetIssueCount.Response.OK>(options: Project.Component.GetIssueCount.Options): Promise<import("./definitions/ComponentIssuesCountAsResponse").ComponentIssuesCountAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.Component.getComponentsPaginated
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-component-get
  * @param options Request options.
  */
    getProjectComponentsPaginated<T = Project.Component.GetComponentsPaginated.Response.OK>(options: Project.Component.GetComponentsPaginated.Options): Promise<import("./definitions/PageBeanComponentWithIssueCountAsResponse").PageBeanComponentWithIssueCountAsResponse>;
    /**
  * Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.Component.getComponents
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-components-get
  * @param options Request options.
  */
    getProjectComponents<T = Project.Component.GetComponents.Response.OK>(options: Project.Component.GetComponents.Options): Promise<Project.Component.GetComponents.Response.OK>;
    /**
  * Returns a list of [project roles](https://confluence.atlassian.com/x/3odKLg) for the project returning the name and self URL for each role.
  
  Note that all project roles are shared with all projects in Jira Cloud. See [Get all project roles](#api-rest-api-3-role-get) for more information.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for any project on the site or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.getRolesForProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-get
  * @param options Request options.
  */
    getProjectRolesForProject<T = Project.Role.GetRolesForProject.Response.OK>(options: Project.Role.GetRolesForProject.Options): Promise<Project.Role.GetRolesForProject.Response.OK>;
    /**
  * Returns a project role's details and actors associated with the project. The list of actors is sorted by display name.
  
  To check whether a user belongs to a role based on their group memberships, use [Get user](#api-rest-api-3-user-get) with the `groups` expand parameter selected. Then check whether the user keys and groups match with the actors returned for the project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.getRoleForProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-get
  * @param options Request options.
  */
    getProjectRoleForProject<T = Project.Role.GetRoleForProject.Response.OK>(options: Project.Role.GetRoleForProject.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Returns all [project roles](https://confluence.atlassian.com/x/3odKLg) and the details for each role. Note that the list of project roles is common to all projects.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.Role.getDetails
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-roledetails-get
  * @param options Request options.
  */
    getProjectRoleDetails<T = Project.Role.GetDetails.Response.OK>(options: Project.Role.GetDetails.Options): Promise<Project.Role.GetDetails.Response.OK>;
    /**
  * Gets a list of all project roles, complete with project role details and default actors.
  
  ### About project roles ###
  
  [Project roles](https://confluence.atlassian.com/x/3odKLg) are a flexible way to to associate users and groups with projects. In Jira Cloud, the list of project roles is shared globally with all projects, but each project can have a different set of actors associated with it (unlike groups, which have the same membership throughout all Jira applications).
  
  Project roles are used in [permission schemes](#api-rest-api-3-permissionscheme-get), [email notification schemes](#api-rest-api-3-notificationscheme-get), [issue security levels](#api-rest-api-3-issuesecurityschemes-get), [comment visibility](#api-rest-api-3-comment-list-post), and workflow conditions.
  
  #### Members and actors ####
  
  In the Jira REST API, a member of a project role is called an *actor*. An *actor* is a group or user associated with a project role.
  
  Actors may be set as [default members](https://confluence.atlassian.com/x/3odKLg#Managingprojectroles-Specifying'defaultmembers'foraprojectrole) of the project role or set at the project level:
  
   *  Default actors: Users and groups that are assigned to the project role for all newly created projects. The default actors can be removed at the project level later if desired.
   *  Actors: Users and groups that are associated with a project role for a project, which may differ from the default actors. This enables you to assign a user to different roles in different projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.getRoles
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-get
  * @param options Request options.
  */
    getProjectRoles<T = Project.Role.GetRoles.Response.OK>(options?: Project.Role.GetRoles.Options): Promise<Project.Role.GetRoles.Response.OK>;
    /**
  * Creates a new project role with no [default actors](#api-rest-api-3-resolution-get). You can use the [Add default actors to project role](#api-rest-api-3-role-id-actors-post) operation to add default actors to the project role after creating it.
  
  *Note that although a new project role is available to all projects upon creation, any default actors that are associated with the project role are not added to projects that existed prior to the role being created.*<
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.createRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-post
  * @param options Request options.
  */
    createProjectRole<T = Project.Role.CreateRole.Response.OK>(options: Project.Role.CreateRole.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Gets the project role details and the default actors associated with the role. The list of default actors is sorted by display name.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.getRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-get
  * @param options Request options.
  */
    getProjectRole<T = Project.Role.GetRole.Response.OK>(options: Project.Role.GetRole.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Updates the project role's name and description. You must include both a name and a description in the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.fullyUpdateRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-put
  * @param options Request options.
  */
    fullyUpdateProjectRole<T = Project.Role.FullyUpdateRole.Response.OK>(options: Project.Role.FullyUpdateRole.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Updates either the project role's name or its description.
  
  You cannot update both the name and description at the same time using this operation. If you send a request with a name and a description only the name is updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.partiallyUpdateRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-post
  * @param options Request options.
  */
    partiallyUpdateProjectRole<T = Project.Role.PartiallyUpdateRole.Response.OK>(options: Project.Role.PartiallyUpdateRole.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Deletes a project role. You must specify a replacement project role if you wish to delete a project role that is in use.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.deleteRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-delete
  * @param options Request options.
  */
    deleteProjectRole<T = Project.Role.DeleteRole.Response.OK>(options: Project.Role.DeleteRole.Options): Promise<undefined>;
    /**
  * Sets the actors for a project role for a project, replacing all existing actors.
  
  To add actors to the project without overwriting the existing list, use [Add actors to project role](#api-rest-api-3-project-projectIdOrKey-role-id-post).
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.Actor.setActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-put
  * @param options Request options.
  */
    setActorsForProjectRole<T = Project.Role.Actor.SetActors.Response.OK>(options: Project.Role.Actor.SetActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Adds actors to a project role for the project.
  
  To replace all actors for the project, use [Set actors for project role](#api-rest-api-3-project-projectIdOrKey-role-id-put).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.Actor.addActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-post
  * @param options Request options.
  */
    addActorsToProjectRole<T = Project.Role.Actor.AddActors.Response.OK>(options: Project.Role.Actor.AddActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Deletes actors from a project role for the project.
  
  To remove default actors from the project role, use [Delete default actors from project role](#api-rest-api-3-role-id-actors-delete).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.Actor.deleteActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-delete
  * @param options Request options.
  */
    deleteActorsFromProjectRole<T = Project.Role.Actor.DeleteActors.Response.OK>(options: Project.Role.Actor.DeleteActors.Options): Promise<undefined>;
    /**
  * Returns the [default actors](#api-rest-api-3-resolution-get) for the project role.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.Actor.Default.getActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-get
  * @param options Request options.
  */
    getDefaultActorsForProjectRole<T = Project.Role.Actor.Default.GetActors.Response.OK>(options: Project.Role.Actor.Default.GetActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Adds [default actors](#api-rest-api-3-resolution-get) to a role. You may add groups or users, but you cannot add groups and users in the same request.
  
  Changing a project role's default actors does not affect project role members for projects already created.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.Actor.Default.addActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-post
  * @param options Request options.
  */
    addDefaultActorsToProjectRole<T = Project.Role.Actor.Default.AddActors.Response.OK>(options: Project.Role.Actor.Default.AddActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Deletes the [default actors](#api-rest-api-3-resolution-get) from a project role. You may delete a group or user, but you cannot delete a group and a user in the same request.
  
  Changing a project role's default actors does not affect project role members for projects already created.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Role.Actor.Default.deleteActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-delete
  * @param options Request options.
  */
    deleteDefaultActorsFromProjectRole<T = Project.Role.Actor.Default.DeleteActors.Response.OK>(options: Project.Role.Actor.Default.DeleteActors.Options): Promise<import("./definitions/ProjectRoleAsResponse").ProjectRoleAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of all versions in a project. See the [Get project versions](#api-rest-api-3-project-projectIdOrKey-versions-get) resource if you want to get a full list of versions without pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.Version.getVersionsPaginated
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-version-get
  * @param options Request options.
  */
    getProjectVersionsPaginated<T = Project.Version.GetVersionsPaginated.Response.OK>(options: Project.Version.GetVersionsPaginated.Options): Promise<import("./definitions/PageBeanVersionAsResponse").PageBeanVersionAsResponse>;
    /**
  * Returns all versions in a project. The response is not paginated. Use [Get project versions paginated](#api-rest-api-3-project-projectIdOrKey-version-get) if you want to get the versions in a project with pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.Version.getVersions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-versions-get
  * @param options Request options.
  */
    getProjectVersions<T = Project.Version.GetVersions.Response.OK>(options: Project.Version.GetVersions.Options): Promise<Project.Version.GetVersions.Response.OK>;
    /**
  * Creates a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the version is added to.
  * Recommended usage: Project.Version.createVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-post
  * @param options Request options.
  */
    createProjectVersion<T = Project.Version.CreateVersion.Response.OK>(options: Project.Version.CreateVersion.Options): Promise<import("./definitions/VersionAsResponse").VersionAsResponse>;
    /**
  * Returns a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the version.
  * Recommended usage: Project.Version.getVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-get
  * @param options Request options.
  */
    getProjectVersion<T = Project.Version.GetVersion.Response.OK>(options: Project.Version.GetVersion.Options): Promise<import("./definitions/VersionAsResponse").VersionAsResponse>;
    /**
  * Updates a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Recommended usage: Project.Version.updateVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-put
  * @param options Request options.
  */
    updateProjectVersion<T = Project.Version.UpdateVersion.Response.OK>(options: Project.Version.UpdateVersion.Options): Promise<import("./definitions/VersionAsResponse").VersionAsResponse>;
    /**
  * Merges two project versions. The merge is completed by deleting the version specified in `id` and replacing any occurrences of its ID in `fixVersion` with the version ID specified in `moveIssuesTo`.
  
  Consider using [ Delete and replace version](#api-rest-api-3-version-id-removeAndSwap-post) instead. This resource supports swapping version values in `fixVersion`, `affectedVersion`, and custom fields.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Recommended usage: Project.Version.mergeVersions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-mergeto-moveIssuesTo-put
  * @param options Request options.
  */
    mergeProjectVersions<T = Project.Version.MergeVersions.Response.OK>(options: Project.Version.MergeVersions.Options): Promise<any>;
    /**
  * Modifies the version's sequence within the project, which affects the display order of the versions in Jira.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Recommended usage: Project.Version.moveVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-move-post
  * @param options Request options.
  */
    moveProjectVersion<T = Project.Version.MoveVersion.Response.OK>(options: Project.Version.MoveVersion.Options): Promise<import("./definitions/VersionAsResponse").VersionAsResponse>;
    /**
  * Deletes a project version.
  
  Alternative versions can be provided to update issues that use the deleted version in `fixVersion`, `affectedVersion`, or any version picker custom fields. If alternatives are not provided, occurrences of `fixVersion`, `affectedVersion`, and any version picker custom field, that contain the deleted version, are cleared. Any replacement version must be in the same project as the version being deleted and cannot be the version being deleted.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Recommended usage: Project.Version.deleteAndReplaceVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-removeAndSwap-post
  * @param options Request options.
  */
    deleteAndReplaceProjectVersion<T = Project.Version.DeleteAndReplaceVersion.Response.OK>(options: Project.Version.DeleteAndReplaceVersion.Options): Promise<any>;
    /**
  * Returns the following counts for a version:
  
   *  Number of issues where the `fixVersion` is set to the version.
   *  Number of issues where the `affectedVersion` is set to the version.
   *  Number of issues where a version custom field is set to the version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Recommended usage: Project.Version.Count.getRelatedIssueCount
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-relatedIssueCounts-get
  * @param options Request options.
  */
    getProjectVersionRelatedIssueCount<T = Project.Version.Count.GetRelatedIssueCount.Response.OK>(options: Project.Version.Count.GetRelatedIssueCount.Options): Promise<import("./definitions/VersionIssueCountsAsResponse").VersionIssueCountsAsResponse>;
    /**
  * Returns counts of the issues and unresolved issues for the project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Recommended usage: Project.Version.Count.getUnresolvedIssueCount
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-unresolvedIssueCount-get
  * @param options Request options.
  */
    getProjectVersionUnresolvedIssueCount<T = Project.Version.Count.GetUnresolvedIssueCount.Response.OK>(options: Project.Version.Count.GetUnresolvedIssueCount.Options): Promise<import("./definitions/VersionUnresolvedIssuesCountAsResponse").VersionUnresolvedIssuesCountAsResponse>;
    /**
  * Get the issue type hierarchy for a next-gen project.
  
  The issue type hierarchy for a project consists of:
  
   *  *Epic* at level 1 (optional).
   *  One or more issue types at level 0 such as *Story*, *Task*, or *Bug*. Where the issue type *Epic* is defined, these issue types are used to break down the content of an epic.
   *  *Subtask* at level -1 (optional). This issue type enables level 0 issue types to be broken down into components. Issues based on a level -1 issue type must have a parent issue.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.IssueType.getHierarchy
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectId-hierarchy-get
  * @param options Request options.
  * @deprecated
  */
    getProjectIssueTypeHierarchy<T = Project.IssueType.GetHierarchy.Response.OK>(options: Project.IssueType.GetHierarchy.Options): Promise<import("./definitions/ProjectIssueTypeHierarchyAsResponse").ProjectIssueTypeHierarchyAsResponse>;
    /**
  * Validates a project key by confirming the key is a valid string and not in use.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Project.Validation.validateProjectKey
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-key-get
  * @param options Request options.
  */
    validateProjectKey<T = Project.Validation.ValidateProjectKey.Response.OK>(options: Project.Validation.ValidateProjectKey.Options): Promise<import("./definitions/ErrorCollectionAsResponse").ErrorCollectionAsResponse>;
    /**
  * Validates a project key and, if the key is invalid or in use, generates a valid random string for the project key.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Project.Validation.getValidProjectKey
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-validProjectKey-get
  * @param options Request options.
  */
    getValidProjectKey<T = Project.Validation.GetValidProjectKey.Response.OK>(options: Project.Validation.GetValidProjectKey.Options): Promise<string>;
    /**
  * Checks that a project name isn't in use. If the name isn't in use, the passed string is returned. If the name is in use, this operation attempts to generate a valid project name based on the one supplied, usually by adding a sequence number. If a valid project name cannot be generated, a 404 response is returned.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Project.Validation.getValidProjectName
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-validProjectName-get
  * @param options Request options.
  */
    getValidProjectName<T = Project.Validation.GetValidProjectName.Response.OK>(options: Project.Validation.GetValidProjectName.Options): Promise<string>;
    /**
  * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw), whether or not the instance has a valid license for each type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Project.Type.getTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-get
  * @param options Request options.
  */
    getProjectTypes<T = Project.Type.GetTypes.Response.OK>(options?: Project.Type.GetTypes.Options): Promise<Project.Type.GetTypes.Response.OK>;
    /**
     * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw) with a valid license.
     * Recommended usage: Project.Type.getLicensedTypes
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-accessible-get
     * @param options Request options.
     */
    getLicensedProjectTypes<T = Project.Type.GetLicensedTypes.Response.OK>(options?: Project.Type.GetLicensedTypes.Options): Promise<Project.Type.GetLicensedTypes.Response.OK>;
    /**
  * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Project.Type.getTypeByKey
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-get
  * @param options Request options.
  */
    getProjectTypeByKey<T = Project.Type.GetTypeByKey.Response.OK>(options: Project.Type.GetTypeByKey.Options): Promise<import("./definitions/ProjectTypeAsResponse").ProjectTypeAsResponse>;
    /**
  * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw) if it is accessible to the user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Project.Type.getAccessibleTypeByKey
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-accessible-get
  * @param options Request options.
  */
    getAccessibleProjectTypeByKey<T = Project.Type.GetAccessibleTypeByKey.Response.OK>(options: Project.Type.GetAccessibleTypeByKey.Options): Promise<import("./definitions/ProjectTypeAsResponse").ProjectTypeAsResponse>;
    /**
  * Returns all project categories.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Project.Category.getCategories
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-get
  * @param options Request options.
  */
    getProjectCategories<T = Project.Category.GetCategories.Response.OK>(options?: Project.Category.GetCategories.Options): Promise<Project.Category.GetCategories.Response.OK>;
    /**
  * Creates a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Category.createCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-post
  * @param options Request options.
  */
    createProjectCategory<T = Project.Category.CreateCategory.Response.OK>(options: Project.Category.CreateCategory.Options): Promise<import("./definitions/ProjectCategoryAsResponse").ProjectCategoryAsResponse>;
    /**
  * Returns a project category.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Project.Category.getCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-get
  * @param options Request options.
  */
    getProjectCategory<T = Project.Category.GetCategory.Response.OK>(options: Project.Category.GetCategory.Options): Promise<import("./definitions/ProjectCategoryAsResponse").ProjectCategoryAsResponse>;
    /**
  * Updates a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Category.updateCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-put
  * @param options Request options.
  */
    updateProjectCategory<T = Project.Category.UpdateCategory.Response.OK>(options: Project.Category.UpdateCategory.Options): Promise<import("./definitions/UpdatedProjectCategoryAsResponse").UpdatedProjectCategoryAsResponse>;
    /**
  * Deletes a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Project.Category.deleteCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-delete
  * @param options Request options.
  */
    deleteProjectCategory<T = Project.Category.DeleteCategory.Response.OK>(options: Project.Category.DeleteCategory.Options): Promise<undefined>;
    /**
  * Gets a [notification scheme](https://confluence.atlassian.com/x/8YdKLg) associated with the project. See the [Get notification scheme](#api-rest-api-3-notificationscheme-id-get) resource for more information about notification schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Recommended usage: Project.Notification.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectkeyorid-notificationscheme-get
  * @param options Request options.
  */
    getProjectNotificationScheme<T = Project.Notification.Scheme.GetScheme.Response.OK>(options: Project.Notification.Scheme.GetScheme.Options): Promise<import("./definitions/NotificationSchemeAsResponse").NotificationSchemeAsResponse>;
    /**
  * Assigns a permission scheme with a project. See [Managing project permissions](https://confluence.atlassian.com/x/yodKLg) for more information about permission schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
  * Recommended usage: Project.Permission.Scheme.assignScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-put
  * @param options Request options.
  */
    assignProjectPermissionScheme<T = Project.Permission.Scheme.AssignScheme.Response.OK>(options: Project.Permission.Scheme.AssignScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Gets the [permission scheme](https://confluence.atlassian.com/x/yodKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Recommended usage: Project.Permission.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-get
  * @param options Request options.
  */
    getProjectPermissionScheme<T = Project.Permission.Scheme.GetScheme.Response.OK>(options: Project.Permission.Scheme.GetScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Returns all [issue security](https://confluence.atlassian.com/x/J4lKLg) levels for the project that the user has access to.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project, however, issue security levels are only returned for authenticated user with *Set Issue Security* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project.
  * Recommended usage: Project.Permission.Scheme.getIssueSecurityLevels
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-securitylevel-get
  * @param options Request options.
  */
    getProjectIssueSecurityLevels<T = Project.Permission.Scheme.GetIssueSecurityLevels.Response.OK>(options: Project.Permission.Scheme.GetIssueSecurityLevels.Options): Promise<import("./definitions/ProjectIssueSecurityLevelsAsResponse").ProjectIssueSecurityLevelsAsResponse>;
    /**
  * Returns the [issue security scheme](https://confluence.atlassian.com/x/J4lKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or the *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Recommended usage: Project.Security.Scheme.getIssueScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-issuesecuritylevelscheme-get
  * @param options Request options.
  */
    getProjectIssueSecurityScheme<T = Project.Security.Scheme.GetIssueScheme.Response.OK>(options: Project.Security.Scheme.GetIssueScheme.Options): Promise<import("./definitions/SecuritySchemeAsResponse").SecuritySchemeAsResponse>;
    /**
  * Returns all [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys for the project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Recommended usage: Project.Property.getPropertyKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-get
  * @param options Request options.
  */
    getProjectPropertyKeys<T = Project.Property.GetPropertyKeys.Response.OK>(options: Project.Property.GetPropertyKeys.Options): Promise<import("./definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
    /**
  * Returns the value of a [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
  * Recommended usage: Project.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-get
  * @param options Request options.
  */
    getProjectProperty<T = Project.Property.GetProperty.Response.OK>(options: Project.Property.GetProperty.Options): Promise<import("./definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
    /**
  * Sets the value of the [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). You can use project properties to store custom data against the project.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the property is created.
  * Recommended usage: Project.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-put
  * @param options Request options.
  */
    setProjectProperty<T = Project.Property.SetProperty.Response.OK>(options: Project.Property.SetProperty.Options): Promise<any>;
    /**
  * Deletes the [property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) from a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
  * Recommended usage: Project.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-delete
  * @param options Request options.
  */
    deleteProjectProperty<T = Project.Property.DeleteProperty.Response.OK>(options: Project.Property.DeleteProperty.Options): Promise<undefined>;
    /**
  * Creates a filter. The filter is shared according to the [default share scope](#api-rest-api-3-filter-post). The filter is not selected as a favorite.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Filter.createFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-post
  * @param options Request options.
  */
    createFilter<T = Filter.CreateFilter.Response.OK>(options: Filter.CreateFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Returns the filters owned by the user. If `includeFavourites` is `true`, the user's visible favorite filters are also returned.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, a favorite filters is only visible to the user where the filter is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  
  For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
  * Recommended usage: Filter.getMyFilters
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-my-get
  * @param options Request options.
  */
    getMyFilters<T = Filter.GetMyFilters.Response.OK>(options?: Filter.GetMyFilters.Options): Promise<Filter.GetMyFilters.Response.OK>;
    /**
  * Returns a [paginated](#pagination) list of filters. Use this operation to get:
  
   *  specific filters, by defining `id` only.
   *  filters that match all of the specified attributes. For example, all filters for a user with a particular word in their name. When multiple attributes are specified only filters matching all attributes are returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, only the following filters that match the query parameters are returned:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Recommended usage: Filter.searchFilters
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-search-get
  * @param options Request options.
  */
    searchFilters<T = Filter.SearchFilters.Response.OK>(options?: Filter.SearchFilters.Options): Promise<import("./definitions/PageBeanFilterDetailsAsResponse").PageBeanFilterDetailsAsResponse>;
    /**
  * Returns a filter.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, the filter is only returned where it is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  * Recommended usage: Filter.getFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-get
  * @param options Request options.
  */
    getFilter<T = Filter.GetFilter.Response.OK>(options: Filter.GetFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter.
  * Recommended usage: Filter.updateFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-put
  * @param options Request options.
  */
    updateFilter<T = Filter.UpdateFilter.Response.OK>(options: Filter.UpdateFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Delete a filter.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however filters can only be deleted by the creator of the filter or a user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Filter.deleteFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-delete
  * @param options Request options.
  */
    deleteFilter<T = Filter.DeleteFilter.Response.OK>(options: Filter.DeleteFilter.Options): Promise<undefined>;
    /**
  * Returns the visible favorite filters of the user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** A favorite filter is only visible to the user where the filter is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  
  For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
  * Recommended usage: Filter.Favourite.getFilters
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-favourite-get
  * @param options Request options.
  */
    getFavouriteFilters<T = Filter.Favourite.GetFilters.Response.OK>(options?: Filter.Favourite.GetFilters.Options): Promise<Filter.Favourite.GetFilters.Response.OK>;
    /**
  * Add a filter as a favorite for the user.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, the user can only favorite:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Recommended usage: Filter.Favourite.addFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-favourite-put
  * @param options Request options.
  */
    addFilterAsFavourite<T = Filter.Favourite.AddFilter.Response.OK>(options: Filter.Favourite.AddFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Removes a filter as a favorite for the user. Note that this operation only removes filters visible to the user from the user's favorites list. For example, if the user favorites a public filter that is subsequently made private (and is therefore no longer visible on their favorites list) they cannot remove it from their favorites list.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Filter.Favourite.removeFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-favourite-delete
  * @param options Request options.
  */
    removeFilterAsFavourite<T = Filter.Favourite.RemoveFilter.Response.OK>(options: Filter.Favourite.RemoveFilter.Options): Promise<import("./definitions/FilterAsResponse").FilterAsResponse>;
    /**
  * Returns the columns configured for a filter. The column configuration is used when the filter's results are viewed in *List View* with the *Columns* set to *Filter*.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, column details are only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Recommended usage: Filter.Column.getColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-get
  * @param options Request options.
  */
    getFilterColumns<T = Filter.Column.GetColumns.Response.OK>(options: Filter.Column.GetColumns.Options): Promise<Filter.Column.GetColumns.Response.OK>;
    /**
  * Sets the columns for a filter. Only navigable fields can be set as columns. Use [Get fields](#api-rest-api-3-field-get) to get the list fields in Jira. A navigable field has `navigable` set to `true`.
  
  The parameters for this resource are expressed as HTML form data. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/filter/10000/columns`
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only set for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Recommended usage: Filter.Column.setColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-put
  * @param options Request options.
  */
    setFilterColumns<T = Filter.Column.SetColumns.Response.OK>(options: Filter.Column.SetColumns.Options): Promise<any>;
    /**
  * Reset the user's column configuration for the filter to the default.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only reset for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Recommended usage: Filter.Column.resetColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-delete
  * @param options Request options.
  */
    resetFilterColumns<T = Filter.Column.ResetColumns.Response.OK>(options: Filter.Column.ResetColumns.Options): Promise<undefined>;
    /**
  * Returns the default sharing settings for new filters and dashboards for a user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Filter.Share.getDefaultScope
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-defaultsharescope-get
  * @param options Request options.
  */
    getFiltersDefaultShareScope<T = Filter.Share.GetDefaultScope.Response.OK>(options?: Filter.Share.GetDefaultScope.Options): Promise<import("./definitions/DefaultShareScopeAsResponse").DefaultShareScopeAsResponse>;
    /**
  * Sets the default sharing for new filters and dashboards for a user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Filter.Share.setDefaultScope
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-defaultsharescope-put
  * @param options Request options.
  */
    setFiltersDefaultShareScope<T = Filter.Share.SetDefaultScope.Response.OK>(options: Filter.Share.SetDefaultScope.Options): Promise<import("./definitions/DefaultShareScopeAsResponse").DefaultShareScopeAsResponse>;
    /**
  * Returns the share permissions for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, share permissions are only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Recommended usage: Filter.Share.Permission.getPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-get
  * @param options Request options.
  */
    getFiltersSharePermissions<T = Filter.Share.Permission.GetPermissions.Response.OK>(options: Filter.Share.Permission.GetPermissions.Options): Promise<Filter.Share.Permission.GetPermissions.Response.OK>;
    /**
  * Add a share permissions to a filter. If you add a global share permission (one for all logged-in users or the public) it will overwrite all share permissions for the filter.
  
  Be aware that this operation uses different objects for updating share permissions compared to [Update filter](#api-rest-api-3-filter-id-put).
  
  **[Permissions](#permissions) required:** *Share dashboards and filters* [global permission](https://confluence.atlassian.com/x/x4dKLg) and the user must own the filter.
  * Recommended usage: Filter.Share.Permission.addPermission
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-post
  * @param options Request options.
  */
    addFiltersSharePermission<T = Filter.Share.Permission.AddPermission.Response.OK>(options: Filter.Share.Permission.AddPermission.Options): Promise<Filter.Share.Permission.AddPermission.Response.OK>;
    /**
  * Returns a share permission for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, a share permission is only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Recommended usage: Filter.Share.Permission.getPermission
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-get
  * @param options Request options.
  */
    getFiltersSharePermission<T = Filter.Share.Permission.GetPermission.Response.OK>(options: Filter.Share.Permission.GetPermission.Options): Promise<import("./definitions/SharePermissionAsResponse").SharePermissionAsResponse>;
    /**
  * Deletes a share permission from a filter.
  
  **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter.
  * Recommended usage: Filter.Share.Permission.deletePermission
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-delete
  * @param options Request options.
  */
    deleteFiltersSharePermission<T = Filter.Share.Permission.DeletePermission.Response.OK>(options: Filter.Share.Permission.DeletePermission.Options): Promise<undefined>;
    /**
  * Creates a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Recommended usage: Group.createGroup
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-post
  * @param options Request options.
  */
    createGroup<T = Group.CreateGroup.Response.OK>(options: Group.CreateGroup.Options): Promise<import("./definitions/GroupAsResponse").GroupAsResponse>;
    /**
  * Deletes a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* strategic [group](https://confluence.atlassian.com/x/24xjL)).
  * Recommended usage: Group.removeGroup
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-delete
  * @param options Request options.
  */
    removeGroup<T = Group.RemoveGroup.Response.OK>(options: Group.RemoveGroup.Options): Promise<undefined>;
    /**
  * Returns a list of groups whose names contain a query string. A list of group names can be provided to exclude groups from the results.
  
  The primary use case for this resource is to populate a group picker suggestions list. To this end, the returned object includes the `html` field where the matched query term is highlighted in the group name with the HTML strong tag. Also, the groups list is wrapped in a response object that contains a header for use in the picker, specifically *Showing X of Y matching groups*.
  
  The list returns with the groups sorted. If no groups match the list criteria, an empty list is returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg). Anonymous calls and calls by users without the required permission return an empty list.
  * Recommended usage: Group.findGroups
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-groups-picker-get
  * @param options Request options.
  */
    findGroups<T = Group.FindGroups.Response.OK>(options?: Group.FindGroups.Options): Promise<import("./definitions/FoundGroupsAsResponse").FoundGroupsAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of all users in a group.
  
  Note that users are ordered by username, however the username is not returned in the results due to privacy reasons.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Group.User.getUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-member-get
  * @param options Request options.
  */
    getUsersFromGroup<T = Group.User.GetUsers.Response.OK>(options: Group.User.GetUsers.Options): Promise<import("./definitions/PageBeanUserDetailsAsResponse").PageBeanUserDetailsAsResponse>;
    /**
  * Adds a user to a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Recommended usage: Group.User.addUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-post
  * @param options Request options.
  */
    addUserToGroup<T = Group.User.AddUser.Response.OK>(options: Group.User.AddUser.Options): Promise<import("./definitions/GroupAsResponse").GroupAsResponse>;
    /**
  * Removes a user from a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Recommended usage: Group.User.removeUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-delete
  * @param options Request options.
  */
    removeUserFromGroup<T = Group.User.RemoveUser.Response.OK>(options: Group.User.RemoveUser.Options): Promise<undefined>;
    /**
  * Returns a list of users and groups matching a string. The string is used:
  
   *  for users, to find a case-insensitive match with display name and e-mail address. Note that if a user has hidden their email address in their user profile, partial matches of the email address will not find the user. An exact match is required.
   *  for groups, to find a case-sensitive match with group name.
  
  For example, if the string *tin* is used, records with the display name *Tina*, email address *sarah@tinplatetraining.com*, and the group *accounting* would be returned.
  
  Optionally, the search can be refined to:
  
   *  the projects and issue types associated with a custom field, such as a user picker. The search can then be further refined to return only users and groups that have permission to view specific:
      
       *  projects.
       *  issue types.
      
      If multiple projects or issue types are specified, they must be a subset of those enabled for the custom field or no results are returned. For example, if a field is enabled for projects A, B, and C then the search could be limited to projects B and C. However, if the search is limited to projects B and D, nothing is returned.
   *  not return Connect app users and groups.
   *  return groups that have a case-insensitive match with the query.
  
  The primary use case for this resource is to populate a picker field suggestion list with users or groups. To this end, the returned object includes an `html` field for each list. This field highlights the matched query term in the item name with the HTML strong tag. Also, each list is wrapped in a response object that contains a header for use in a picker, specifically *Showing X of Y matching groups*.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/yodKLg).
  * Recommended usage: GroupAndUserPicker.findUsersAndGroups
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-groupuserpicker-get
  * @param options Request options.
  */
    findUsersAndGroupsForPicker<T = GroupAndUserPicker.FindUsersAndGroups.Response.OK>(options: GroupAndUserPicker.FindUsersAndGroups.Options): Promise<import("./definitions/FoundUsersAndGroupsAsResponse").FoundUsersAndGroupsAsResponse>;
    /**
  * Parses and validates JQL queries.
  
  Validation is performed in context of the current user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Jql.parseQuery
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-jql-parse-post
  * @param options Request options.
  */
    parseJqlQuery<T = Jql.ParseQuery.Response.OK>(options: Jql.ParseQuery.Options): Promise<import("./definitions/ParsedJqlQueriesAsResponse").ParsedJqlQueriesAsResponse>;
    /**
  * Converts one or more JQL queries with user identifiers (username or user key) to equivalent JQL queries with account IDs.
  
  You may wish to use this operation if your system stores JQL queries and you want to make them GDPR-compliant. For more information about GDPR-related changes, see the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/).
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Jql.convertUserIdentifiersToAccountIdsInQueries
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-jql-pdcleaner-post
  * @param options Request options.
  */
    convertUserIdentifiersToAccountIdsInJqlQueries<T = Jql.ConvertUserIdentifiersToAccountIdsInQueries.Response.OK>(options: Jql.ConvertUserIdentifiersToAccountIdsInQueries.Options): Promise<import("./definitions/ConvertedJQLQueriesAsResponse").ConvertedJQLQueriesAsResponse>;
    /**
  * Returns reference data for JQL searches. This is a downloadable version of the documentation provided in [Advanced searching - fields reference](https://confluence.atlassian.com/x/gwORLQ) and [Advanced searching - functions reference](https://confluence.atlassian.com/x/hgORLQ), along with a list of JQL-reserved words. Use this information to assist with the programmatic creation of JQL queries or the validation of queries built in a custom query builder.
  
  To filter visible field details by project or collapse non-unique fields by field type then [Get field reference data (POST)](#api-rest-api-3-jql-autocompletedata-post) can be used.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Jql.getReferenceData
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-autocompletedata-get
  * @param options Request options.
  */
    getReferenceDataForJql<T = Jql.GetReferenceData.Response.OK>(options?: Jql.GetReferenceData.Options): Promise<import("./definitions/JQLReferenceDataAsResponse").JQLReferenceDataAsResponse>;
    /**
     * Returns a [paginated](#pagination) list of labels.
     * Recommended usage: Label.getLabels
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-label-get
     * @param options Request options.
     */
    getLabels<T = Label.GetLabels.Response.OK>(options?: Label.GetLabels.Options): Promise<import("./definitions/PageBeanStringAsResponse").PageBeanStringAsResponse>;
    /**
  * Returns a list of permissions indicating which permissions the user has. Details of the user's permissions can be obtained in a global, project, or issue context.
  
  The user is reported as having a project permission:
  
   *  in the global context, if the user has the project permission in any project.
   *  for a project, where the project permission is determined using issue data, if the user meets the permission's criteria for any issue in the project. Otherwise, if the user has the project permission in the project.
   *  for an issue, where a project permission is determined using issue data, if the user has the permission in the issue. Otherwise, if the user has the project permission in the project containing the issue.
  
  This means that users may be shown as having an issue permission (such as EDIT\_ISSUES) in the global context or a project context but may not have the permission for any or all issues. For example, if Reporters have the EDIT\_ISSUES permission a user would be shown as having this permission in the global context or the context of a project, because any user can be a reporter. However, if they are not the user who reported the issue queried they would not have EDIT\_ISSUES permission for that issue.
  
  Global permissions are unaffected by context.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Permission.getMyPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypermissions-get
  * @param options Request options.
  */
    getMyPermissions<T = Permission.GetMyPermissions.Response.OK>(options: Permission.GetMyPermissions.Options): Promise<import("./definitions/PermissionsAsResponse").PermissionsAsResponse>;
    /**
  * Returns all permissions, including:
  
   *  global permissions.
   *  project permissions.
   *  global permissions added by plugins.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Permission.getPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-permissions-get
  * @param options Request options.
  */
    getPermissions<T = Permission.GetPermissions.Response.OK>(options?: Permission.GetPermissions.Options): Promise<import("./definitions/PermissionsAsResponse").PermissionsAsResponse>;
    /**
  * Returns:
  
   *  for a list of global permissions, the global permissions granted to a user.
   *  for a list of project permissions and lists of projects and issues, for each project permission a list of the projects and issues a user can access or manipulate.
  
  If no account ID is provided, the operation returns details for the logged in user.
  
  Note that:
  
   *  Invalid project and issue IDs are ignored.
   *  A maximum of 1000 projects and 1000 issues can be checked.
   *  Null values in `globalPermissions`, `projectPermissions`, `projectPermissions.projects`, and `projectPermissions.issues` are ignored.
   *  Empty strings in `projectPermissions.permissions` are ignored.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to check the permissions for other users, otherwise none. However, Connect apps can make a call from the app server to the product to obtain permission details for any user, without admin permission. This Connect app ability doesn't apply to calls made using AP.request() in a browser.
  * Recommended usage: Permission.getBulkPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-permissions-check-post
  * @param options Request options.
  */
    getBulkPermissions<T = Permission.GetBulkPermissions.Response.OK>(options: Permission.GetBulkPermissions.Options): Promise<import("./definitions/BulkPermissionGrantsAsResponse").BulkPermissionGrantsAsResponse>;
    /**
  * Returns all the projects where the user is granted a list of project permissions.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Permission.getPermittedProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-permissions-project-post
  * @param options Request options.
  */
    getPermittedProjects<T = Permission.GetPermittedProjects.Response.OK>(options: Permission.GetPermittedProjects.Options): Promise<import("./definitions/PermittedProjectsAsResponse").PermittedProjectsAsResponse>;
    /**
  * Returns all permission schemes.
  
  ### About permission schemes and grants ###
  
  A permission scheme is a collection of permission grants. A permission grant consists of a `holder` and a `permission`.
  
  #### Holder object ####
  
  The `holder` object contains information about the user or group being granted the permission. For example, the *Administer projects* permission is granted to a group named *Teams in space administrators*. In this case, the type is `"type": "group"`, and the parameter is the group name, `"parameter": "Teams in space administrators"`. The `holder` object is defined by the following properties:
  
   *  `type` Identifies the user or group (see the list of types below).
   *  `parameter` The value of this property depends on the `type`. For example, if the `type` is a group, then you need to specify the group name.
  
  The following `types` are available. The expected values for the `parameter` are given in parenthesis (some `types` may not have a `parameter`):
  
   *  `anyone` Grant for anonymous users.
   *  `applicationRole` Grant for users with access to the specified application (application name). See [Update product access settings](https://confluence.atlassian.com/x/3YxjL) for more information.
   *  `assignee` Grant for the user currently assigned to an issue.
   *  `group` Grant for the specified group (group name).
   *  `groupCustomField` Grant for a user in the group selected in the specified custom field (custom field ID).
   *  `projectLead` Grant for a project lead.
   *  `projectRole` Grant for the specified project role (project role ID).
   *  `reporter` Grant for the user who reported the issue.
   *  `sd.customer.portal.only` Jira Service Desk only. Grants customers permission to access the customer portal but not Jira. See [Customizing Jira Service Desk permissions](https://confluence.atlassian.com/x/24dKLg) for more information.
   *  `user` Grant for the specified user (user ID - historically this was the userkey but that is deprecated and the account ID should be used).
   *  `userCustomField` Grant for a user selected in the specified custom field (custom field ID).
  
  #### Built-in permissions ####
  
  The [built-in Jira permissions](https://confluence.atlassian.com/x/yodKLg) are listed below. Apps can also define custom permissions. See the [project permission](https://developer.atlassian.com/cloud/jira/platform/modules/project-permission/) and [global permission](https://developer.atlassian.com/cloud/jira/platform/modules/global-permission/) module documentation for more information.
  
  **Project permissions**
  
   *  `ADMINISTER_PROJECTS`
   *  `BROWSE_PROJECTS`
   *  `MANAGE_SPRINTS_PERMISSION` (Jira Software only)
   *  `SERVICEDESK_AGENT` (Jira Service Desk only)
   *  `VIEW_DEV_TOOLS` (Jira Software only)
   *  `VIEW_READONLY_WORKFLOW`
  
  **Issue permissions**
  
   *  `ASSIGNABLE_USER`
   *  `ASSIGN_ISSUES`
   *  `CLOSE_ISSUES`
   *  `CREATE_ISSUES`
   *  `DELETE_ISSUES`
   *  `EDIT_ISSUES`
   *  `LINK_ISSUES`
   *  `MODIFY_REPORTER`
   *  `MOVE_ISSUES`
   *  `RESOLVE_ISSUES`
   *  `SCHEDULE_ISSUES`
   *  `SET_ISSUE_SECURITY`
   *  `TRANSITION_ISSUES`
  
  **Voters and watchers permissions**
  
   *  `MANAGE_WATCHERS`
   *  `VIEW_VOTERS_AND_WATCHERS`
  
  **Comments permissions**
  
   *  `ADD_COMMENTS`
   *  `DELETE_ALL_COMMENTS`
   *  `DELETE_OWN_COMMENTS`
   *  `EDIT_ALL_COMMENTS`
   *  `EDIT_OWN_COMMENTS`
  
  **Attachments permissions**
  
   *  `CREATE_ATTACHMENTS`
   *  `DELETE_ALL_ATTACHMENTS`
   *  `DELETE_OWN_ATTACHMENTS`
  
  **Time tracking permissions**
  
   *  `DELETE_ALL_WORKLOGS`
   *  `DELETE_OWN_WORKLOGS`
   *  `EDIT_ALL_WORKLOGS`
   *  `EDIT_OWN_WORKLOGS`
   *  `WORK_ON_ISSUES`
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Permission.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-get
  * @param options Request options.
  */
    getPermissionSchemes<T = Permission.Scheme.GetSchemes.Response.OK>(options?: Permission.Scheme.GetSchemes.Options): Promise<import("./definitions/PermissionSchemesAsResponse").PermissionSchemesAsResponse>;
    /**
  * Creates a new permission scheme. You can create a permission scheme with or without defining a set of permission grants.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Permission.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-post
  * @param options Request options.
  */
    createPermissionScheme<T = Permission.Scheme.CreateScheme.Response.OK>(options: Permission.Scheme.CreateScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Returns a permission scheme.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Permission.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-get
  * @param options Request options.
  */
    getPermissionScheme<T = Permission.Scheme.GetScheme.Response.OK>(options: Permission.Scheme.GetScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Updates a permission scheme. Below are some important things to note when using this resource:
  
   *  If a permissions list is present in the request, then it is set in the permission scheme, overwriting *all existing* grants.
   *  If you want to update only the name and description, then do not send a permissions list in the request.
   *  Sending an empty list will remove all permission grants from the permission scheme.
  
  If you want to add or delete a permission grant instead of updating the whole list, see [Create permission grant](#api-rest-api-3-permissionscheme-schemeId-permission-post) or [Delete permission scheme entity](#api-rest-api-3-permissionscheme-schemeId-permission-permissionId-delete).
  
  See [About permission schemes and grants](#about-permission-schemes) for more details.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Permission.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-put
  * @param options Request options.
  */
    updatePermissionScheme<T = Permission.Scheme.UpdateScheme.Response.OK>(options: Permission.Scheme.UpdateScheme.Options): Promise<import("./definitions/PermissionSchemeAsResponse").PermissionSchemeAsResponse>;
    /**
  * Deletes a permission scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Permission.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-delete
  * @param options Request options.
  */
    deletePermissionScheme<T = Permission.Scheme.DeleteScheme.Response.OK>(options: Permission.Scheme.DeleteScheme.Options): Promise<undefined>;
    /**
  * Returns all permission grants for a permission scheme.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Permission.Scheme.Grant.getGrants
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-get
  * @param options Request options.
  */
    getPermissionSchemeGrants<T = Permission.Scheme.Grant.GetGrants.Response.OK>(options: Permission.Scheme.Grant.GetGrants.Options): Promise<import("./definitions/PermissionGrantsAsResponse").PermissionGrantsAsResponse>;
    /**
  * Creates a permission grant in a permission scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Permission.Scheme.Grant.createGrant
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-post
  * @param options Request options.
  */
    createPermissionSchemeGrant<T = Permission.Scheme.Grant.CreateGrant.Response.OK>(options: Permission.Scheme.Grant.CreateGrant.Options): Promise<import("./definitions/PermissionGrantAsResponse").PermissionGrantAsResponse>;
    /**
  * Returns a permission grant.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Permission.Scheme.Grant.getGrant
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-get
  * @param options Request options.
  */
    getPermissionSchemeGrant<T = Permission.Scheme.Grant.GetGrant.Response.OK>(options: Permission.Scheme.Grant.GetGrant.Options): Promise<import("./definitions/PermissionGrantAsResponse").PermissionGrantAsResponse>;
    /**
  * Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Permission.Scheme.Grant.deleteGrant
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-delete
  * @param options Request options.
  */
    deletePermissionSchemeGrant<T = Permission.Scheme.Grant.DeleteGrant.Response.OK>(options: Permission.Scheme.Grant.DeleteGrant.Options): Promise<undefined>;
    /**
  * Returns the value of a preference of the current user.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default this is not set and the user takes the locale of the instance.
   *  *jira.user.timezone* The time zone of the user. By default this is not set and the user takes the timezone of the instance.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Myself.getPreference
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-get
  * @param options Request options.
  */
    getMyPreference<T = Myself.GetPreference.Response.OK>(options: Myself.GetPreference.Options): Promise<string>;
    /**
  * Creates a preference for the user or updates a preference's value by sending a plain text string. For example, `false`. An arbitrary preference can be created with the value containing up to 255 characters. In addition, the following keys define system preferences that can be set or created:
  
   *  *user.notifications.mimetype* The mime type used in notifications sent to the user. Defaults to `html`.
   *  *user.notify.own.changes* Whether the user gets notified of their own changes. Defaults to `false`.
   *  *user.default.share.private* Whether new [ filters](https://confluence.atlassian.com/x/eQiiLQ) are set to private. Defaults to `true`.
   *  *user.keyboard.shortcuts.disabled* Whether keyboard shortcuts are disabled. Defaults to `false`.
   *  *user.autowatch.disabled* Whether the user automatically watches issues they create or add a comment to. By default, not set: the user takes the instance autowatch setting.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
   *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Myself.setPreference
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-put
  * @param options Request options.
  */
    setMyPreference<T = Myself.SetPreference.Response.OK>(options: Myself.SetPreference.Options): Promise<any>;
    /**
  * Deletes a preference of the user, which restores the default value of system defined settings.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
   *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Myself.deletePreference
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-delete
  * @param options Request options.
  */
    deleteMyPreference<T = Myself.DeletePreference.Response.OK>(options: Myself.DeletePreference.Options): Promise<undefined>;
    /**
  * Returns the locale for the user.
  
  If the user has no language preference set (which is the default setting) or this resource is accessed anonymous, the browser locale detected by Jira is returned. Jira detects the browser locale using the *Accept-Language* header in the request. However, if this doesn't match a locale available Jira, the site default locale is returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Myself.getLocale
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-locale-get
  * @param options Request options.
  */
    getMyLocale<T = Myself.GetLocale.Response.OK>(options?: Myself.GetLocale.Options): Promise<import("./definitions/LocaleAsResponse").LocaleAsResponse>;
    /**
  * Returns details for the current user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Myself.getCurrentUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-myself-get
  * @param options Request options.
  */
    getCurrentUser<T = Myself.GetCurrentUser.Response.OK>(options?: Myself.GetCurrentUser.Options): Promise<import("./definitions/UserAsResponse").UserAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of published classic workflows. When workflow names are specified, details of those workflows are returned. Otherwise, all published classic workflows are returned.
  
  This operation does not return next-gen workflows.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.getWorkflows
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflow-search-get
  * @param options Request options.
  */
    getWorkflows<T = Workflow.GetWorkflows.Response.OK>(options?: Workflow.GetWorkflows.Options): Promise<import("./definitions/PageBeanWorkflowAsResponse").PageBeanWorkflowAsResponse>;
    /**
  * Returns a list of all statuses associated with workflows.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Recommended usage: Workflow.Status.getStatuses
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-status-get
  * @param options Request options.
  */
    getWorkflowStatuses<T = Workflow.Status.GetStatuses.Response.OK>(options?: Workflow.Status.GetStatuses.Options): Promise<Workflow.Status.GetStatuses.Response.OK>;
    /**
  * Returns a status. The status must be associated with a workflow to be returned.
  
  If a name is used on more than one status, only the status found first is returned. Therefore, identifying the status by its ID may be preferable.
  
  This operation can be accessed anonymously.
  
  [Permissions](#permissions) required: None.
  * Recommended usage: Workflow.Status.getStatus
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-status-idOrName-get
  * @param options Request options.
  */
    getWorkflowStatus<T = Workflow.Status.GetStatus.Response.OK>(options: Workflow.Status.GetStatus.Options): Promise<import("./definitions/StatusDetailsAsResponse").StatusDetailsAsResponse>;
    /**
  * Returns a list of all status categories.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Workflow.Status.Category.getCategories
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-get
  * @param options Request options.
  */
    getWorkflowStatusCategories<T = Workflow.Status.Category.GetCategories.Response.OK>(options?: Workflow.Status.Category.GetCategories.Options): Promise<Workflow.Status.Category.GetCategories.Response.OK>;
    /**
  * Returns a status category. Status categories provided a mechanism for categorizing [statuses](#api-rest-api-3-status-idOrName-get).
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Recommended usage: Workflow.Status.Category.getCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-idorkey-get
  * @param options Request options.
  */
    getWorkflowStatusCategory<T = Workflow.Status.Category.GetCategory.Response.OK>(options: Workflow.Status.Category.GetCategory.Options): Promise<import("./definitions/StatusCategoryAsResponse").StatusCategoryAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of all workflow schemes, not including draft workflow schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-workflowscheme-get
  * @param options Request options.
  */
    getWorkflowSchemes<T = Workflow.Scheme.GetSchemes.Response.OK>(options?: Workflow.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanWorkflowSchemeAsResponse").PageBeanWorkflowSchemeAsResponse>;
    /**
  * Creates a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-post
  * @param options Request options.
  */
    createWorkflowScheme<T = Workflow.Scheme.CreateScheme.Response.OK>(options: Workflow.Scheme.CreateScheme.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Returns a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-get
  * @param options Request options.
  */
    getWorkflowScheme<T = Workflow.Scheme.GetScheme.Response.OK>(options: Workflow.Scheme.GetScheme.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Updates a workflow scheme, including the name, default workflow, issue type to project mappings, and more. If the workflow scheme is active (that is, being used by at least one project), then a draft workflow scheme is created or updated instead, provided that `updateDraftIfNeeded` is set to `true`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-put
  * @param options Request options.
  */
    updateWorkflowScheme<T = Workflow.Scheme.UpdateScheme.Response.OK>(options: Workflow.Scheme.UpdateScheme.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Deletes a workflow scheme. Note that a workflow scheme cannot be deleted if it is active (that is, being used by at least one project).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-delete
  * @param options Request options.
  */
    deleteWorkflowScheme<T = Workflow.Scheme.DeleteScheme.Response.OK>(options: Workflow.Scheme.DeleteScheme.Options): Promise<undefined>;
    /**
  * Returns the issue type-workflow mapping for an issue type in a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.getWorkflowForIssueType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-get
  * @param options Request options.
  */
    getWorkflowForIssueTypeInWorkflowScheme<T = Workflow.Scheme.GetWorkflowForIssueType.Response.OK>(options: Workflow.Scheme.GetWorkflowForIssueType.Options): Promise<import("./definitions/IssueTypeWorkflowMappingAsResponse").IssueTypeWorkflowMappingAsResponse>;
    /**
  * Sets the workflow for an issue type in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new issue type-workflow mapping. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.setWorkflowForIssueType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-put
  * @param options Request options.
  */
    setWorkflowForIssueTypeInWorkflowScheme<T = Workflow.Scheme.SetWorkflowForIssueType.Response.OK>(options: Workflow.Scheme.SetWorkflowForIssueType.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Deletes the issue type-workflow mapping for an issue type in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the issue type-workflow mapping deleted. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.deleteWorkflowForIssueType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-delete
  * @param options Request options.
  */
    deleteWorkflowForIssueTypeInWorkflowScheme<T = Workflow.Scheme.DeleteWorkflowForIssueType.Response.OK>(options: Workflow.Scheme.DeleteWorkflowForIssueType.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Returns the workflow-issue type mappings for a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.getIssueTypesForWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-get
  * @param options Request options.
  */
    getIssueTypesForWorkflowInWorkflowScheme<T = Workflow.Scheme.GetIssueTypesForWorkflow.Response.OK>(options: Workflow.Scheme.GetIssueTypesForWorkflow.Options): Promise<Workflow.Scheme.GetIssueTypesForWorkflow.Response.OK>;
    /**
  * Sets the issue types for a workflow in a workflow scheme. The workflow can also be set as the default workflow for the workflow scheme. Unmapped issues types are mapped to the default workflow.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new workflow-issue types mappings. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.setIssueTypesForWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-put
  * @param options Request options.
  */
    setIssueTypesForWorkflowInWorkflowScheme<T = Workflow.Scheme.SetIssueTypesForWorkflow.Response.OK>(options: Workflow.Scheme.SetIssueTypesForWorkflow.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Deletes the workflow-issue type mapping for a workflow in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the workflow-issue type mapping deleted. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.deleteIssueTypesForWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-delete
  * @param options Request options.
  */
    deleteIssueTypesForWorkflowInWorkflowScheme<T = Workflow.Scheme.DeleteIssueTypesForWorkflow.Response.OK>(options: Workflow.Scheme.DeleteIssueTypesForWorkflow.Options): Promise<undefined>;
    /**
  * Returns the default workflow for a workflow scheme. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.getDefaultWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-get
  * @param options Request options.
  */
    getDefaultWorkflowForWorkflowScheme<T = Workflow.Scheme.GetDefaultWorkflow.Response.OK>(options: Workflow.Scheme.GetDefaultWorkflow.Options): Promise<import("./definitions/DefaultWorkflowAsResponse").DefaultWorkflowAsResponse>;
    /**
  * Sets the default workflow for a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request object and a draft workflow scheme is created or updated with the new default workflow. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.updateDefaultWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-put
  * @param options Request options.
  */
    updateDefaultWorkflowForWorkflowScheme<T = Workflow.Scheme.UpdateDefaultWorkflow.Response.OK>(options: Workflow.Scheme.UpdateDefaultWorkflow.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Resets the default workflow for a workflow scheme. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the default workflow reset. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.deleteDefaultWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-delete
  * @param options Request options.
  */
    deleteDefaultWorkflowForWorkflowScheme<T = Workflow.Scheme.DeleteDefaultWorkflow.Response.OK>(options: Workflow.Scheme.DeleteDefaultWorkflow.Options): Promise<import("./definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse>;
    /**
  * Returns a list of the workflow schemes associated with a list of projects. Each returned workflow scheme includes a list of the requested projects associated with it. Any team-managed or non-existent projects in the request are ignored and no errors are returned.
  
  If the project is associated with the `Default Workflow Scheme` no ID is returned. This is because the way the `Default Workflow Scheme` is stored means it has no ID.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.Project.getProjectAssociations
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-get
  * @param options Request options.
  */
    getWorkflowSchemeProjectAssociations<T = Workflow.Scheme.Project.GetProjectAssociations.Response.OK>(options: Workflow.Scheme.Project.GetProjectAssociations.Options): Promise<import("./definitions/ContainerOfWorkflowSchemeAssociationsAsResponse").ContainerOfWorkflowSchemeAssociationsAsResponse>;
    /**
  * Assigns a workflow scheme to a project. This operation is performed only when there are no issues in the project.
  
  Workflow schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Scheme.Project.assignWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-put
  * @param options Request options.
  */
    assignWorkflowSchemeToProject<T = Workflow.Scheme.Project.AssignWorkflow.Response.OK>(options: Workflow.Scheme.Project.AssignWorkflow.Options): Promise<any>;
    /**
  * Updates a workflow transition by changing the property value. Trying to update a property that does not exist results in a new property being added to the transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Transition.Property.updateProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-put
  * @param options Request options.
  */
    updateWorkflowTransitionProperty<T = Workflow.Transition.Property.UpdateProperty.Response.OK>(options: Workflow.Transition.Property.UpdateProperty.Options): Promise<import("./definitions/WorkflowTransitionPropertyAsResponse").WorkflowTransitionPropertyAsResponse>;
    /**
  * Adds a property to a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Transition.Property.createProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-post
  * @param options Request options.
  */
    createWorkflowTransitionProperty<T = Workflow.Transition.Property.CreateProperty.Response.OK>(options: Workflow.Transition.Property.CreateProperty.Options): Promise<import("./definitions/WorkflowTransitionPropertyAsResponse").WorkflowTransitionPropertyAsResponse>;
    /**
  * Deletes a property from a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Workflow.Transition.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-delete
  * @param options Request options.
  */
    deleteWorkflowTransitionProperty<T = Workflow.Transition.Property.DeleteProperty.Response.OK>(options: Workflow.Transition.Property.DeleteProperty.Options): Promise<undefined>;
    /**
  * Returns a [paginated](#pagination) list of the screens a field is used in.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.getScreensForField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-field-fieldid-screens-get
  * @param options Request options.
  */
    getScreensForField<T = Screen.GetScreensForField.Response.OK>(options: Screen.GetScreensForField.Options): Promise<import("./definitions/PageBeanScreenWithTabAsResponse").PageBeanScreenWithTabAsResponse>;
    /**
  * Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.getScreens
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-get
  * @param options Request options.
  */
    getScreens<T = Screen.GetScreens.Response.OK>(options?: Screen.GetScreens.Options): Promise<import("./definitions/PageBeanScreenAsResponse").PageBeanScreenAsResponse>;
    /**
  * Creates a screen with a default field tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.createScreen
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-post
  * @param options Request options.
  */
    createScreen<T = Screen.CreateScreen.Response.OK>(options: Screen.CreateScreen.Options): Promise<import("./definitions/ScreenAsResponse").ScreenAsResponse>;
    /**
  * Adds a field to the default tab of the default screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.addFieldToDefaultScreen
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-addtodefault-fieldid-post
  * @param options Request options.
  */
    addFieldToDefaultScreen<T = Screen.AddFieldToDefaultScreen.Response.OK>(options: Screen.AddFieldToDefaultScreen.Options): Promise<"CREATED">;
    /**
  * Returns the fields that can be added to a tab on a screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.getAvailableScreenFields
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-availablefields-get
  * @param options Request options.
  */
    getAvailableScreenFields<T = Screen.GetAvailableScreenFields.Response.OK>(options: Screen.GetAvailableScreenFields.Options): Promise<Screen.GetAvailableScreenFields.Response.OK>;
    /**
  * Updates a screen. Only screens used in classic projects can be updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.updateScreen
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-put
  * @param options Request options.
  */
    updateScreen<T = Screen.UpdateScreen.Response.OK>(options: Screen.UpdateScreen.Options): Promise<import("./definitions/ScreenAsResponse").ScreenAsResponse>;
    /**
  * Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.
  
  Only screens used in classic projects can be deleted.
  * Recommended usage: Screen.deleteScreen
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-delete
  * @param options Request options.
  */
    deleteScreen<T = Screen.DeleteScreen.Response.OK>(options: Screen.DeleteScreen.Options): Promise<undefined>;
    /**
  * Returns a [paginated](#pagination) list of screen schemes.
  
  Only screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-screenscheme-get
  * @param options Request options.
  */
    getScreenSchemes<T = Screen.Scheme.GetSchemes.Response.OK>(options?: Screen.Scheme.GetSchemes.Options): Promise<import("./definitions/PageBeanScreenSchemeAsResponse").PageBeanScreenSchemeAsResponse>;
    /**
  * Creates a screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-post
  * @param options Request options.
  */
    createScreenScheme<T = Screen.Scheme.CreateScheme.Response.OK>(options: Screen.Scheme.CreateScheme.Options): Promise<import("./definitions/ScreenSchemeIdAsResponse").ScreenSchemeIdAsResponse>;
    /**
  * Updates a screen scheme. Only screen schemes used in classic projects can be updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-put
  * @param options Request options.
  */
    updateScreenScheme<T = Screen.Scheme.UpdateScheme.Response.OK>(options: Screen.Scheme.UpdateScheme.Options): Promise<any>;
    /**
  * Deletes a screen scheme. A screen scheme cannot be deleted if it is used in an issue type screen scheme.
  
  Only screens schemes used in classic projects can be deleted.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-delete
  * @param options Request options.
  */
    deleteScreenScheme<T = Screen.Scheme.DeleteScheme.Response.OK>(options: Screen.Scheme.DeleteScheme.Options): Promise<undefined>;
    /**
  * Returns the list of tabs for a screen.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
  * Recommended usage: Screen.Tab.getTabs
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-get
  * @param options Request options.
  */
    getScreenTabs<T = Screen.Tab.GetTabs.Response.OK>(options: Screen.Tab.GetTabs.Options): Promise<Screen.Tab.GetTabs.Response.OK>;
    /**
  * Creates a tab for a screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Tab.createTab
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-post
  * @param options Request options.
  */
    createScreenTab<T = Screen.Tab.CreateTab.Response.OK>(options: Screen.Tab.CreateTab.Options): Promise<import("./definitions/ScreenableTabAsResponse").ScreenableTabAsResponse>;
    /**
  * Updates the name of a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Tab.updateTab
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-put
  * @param options Request options.
  */
    updateScreenTab<T = Screen.Tab.UpdateTab.Response.OK>(options: Screen.Tab.UpdateTab.Options): Promise<import("./definitions/ScreenableTabAsResponse").ScreenableTabAsResponse>;
    /**
  * Deletes a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Tab.deleteTab
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-delete
  * @param options Request options.
  */
    deleteScreenTab<T = Screen.Tab.DeleteTab.Response.OK>(options: Screen.Tab.DeleteTab.Options): Promise<undefined>;
    /**
  * Moves a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Tab.moveTab
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-move-pos-post
  * @param options Request options.
  */
    moveScreenTab<T = Screen.Tab.MoveTab.Response.OK>(options: Screen.Tab.MoveTab.Options): Promise<any>;
    /**
  * Returns all fields for a screen tab.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
  * Recommended usage: Screen.Tab.Field.getFields
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-get
  * @param options Request options.
  */
    getScreenTabFields<T = Screen.Tab.Field.GetFields.Response.OK>(options: Screen.Tab.Field.GetFields.Options): Promise<Screen.Tab.Field.GetFields.Response.OK>;
    /**
  * Adds a field to a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Tab.Field.addField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-post
  * @param options Request options.
  */
    addScreenTabField<T = Screen.Tab.Field.AddField.Response.OK>(options: Screen.Tab.Field.AddField.Options): Promise<import("./definitions/ScreenableFieldAsResponse").ScreenableFieldAsResponse>;
    /**
  * Removes a field from a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Tab.Field.removeField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-delete
  * @param options Request options.
  */
    removeScreenTabField<T = Screen.Tab.Field.RemoveField.Response.OK>(options: Screen.Tab.Field.RemoveField.Options): Promise<undefined>;
    /**
  * Moves a screen tab field.
  
  If `after` and `position` are provided in the request, `position` is ignored.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Screen.Tab.Field.moveField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-move-post
  * @param options Request options.
  */
    moveScreenTabField<T = Screen.Tab.Field.MoveField.Response.OK>(options: Screen.Tab.Field.MoveField.Options): Promise<any>;
    /**
  * Returns the system and custom avatars for a project or issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  for custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
   *  for custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
   *  for system avatars, none.
  * Recommended usage: Avatar.getAvatars
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-entityid-get
  * @param options Request options.
  */
    getAvatars<T = Avatar.GetAvatars.Response.OK>(options: Avatar.GetAvatars.Options): Promise<import("./definitions/AvatarsAsResponse").AvatarsAsResponse>;
    /**
  * Loads a custom avatar for a project or issue type.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST `
  
  `--user email@example.com:<api_token> `
  
  `--header 'X-Atlassian-Token: no-check' `
  
  `--header 'Content-Type: image/< image_type>' `
  
  `--data-binary "<@/path/to/file/with/your/avatar>" `
  
  `--url 'https://your-domain.atlassian.net/rest/api/3/universal_avatar/type/{type}/owner/{entityId}'`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar use:
  
   *  [Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
   *  [Set project avatar](#api-rest-api-3-project-projectIdOrKey-avatar-put) to set it as the project's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Avatar.loadAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-entityid-post
  * @param options Request options.
  */
    loadAvatar<T = Avatar.LoadAvatar.Response.OK>(options: Avatar.LoadAvatar.Options): Promise<import("./definitions/AvatarAsResponse").AvatarAsResponse>;
    /**
  * Deletes an avatar from a project or issue type.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Avatar.deleteAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-owningobjectid-avatar-id-delete
  * @param options Request options.
  */
    deleteAvatar<T = Avatar.DeleteAvatar.Response.OK>(options: Avatar.DeleteAvatar.Options): Promise<undefined>;
}
export {};
//# sourceMappingURL=index.d.ts.map